#
# spec file for package grafana
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           grafana
Version:        7.5.7
Release:        lp152.2.19.1
Summary:        The open-source platform for monitoring and observability
License:        Apache-2.0
Group:          System/Monitoring
URL:            http://grafana.org/
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        %{name}-rpmlintrc
# Instructions on the build process
Source3:        README
# Makefile to automate build process
Source4:        Makefile
Source5:        0001-Add-source-code-reference.patch
Patch1:         drop-grafana-aws-sdk-0.3.0-module.patch
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.15
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post): %fillup_prereq
Requires:       group(grafana)
Requires:       user(grafana)
%systemd_ordering

%go_nostrip

# Exclude s390 on SLE12, since golang 1.14 itself is not built for this arch on SLE12
# See https://build.suse.de/package/view_file/SUSE:SLE-12:Update/go1.14/go1.14.spec?expand=1
%if 0%{?suse_version} == 1315
ExcludeArch:    s390
%endif

%description
A graph and dashboard builder for visualizing time series metrics.

Grafana provides ways to create, explore, and share
dashboards and data with teams.

%prep
%setup -q -n grafana-%{version}
%setup -q -T -D -a 1 -n grafana-%{version}
%patch1 -p1

%build
%goprep github.com/grafana/grafana
# Manual build in order to inject ldflags so grafana correctly displays
# the version in the footer of each page.  Note that we're only injecting
# main.version, not main.commit or main.buildstamp as is done in the upstream
# build.go, because we don't have access to the git commit history here.
# (The %%gobuild macro can't take quoted strings; they get split up when
# expanded to $extra_flags in process_build() in /usr/lib/rpm/golang.sh.)
export IMPORTPATH="github.com/grafana/grafana"
export BUILDFLAGS="-v -p 4 -x -buildmode=pie -mod=vendor"
export GOPATH=%{_builddir}/go:%{_builddir}/contrib
export GOBIN=%{_builddir}/go/bin
go install $BUILDFLAGS -ldflags '-X main.version=%{version}' $IMPORTPATH/pkg/cmd/...

%install
%goinstall

# we're missing %%gosrc and %%gofilelist... (although that *might* be ok...)

install -Dm644 {packaging/rpm/systemd/,%{buildroot}%{_unitdir}/}%{name}-server.service
install -dm755 %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service  %{buildroot}%{_sbindir}/rc%{name}-server
mv %{buildroot}/%{_bindir}/grafana-* %{buildroot}/%{_sbindir}

install -Dm644 packaging/rpm/sysconfig/%{name}-server \
%{buildroot}%{_fillupdir}/sysconfig.%{name}-server

install -d -m0750 %{buildroot}%{_localstatedir}/lib/%{name}
install -d -m0750 %{buildroot}%{_localstatedir}/log/%{name}
install -d -m0755 %{buildroot}/%{_localstatedir}/lib/%{name}/plugins
install -d -m0755 %{buildroot}/%{_localstatedir}/lib/%{name}/dashboards
install -d -m0755 %{buildroot}%{_sysconfdir}/%{name}/provisioning/dashboards

install -Dm640 conf/sample.ini %{buildroot}%{_sysconfdir}/%{name}/%{name}.ini
install -Dm640 {conf/,%{buildroot}%{_sysconfdir}/%{name}/}ldap.toml
install -Dm644 {conf/,%{buildroot}%{_datadir}/%{name}/conf/}defaults.ini
install -m644 {conf/,%{buildroot}%{_datadir}/%{name}/conf/}sample.ini
install -Dm644 {conf/provisioning/dashboards/,%{buildroot}%{_datadir}/%{name}/conf/provisioning/dashboards/}sample.yaml
install -Dm644 {conf/provisioning/datasources/,%{buildroot}%{_datadir}/%{name}/conf/provisioning/datasources/}sample.yaml
cp -pr public %{buildroot}%{_datadir}/%{name}/
install -d -m755 %{buildroot}%{_datadir}/%{name}/vendor
install -d -m755 %{buildroot}%{_datadir}/%{name}/tools

# Do *not* use %%fudpes -s -- this will result in grafana failing to load
# all the plugins (something in the plugin scanner can't cope with files
# in there being symlinks).
%fdupes %{buildroot}/%{_datadir}

%check
#gotest github.com/grafana/grafana/pkg...

%pre
%service_add_pre %{name}-server.service

%post
%{fillup_only -n %{name}-server}
%service_add_post %{name}-server.service

%preun
%service_del_preun %{name}-server.service

%postun
%service_del_postun %{name}-server.service

%files
%defattr(-,root,root)
%license LICENSE*
%doc CHANGELOG*
%{_sbindir}/%{name}*
%{_sbindir}/rc%{name}-server
%{_unitdir}/%{name}-server.service
%{_fillupdir}/sysconfig.%{name}-server
%attr(0755,root,root) %dir %{_sysconfdir}/%{name}
%attr(0755,root,root) %dir %{_sysconfdir}/%{name}/provisioning
%attr(0755,root,root) %dir %{_sysconfdir}/%{name}/provisioning/dashboards
%attr(0755,root,grafana) %dir %{_datadir}/%{name}/conf
%attr(0640,root,grafana) %config(noreplace) %{_sysconfdir}/%{name}/%{name}.ini
%attr(0640,root,grafana) %config(noreplace) %{_sysconfdir}/%{name}/ldap.toml
%attr(0755,grafana,grafana) %dir %{_localstatedir}/lib/%{name}
%attr(0755,grafana,grafana) %dir %{_localstatedir}/lib/%{name}/plugins
%attr(0755,grafana,grafana) %dir %{_localstatedir}/lib/%{name}/dashboards
%attr(0750,grafana,grafana) %dir %{_localstatedir}/log/%{name}
%doc %{_datadir}/%{name}/conf/sample.ini
%doc %{_datadir}/%{name}/conf/provisioning/dashboards/sample.yaml
%doc %{_datadir}/%{name}/conf/provisioning/datasources/sample.yaml
%config %{_datadir}/%{name}/conf/defaults.ini
%{_datadir}/%{name}

%changelog
* Tue Sep 21 2021 Witek Bedyk <witold.bedyk@suse.com>
- Add patch 0001-Add-source-code-reference.patch
  * Add URL to package source code in the login page footer
* Thu May 20 2021 daniel.molkentin@suse.com
- Update to version 7.5.7:
  * Updated relref to "Configuring exemplars" section (#34240) (#34243)
  * Added exemplar topic (#34147) (#34226)
  * Quota: Do not count folders towards dashboard quota (#32519) (#34025)
  * Instructions to separate emails with semicolons (#32499) (#34138)
  * Docs: Remove documentation of v8 generic OAuth feature (#34018)
  * Annotations: Prevent orphaned annotation tags cleanup when no annotations were cleaned (#33957) (#33975)
  * [GH-33898] Add missing --no-cache to Dockerfile. (#33906) (#33935)
  * ReleaseNotes: Updated changelog and release notes for 7.5.6 (#33932) (#33936)
  * Stop hoisting @icons/material (#33922)
  * Chore: fix react-color version in yarn.lock (#33914)
  * "Release: Updated versions in package to 7.5.6" (#33909)
  * Loki: fix label browser crashing when + typed (#33900) (#33901)
  * Document `hide_version` flag (#33670) (#33881)
  * Add isolation level db configuration parameter (#33830) (#33878)
  * Sanitize PromLink button (#33874) (#33876)
  * Removed content as per MarcusE's suggestion in https://github.com/grafana/grafana/issues/33822. (#33870) (#33872)
  * Docs feedback: /administration/provisioning.md (#33804) (#33842)
  * Docs: delete from high availability docs references to removed configurations related to session storage (#33827) (#33851)
  * Docs: Update _index.md (#33797) (#33799)
  * Docs: Update installation.md (#33656) (#33703)
  * GraphNG: uPlot 1.6.9 (#33598) (#33612)
  * dont consider invalid email address a failed email (#33671) (#33681)
  * InfluxDB: Improve measurement-autocomplete behavior in query editor (#33494) (#33625)
  * add template for dashboard url parameters  (#33549) (#33588)
  * Add note to Snapshot API doc to specify that user has to provide the entire dashboard model  (#33572) (#33586)
  * Update team.md (#33454) (#33536)
  * Removed duplicate file "dashboard_folder_permissions.md (#33497)
  * Document customQueryParameters for prometheus datasource provisioning (#33440) (#33495)
  * ReleaseNotes: Updated changelog and release notes for 7.5.5 (#33473) (#33492)
  * Documentation: Update developer-guide.md (#33478) (#33490)
  * add closed parenthesis to fix a hyperlink (#33471) (#33481)
* Thu May  6 2021 ecsos@opensuse.org
- Update to version 7.5.5:
  * "Release: Updated versions in package to 7.5.5" (#33469)
  * GraphNG: Fix exemplars window position (#33427) (#33462)
  * Remove field limitation from slack notification (#33113) (#33455)
  * Prometheus: Support POST in template variables (#33321) (#33441)
  * Instrumentation: Add success rate metrics for email notifications (#33359) (#33409)
  * Use either moment objects (for absolute times in the datepicker) or string (for relative time) (#33315) (#33406)
  * Docs: Removed type from find annotations example. (#33399) (#33403)
  * [v7.5.x]: FrontendMetrics: Adds new backend api that frontend can use to push frontend measurements and counters to prometheus (#33255)
  * Updated label for add panel. (#33285) (#33286)
  * Bug: Add git to Dockerfile.ubuntu (#33247) (#33248)
  * Docs: Sync latest master docs with 7.5.x (#33156)
  * Docs: Update getting-started-influxdb.md (#33234) (#33241)
  * Doc: Document the X-Grafana-Org-Id HTTP header (#32478) (#33239)
  * Minor Changes in Auditing.md (#31435) (#33238)
  * Docs: Add license check endpoint doc (#32987) (#33236)
  * Postgres: Fix time group macro when TimescaleDB is enabled and interval is less than a second (#33153) (#33219)
  * Docs: InfluxDB doc improvements (#32815) (#33185)
  * [v7.5.x] Loki: Pass Skip TLS Verify setting to alert queries (#33031)
  * update cla (#33181)
  * Fix inefficient regular expression (#33155) (#33159)
  * Auth: Don't clear auth token cookie when lookup token fails (#32999) (#33136)
  * Elasticsearch:  Add documentation for supported Elasticsearch query transformations (#33072) (#33128)
  * Update team.md (#33060) (#33084)
  * GE issue 1268 (#33049) (#33081)
  * Fixed some formatting issues for PRs from yesterday. (#33078) (#33079)
  * Explore: Load default data source in Explore when the provided source does not exist (#32992) (#33061)
  * Docs: Replace next with latest in aliases (#33054) (#33059)
  * Added missing link item. (#33052) (#33055)
  * Backport 33034 (#33038)
  * Docs: Backport 32916 to v7.5x  (#33008)
  * ReleaseNotes: Updated changelog and release notes for 7.5.4 (#32973) (#32998)
  * Elasticsearch: Force re-rendering of each editor row type change (#32993) (#32996)
  * Docs: Sync release branch with latest docs (#32986)
* Thu Apr 15 2021 ecsos@opensuse.org
- Update to version 7.5.4:
  * "Release: Updated versions in package to 7.5.4" (#32971)
  * fix(datasource_srv): prevent infinite loop where default datasource is named default (#32949) (#32967)
  * Added Azure Monitor support for Microsoft.AppConfiguration/configurationStores namespace (#32123) (#32968)
  * fix sqlite3 tx retry condition operator precedence (#32897) (#32952)
  * AzureMonitor: Add support for Virtual WAN namespaces (#32935) (#32947)
  * Plugins: Allow a non-dashboard page to be the default home page (#32926) (#32945)
  * GraphNG: uPlot 1.6.8 (#32859) (#32863)
  * Alerting: Add ability to include aliases with dashes (/) and at (@) signs in InfluxDB (#32844)
  * Prometheus: Allow exemplars endpoint in data source proxy (#32802) (#32804)
  * [v7.5.x] Table: Fixes table data links so they refer to correct row after sorting (#32758)
  * TablePanel: Makes sorting case-insensitive (#32435) (#32752)
* Mon Apr 12 2021 ecsos@opensuse.org
- Update to version 7.5.3:
  * "Release: Updated versions in package to 7.5.3" (#32745)
  * FolderPicker: Prevent dropdown menu from disappearing off screen (#32603) (#32741)
  * Loki: Remove empty annotations tags (#32359) (#32490)
  * SingleStat: fix wrong call to getDataLinkUIModel (#32721) (#32739)
  * Prometheus: Fix instant query to run two times when exemplars enabled (#32508) (#32726)
  * Elasticsearch: Fix bucket script variable duplication in UI (#32705) (#32714)
  * Variables: Confirms selection before opening new picker (#32586) (#32710)
  * CloudWarch: Fix service quotas link (#32686) (#32689)
  * Configuration: Prevent browser hanging / crashing with large number of org users (#32546) (#32598)
  * chore: bump execa to v2.1.0 (#32543) (#32592)
  * Explore: Fix bug where navigating to explore would result in wrong query and datasource to be shown (#32558)
  * Fix broken gtime tests (#32582) (#32587)
  * resolve conflicts (#32567)
  * gtime: Make ParseInterval deterministic (#32539) (#32560)
  * Dashboard: No longer includes default datasource when externally exporting dashboard with row (#32494) (#32535)
  * TextboxVariable: Limits the length of the preview value (#32472) (#32530)
  * AdHocVariable: Adds default data source (#32470) (#32476)
  * Variables: Fixes Unsupported data format error for null values (#32480) (#32487)
  * Prometheus: align exemplars check to latest api change (#32513) (#32515)
  * "Release: Updated versions in package to 7.5.2" (#32502)
  * SigV4: Add support EC2 IAM role auth and possibility to toggle auth providers  (#32444) (#32488)
  * Set spanNulls to default (#32471) (#32486)
  * Graph: Fix setting right y-axis when standard option unit is configured (#32426) (#32442)
  * API: Return 409 on datasource version conflict (#32425) (#32433)
  * API: Return 400 on invalid Annotation requests (#32429) (#32431)
  * Variables: Fixes problem with data source variable when default ds is selected (#32384) (#32424)
  * Table: Fixes so links work for image cells (#32370) (#32410)
  * Variables: Fixes error when manually non-matching entering custom value in variable input/picker (#32390) (#32394)
  * DashboardQueryEditor: Run query after selecting source panel (#32383) (#32395)
  * API: Datasource endpoint should return 400 bad request if id and orgId is invalid (#32392) (#32397)
  * "Release: Updated versions in package to 7.5.1" (#32362)
  * MSSQL: Upgrade go-mssqldb (#32347) (#32361)
  * GraphNG: Fix tooltip displaying wrong or no data (#32312) (#32348)
  * "Release: Updated versions in package to 7.5.0" (#32308)
  * Loki: Fix text search in Label browser (#32293) (#32306)
  * Explore: Show all dataFrames in data tab in Inspector (#32161) (#32299)
  * PieChartV2: Add migration from old piechart (#32259) (#32291)
  * LibraryPanels: Adds Type and Description to DB (#32258) (#32288)
  * LibraryPanels: Prevents deletion of connected library panels (#32277) (#32284)
  * Library Panels: Add "Discard" button to panel save modal (#31647) (#32281)
  * LibraryPanels: Changes to non readonly reducer (#32193) (#32200)
  * Notifications: InfluxDB - Fix regex to include metrics with hyphen in aliases (#32224) (#32262)
  * SSE/InfluxDB: Change InfluxQL to work with server side expressions (#31691) (#32102)
  * DashboardSettings: Fixes issue with tags list not updating when changes are made (#32241) (#32247)
  * Logs: If log message missing, use empty string (#32080) (#32243)
  * CloudWatch: Use latest version of aws sdk (#32217) (#32223)
  * Release: Updated versions in package to 7.5.0-beta.2 (#32158)
  * HttpServer: Make read timeout configurable but disabled by default (#31575) (#32154)
  * GraphNG: Ignore string fields when building data for uPlot in GraphNG (#32150) (#32151)
  * Fix loading timezone info on windows (#32029) (#32149)
  * SQLStore: Close session in withDbSession (#31775) (#32108)
  * Remove datalink template suggestions for accessing specific fields when there are multiple dataframes. (#32057) (#32148)
  * GraphNG: make sure dataset and config are in sync when initializing and re-initializing uPlot (#32106) (#32125)
  * MixedDataSource: Name is updated when data source variable changes (#32090) (#32144)
  * Backport 32005 to v7.5.x #32128 (#32130)
  * Loki: Label browser UI updates (#31737) (#32119)
  * ValueMappings: Fixes value 0 not being mapped (#31924) (#31929)
  * GraphNG: Fix tooltip series color for multi data frame scenario (#32098) (#32103)
  * LibraryPanels: Improves the Get All experience (#32028) (#32093)
  * Grafana/ui: display all selected levels for selected value when searching (#32030) (#32032)
  * Exemplars: always query exemplars (#31673) (#32024)
  * [v7.5.x] TimePicker: Fixes hidden time picker shown in kiosk TV mode (#32055)
  * Chore: Collect elasticsearch version usage stats (#31787) (#32063)
  * Chore: Tidy up Go deps (#32053)
  * GraphNG: Fix PlotLegend field display name being outdated (#32064) (#32066)
  * Data proxy: Fix encoded characters in URL path should be proxied encoded (#30597) (#32060)
  * [v7.5.x] Auth: Allow soft token revocation (#32037)
  * Snapshots: Fix usage of sign in link from the snapshot page (#31986) (#32036)
  * Make master green (#32011) (#32015)
  * Query editor: avoid avoiding word wrap on query editor components (#31949) (#31982)
  * Variables: Fixes filtering in picker with null items (#31979) (#31995)
  * TooltipContainer - use resize observer instead of getClientBoundingRect (#31937) (#32003)
  * Loki: Fix autocomplete when re-editing Loki label values (#31828) (#31987)
  * Loki: Fix type errors in language_provider (#31902) (#31945)
  * PanelInspect: Interpolates variables in CSV file name (#31936) (#31977)
  * Cloudwatch: use shared library for aws auth (#29550) (#31946)
  * Tooltip: partial perf improvement (#31774) (#31837) (#31957)
  * Backport 31913 to v7.5.x (#31955)
  * Grafana/ui: fix searchable options for Cascader with options update (#31906) (#31938)
  * Variables: Do not reset description on variable type change (#31933) (#31939)
  * [v7.5.x] AnnotationList: Adds spacing to UI  (#31888) (#31894)
  * Elasticseach: Support histogram fields (#29079) (#31914)
  * Chore: upgrade eslint and fork-ts-checker-webpack-plugin (#31854) (#31896)
  * Update scripts and Dockerfiles to use Go 1.16.1 (#31881) (#31891)
  * Templating: use dashboard timerange when variables are set to refresh 'On Dashboard Load' (#31721) (#31801)
  * [v7.5.x] Tempo: Add test for backend data source (#31835) (#31882)
  * Run go mod tidy to update go.mod and go.sum (#31859)
  * Grafana/ui: display all selected levels for Cascader (#31729) (#31862)
  * CloudWatch: Consume the grafana/aws-sdk (#31807) (#31861)
  * Cloudwatch: ListMetrics API page limit (#31788) (#31851)
  * Remove invalid attribute (#31848) (#31850)
  * CloudWatch: Restrict auth provider and assume role usage according to… (#31845)
  * CloudWatch: Add support for EC2 IAM role (#31804) (#31841)
  * Loki, Prometheus: Change the placement for query type explanation (#31784) (#31819)
  * Variables: Improves inspection performance and unknown filtering (#31811) (#31813)
  * Change piechart plugin state to beta (#31797) (#31798)
  * ReduceTransform: Include series with numeric string  names (#31763) (#31794)
  * Annotations: Make the annotation clean up batch size configurable (#31487) (#31769)
  * Fix escaping in ANSI and dynamic button removal (#31731) (#31767)
  * DataLinks: Bring back single click links for Stat, Gauge and BarGauge panel (#31692) (#31718)
  * log skipped, performed and duration for migrations (#31722) (#31754)
  * Search: Make items more compact (#31734) (#31750)
  * loki_datasource: add documentation to label_format and line_format (#31710) (#31746)
  * Tempo: Convert tempo to backend data source2 (#31733)
  * Elasticsearch: Fix script fields in query editor (#31681) (#31727)
  * Elasticsearch: revert to isoWeek when resolving weekly indices (#31709) (#31717)
  * Admin: Keeps expired api keys visible in table after delete (#31636) (#31675)
  * Tempo: set authentication header properly (#31699) (#31701)
  * Tempo: convert to backend data source (#31618) (#31695)
  * Update package.json (#31672)
  * Release: Bump version to 7.5.0-beta.1 (#31664)
  * Fix whatsNewUrl version to 7.5 (#31666)
  * Chore: add alias for what's new 7.5 (#31669)
  * Docs: Update doc for PostgreSQL authentication (#31434)
  * Docs: document report template variables (#31637)
  * AzureMonitor: Add deprecation message for App Insights/Insights Analytics (#30633)
  * Color: Fixes issue where colors where reset to gray when switch panels (#31611)
  * Live: Use pure WebSocket transport (#31630)
  * Docs: Fix broken image link (#31661)
  * Docs: Add Whats new in 7.5 (#31659)
  * Docs: Fix links for 7.5 (#31658)
  * Update enterprise-configuration.md (#31656)
  * Explore/Logs: Escaping of incorrectly escaped log lines (#31352)
  * Tracing: Small improvements to trace types (#31646)
  * Update _index.md (#31645)
  * AlertingNG: code refactoring (#30787)
  * Remove pkill gpg-agent (#31169)
  * Remove format for plugin routes (#31633)
  * Library Panels: Change unsaved change detection logic (#31477)
  * CloudWatch: Added AWS Timestream Metrics and Dimensions (#31624)
  * add new metrics and dimensions (#31595)
  * fix devenv dashboard content typo (#31583)
  * DashList: Sort starred and searched dashboard alphabetically (#31605)
  * Docs: Update whats-new-in-v7-4.md (#31612)
  * SSE: Add "Classic Condition" on backend (#31511)
  * InfluxDB: Improve maxDataPoints error-message in Flux-mode, raise limits (#31259)
  * Alerting: PagerDuty: adding current state to the payload (#29270)
  * devenv: Fix typo (#31589)
  * Loki: Label browser (#30351)
  * LibraryPanels: No save modal when user is on same dashboard (#31606)
  * Bug: adding resolution for `react-use-measure` to prevent plugin tests from failing. (#31603)
  * Update node-graph.md (#31571)
  * test: pass Cypress options objects into selector wrappers (#31567)
  * Loki: Add support for alerting (#31424)
  * Tracing: Specify type of the data frame that is expected for TraceView (#31465)
  * LibraryPanels: Adds version column (#31590)
  * PieChart: Add color changing options to pie chart (#31588)
  * Explore: keep enabled/disabled state in angular based QueryEditors correctly (#31558)
  * Bring back correct legend sizing afer PlotLegend refactor (#31582)
  * Alerting: Fix bug in Discord for when name for metric value is absent (#31257)
  * LibraryPanels: Deletes library panels during folder deletion (#31572)
  * chore: bump lodash to 4.17.21 (#31549)
  * Elasticsearch: Fix impossibility to perform non-logs queries after importing queries from loki or prometheus in explore (#31518)
  * TestData: Fixes never ending annotations scenario (#31573)
  * CloudWatch: Added AWS Network Firewall metrics and dimensions (#31498)
  * propagate plugin unavailable message to UI (#31560)
  * ConfirmButton: updates story from knobs to controls (#31476)
  * Loki: Refactor line limit to use grafana/ui component (#31509)
  * LibraryPanels: Adds folder checks and permissions (#31473)
  * Add guide on custom option editors (#31254)
  * PieChart: Update text color and minor changes (#31546)
  * Grafana-data: bump markedjs to v2.x to resolve vulnerability (#31036)
  * Chore(deps): Bump google.golang.org/api from 0.39.0 to 0.40.0 (#31210)
  * PieChart: Improve piechart legend and options (#31446)
  * Chore(deps): Bump google.golang.org/grpc from 1.35.0 to 1.36.0 (#31541)
  * Chore(deps): Bump github.com/aws/aws-sdk-go from 1.37.7 to 1.37.20 (#31538)
  * Chore(deps): Bump github.com/prometheus/common from 0.17.0 to 0.18.0 (#31539)
  * Add multiselect options ui (#31501)
  * Profile: Fixes profile preferences being accessible when anonymous access was enabled (#31516)
  * Variables: Fixes error with: cannot read property length of undefined (#31458)
  * Explore: Show ANSI colored logs in logs context (#31510)
  * LogsPanel: Show all received logs  (#31505)
  * AddPanel: Design polish  (#31484)
  * TimeSeriesPanel: Remove unnecessary margin from legend  (#31467)
  * influxdb: flux: handle is-hidden (#31324)
  * Graph: Fix tooltip not showing when close to the edge of viewport  (#31493)
  * FolderPicker: Remove useNewForms from FolderPicker (#31485)
  * Add reportVariables feature toggle (#31469)
  * Grafana datasource: support multiple targets (#31495)
  * Update license-restrictions.md (#31488)
  * Docs: Derived fields links in logs detail view (#31482)
  * Docs: Add new data source links to Enterprise page (#31480)
  * Convert annotations to dataframes (#31400)
  * ReleaseNotes: Updated changelog and release notes for v7.4.2 (#31475)
  * GrafanaUI: Fixes typescript error for missing css prop (#31479)
  * Login: handle custom token creation error messages (#31283)
  * Library Panels: Don't list current panel in available panels list (#31472)
  * DashboardSettings: Migrate Link Settings to React (#31150)
  * Frontend changes for library panels feature (#30653)
  * Alerting notifier SensuGo: improvements in default message (#31428)
  * AppPlugins: Options to disable showing config page in nav (#31354)
  * add aws config (#31464)
  * Heatmap: Fix missing/wrong value in heatmap legend (#31430)
  * Chore: Fixes small typos (#31461)
  * Graphite/SSE: update graphite to work with server side expressions (#31455)
  * update the lastest version to 7.4.3 (#31457)
  * ReleaseNotes: Updated changelog and release notes for 7.4.3 (#31454)
  * AWS: Add aws plugin configuration (#31312)
  * Revert ""Release: Updated versions in package to 7.4.3" (#31444)" (#31452)
  * Remove UserSyncInfo.tsx (#31450)
  * Elasticsearch: Add word highlighting to search results (#30293)
  * Chore: Fix eslint react hook warnings in grafana-ui (#31092)
  * CloudWatch: Make it possible to specify custom api endpoint (#31402)
  * Chore: fixed incorrect naming for disable settings (#31448)
  * TraceViewer: Fix show log marker in spanbar (#30742)
  * LibraryPanels: Adds permissions to getAllHandler (#31416)
  * NamedColorsPalette: updates story from knobs to controls (#31443)
  * "Release: Updated versions in package to 7.4.3" (#31444)
  * ColorPicker: updates story from knobs to controls (#31429)
  * Streaming: Fixes an issue with time series panel and streaming data source when scrolling back from being out of view (#31431)
  * ClipboardButton: updates story from knobs to controls (#31422)
  * we should never log unhashed tokens (#31432)
  * CI: Upgrade Dockerfiles wrt. Go, Node, Debian (#31407)
  * Elasticsearch: Fix query initialization logic & query transformation from Promethous/Loki (#31322)
  * Postgres: allow providing TLS/SSL certificates as text in addition to file paths (#30353)
  * CloudWatch: Added AWS Ground Station metrics and dimensions (#31362)
  * TraceViewer: Fix trace to logs icon to show in right pane (#31414)
  * add hg team as migrations code owners (#31420)
  * Remove tidy-check script (#31423)
  * InfluxDB: handle columns named "table" (#30985)
  * Prometheus: Use configured HTTP method for /series and /labels endpoints (#31401)
  * Devenv: Add gdev-influxdb2 data source (#31250)
  * Update grabpl from 0.5.38 to 0.5.42 version (#31419)
  * Move NOOP_CONTROL to storybook utils and change to a standalone file (#31421)
  * remove squadcast details from docs (#31413)
  * Add new Cloudwatch AWS/DDoSProtection metrics and dimensions (#31297)
  * Logging: add frontend logging helpers to @grafana/runtime package (#30482)
  * CallToActionCard: updates story from knobs to controls (#31393)
  * Add eu-south-1 cloudwatch region, closes #31197 (#31198)
  * Chore: Upgrade eslint packages (#31408)
  * Cascader: updates story from knobs to controls (#31399)
  * addressed issues 28763 and 30314. (#31404)
  * Added section Query a time series database by id (#31337)
  * Prometheus: Change default httpMethod for new instances to POST (#31292)
  * Data source list: Use Card component (#31326)
  * Chore: Remove gotest.tools dependency (#31391)
  * Revert "StoryBook: Introduces Grafana Controls (#31351)" (#31388)
  * Chore(deps): Bump github.com/prometheus/common from 0.15.0 to 0.17.0 (#31387)
  * AdHocVariables: Fixes crash when values are stored as numbers (#31382)
  * Chore(deps): Bump github.com/golang/mock from 1.4.4 to 1.5.0 (#31379)
  * Chore: Fix strict errors, down to 416 (#31365)
  * Chore(deps): Bump github.com/getsentry/sentry-go from 0.9.0 to 0.10.0 (#31378)
  * StoryBook: Introduces Grafana Controls (#31351)
  * ReleaseNotes: Updated changelog and release notes for 7.4.2 (#31313)
  * Theming: Support for runtime theme switching and hooks for custom themes (#31301)
  * Devenv: Remove old-versioned loki blocks and update prometheus2 block  (#31282)
  * Zipkin: Show success on test data source (#30829)
  * Update grot template (needs more info) (#31350)
  * DatasourceSrv: Fix instance retrieval when datasource variable value set to "default" (#31347)
  * TimeSeriesPanel: Fixes overlapping time axis ticks (#31332)
  * Grafana/UI: Add basic legend to the PieChart (#31278)
  * SAML: single logout only enabled in enterprise (#31325)
  * QueryEditor: handle query.hide changes in angular based query-editors (#31336)
  * DashboardLinks: Fixes another issue where dashboard links cause full page reload (#31334)
  * LibraryPanels: Syncs panel title with name (#31311)
  * Chore: Upgrade golangci-lint (#31330)
  * Add info to docs about concurrent session limits (#31333)
  * Table: Fixes issue with fixed min and auto max with bar gauge cell (#31316)
  * BarGuage: updates story from knobs to controls (#31223)
  * Docs: Clarifies how to add Key/Value pairs (#31303)
  * Usagestats: Exclude folders from total dashboard count (#31320)
  * ButtonCascader: updates story from knobs to controls (#31288)
  * test: allow check for Table as well as Graph for Explore e2e flow (#31290)
  * Grafana-UI: Update tooltip type (#31310)
  * fix 7.4.2 release note (#31299)
  * Add `--tries 3` arg when triggering e2e-tests upon releasing (#31285)
  * Chore: reduce strict errors for variables (#31241)
  * update latest release version (#31296)
  * ReleaseNotes: Updated changelog and release notes for 7.4.2 (#31291)
  * Correct name of Discord notifier tests (#31277)
  * Docs: Clarifies custom date formats for variables (#31271)
  * BigValue: updates story from knobs to controls (#31240)
  * Docs: Annotations update (#31194)
  * Introduce functions for interacting with library panels API (#30993)
  * Search: display sort metadata (#31167)
  * Folders: Editors should be able to edit name and delete folders (#31242)
  * Make Datetime local (No date if today) working (#31274)
  * UsageStats: Purpose named variables (#31264)
  * Snapshots: Disallow anonymous user to create snapshots (#31263)
  * only update usagestats every 30min (#31131)
  * Chore: grafana-toolkit uses grafana-ui and grafana-data workspaces (#30701)
  * Grafana-UI: Add id to Select to make it easier to test (#31230)
  * Prometheus: Fix enabling of disabled queries when editing in dashboard (#31055)
  * UI/Card: Fix handling of 'onClick' callback (#31225)
  * Loki: Add line limit for annotations (#31183)
  * Remove deprecated and breaking loki config field (#31227)
  * SqlDataSources: Fixes the Show Generated SQL button in query editors (#31236)
  * LibraryPanels: Disconnect before connect during dashboard save (#31235)
  * Disable Change Password for OAuth users (#27886)
  * TagsInput: Design update and component refactor (#31163)
  * Variables: Adds back default option for data source variable (#31208)
  * IPv6: Support host address configured with enclosing square brackets (#31226)
  * Postgres: Fix timeGroup macro converts long intervals to invalid numbers when TimescaleDB is enabled (#31179)
  * GraphNG: refactor core to class component (#30941)
  * Remove last synchronisation field from LDAP debug view (#30984)
  * Chore: Upgrade grafana-plugin-sdk-go to v0.88.0 (#30975)
  * Graph: Make axes unit option work even when field option unit is set (#31205)
  * AlertingNG:  Test definition  (#30886)
  * Docs: Update Influx config options (#31146)
  * WIP: Skip this call when we skip migrations (#31216)
  * use 0.1.0 (#31215)
  * DataSourceSrv: Filter out non queryable data sources by default (#31144)
  * QueryEditors: Fixes issue that happens after moving queries then editing would update other queries (#31193)
  * Chore: report eslint no-explicit-any errors to metrics (#31182)
  * Chore(deps): Bump cloud.google.com/go/storage from 1.12.0 to 1.13.0 (#31211)
  * Chore(deps): Bump xorm.io/xorm from 0.8.1 to 0.8.2 (#30773)
  * Alerting: Fix modal text for deleting obsolete notifier (#31171)
  * Chore(deps): Bump github.com/linkedin/goavro/v2 from 2.9.7 to 2.10.0 (#31204)
  * Variables: Fixes missing empty elements from regex filters (#31156)
  * StatPanels: Fixes to palette color scheme is not cleared when loading panel (#31126)
  * Fixed the typo. (#31189)
  * Docs: Rewrite preferences docs (#31154)
  * Explore/Refactor: Simplify URL handling (#29173)
  * DashboardLinks: Fixes links always cause full page reload (#31178)
  * Replace PR with Commit truncated hash when build fails (#31177)
  * Alert: update story to use controls (#31145)
  * Permissions: Fix team and role permissions on folders/dashboards not displayed for non Grafana Admin users (#31132)
  * CloudWatch: Ensure empty query row errors are not passed to the panel (#31172)
  * Update prometheus.md (#31173)
  * Variables: Extend option pickers to accept custom onChange callback (#30913)
  * Prometheus: Multiply exemplars timestamp to follow api change (#31143)
  * DashboardListPanel: Fixes issue with folder picker always showing All and using old form styles (#31160)
  * Add author name and pr number in drone pipeline notifications (#31124)
  * Prometheus: Add documentation for ad-hoc filters (#31122)
  * DataSourceSettings: Fixes add header button, it should not trigger a save & test action (#31135)
  * Alerting: Fix so that sending an alert with the Alertmanager notifier doesn't fail when one of multiple configured URL's are down (#31079)
  * Chore: Update latest.json (#31139)
  * Docs: add 7.4.1 relese notes link (#31137)
  * PieChart: Progress on new core pie chart  (#28020)
  * ReleaseNotes: Updated changelog and release notes for 7.4.1 (#31133)
  * Eslint: no-duplicate-imports rule (bump grafana-eslint-config) (#30989)
  * Transforms: Fixes Outer join issue with duplicate field names not getting the same unique field names as before  (#31121)
  * MuxWriter: Handle error for already closed file (#31119)
  * Logging: sourcemap transform asset urls from CDN in logged stacktraces (#31115)
  * Search: add sort information in dashboard results (#30609)
  * area/grafana/e2e: ginstall should pull version specified (#31056)
  * Exemplars: Change CTA style (#30880)
  * Influx: Make max series limit configurable and show the limiting message if applied (#31025)
  * Docs: request security (#30937)
  * update configurePanel for 7.4.0 changes (#31093)
  * Elasticsearch: fix log row context erroring out (#31088)
  * Prometheus: Fix issues with ad-hoc filters (#30931)
  * LogsPanel: Add deduplication option for logs (#31019)
  * Drone: Make sure CDN upload is ok before pushing docker images (#31075)
  * PluginManager: Remove some global state (#31081)
  * test: update addDashboard flow for v7.4.0 changes (#31059)
  * Transformations: Fixed typo in FilterByValue transformer description. (#31078)
  * Docs: Group id should be 0 instead of 1 in Docker upgrade notes (#31074)
  * Usage stats: Adds source/distributor setting (#31039)
  * CDN: Add CDN upload step to enterprise and release pipelines (#31058)
  * Chore: Replace native select with grafana ui select  (#31030)
  * Docs: Update json-model.md (#31066)
  * Docs: Update whats-new-in-v7-4.md (#31069)
  * Added hyperlinks to Graphite documentation (#31064)
  * DashboardSettings: Update to new form styles (#31022)
  * CDN: Fixing drone CI config (#31052)
  * convert path to posix by default (#31045)
  * DashboardLinks: Fixes crash when link has no title (#31008)
  * Alerting: Fixes so notification channels are properly deleted (#31040)
  * Explore: Remove emotion error when displaying logs (#31026)
  * Elasticsearch: Fix alias field value not being shown in query editor (#30992)
  * CDN: Adds uppload to CDN step to drone CI (#30879)
  * Improved glossary (#31004)
  * BarGauge: Improvements to value sizing and table inner width calculations  (#30990)
  * Drone: Fix deployment image (#31027)
  * ColorPicker: migrated styles from sass to emotion (#30909)
  * Dashboard: Migrate general settings to react (#30914)
  * Chore(deps): Bump github.com/jung-kurt/gofpdf from 1.10.1 to 1.16.2 (#30586)
  * Chore(deps): Bump github.com/aws/aws-sdk-go from 1.36.31 to 1.37.7 (#31018)
  * Prometheus: Min step defaults to seconds when no unit is set to prevent errors when running alerts. (#30966)
  * Chore(deps): Bump github.com/magefile/mage from 1.10.0 to 1.11.0 (#31017)
  * Chore(deps): Bump github.com/grpc-ecosystem/go-grpc-middleware (#31013)
  * Graph: Fixes so graph is shown for non numeric time values (#30972)
  * CloudMonitoring: Prevent resource type variable function from crashing (#30901)
  * Chore(deps): Bump google.golang.org/api from 0.33.0 to 0.39.0 (#30971)
  * Build: Releases e2e and e2e-selectors too (#31006)
  * TextPanel: Fixes so panel title is updated when variables change (#30884)
  * Docs: Update configuration.md (login_maximum_inactive_lifetime_duration, login_maximum_lifetime_duration) (#31000)
  * instrumentation: make the first database histogram bucket smaller (#30995)
  * Grafana/UI: Remove DismissableFeatureInfoBox and replace with LocalSt… (#30988)
  * StatPanel: Fixes issue formatting date values using unit option (#30979)
  * Chore(deps): Bump actions/cache from v2 to v2.1.4 (#30973)
  * Units: Fixes formatting of duration units (#30982)
  * Elasticsearch: Show Size setting for raw_data metric (#30980)
  * Alerts: Dedupe alerts so that we do not fill the screen with the same alert messsage (#30935)
  * make sure service and slo display name is passed to segment comp (#30900)
  * assign changes in cloud datasources to the new cloud datasources team (#30645)
  * Table: Updates devenv test dashboard after change to TestData Randrom Table response (#30927)
  * Theme: Use higher order theme color variables rather then is light/dark logic (#30939)
  * Docs: Add alias for what's new in 7.4 (#30945)
  * e2e: extends selector factory to plugins (#30932)
  * Chore: Upgrade docker build image (#30820)
  * Docs: updated developer guide (#29978)
  * Alerts: Update Alert storybook to show more states (#30908)
  * Variables: Adds queryparam formatting option (#30858)
  * Chore: pad unknown values with undefined (#30808)
  * Transformers: add search to transform selection (#30854)
  * Exemplars: change api to reflect latest changes (#30910)
  * docs: use selinux relabelling on docker containers (#27685)
  * Docs: Fix bad image path for alert notification template (#30911)
  * Make value mappings correctly interpret numeric-like strings (#30893)
  * Chore: Update latest.json (#30905)
  * Docs: Update whats-new-in-v7-4.md (#30882)
  * Dashboard: Ignore changes to dashboard when the user session expires (#30897)
  * ReleaseNotes: Updated changelog and release notes for 7.4.0 (#30902)
  * test: add support for timeout to be passed in for addDatasource (#30736)
  * increase page size and make sure the cache supports query params (#30892)
  * DataSourceSettings: Adds info box and link to Grafana Cloud (#30891)
  * OAuth: custom username docs (#28400)
  * Panels: Remove value mapping of values that have been formatted #26763 (#30868)
  * Alerting: Fixes alert panel header icon not showing (#30840)
  * AlertingNG: Edit Alert Definition (#30676)
  * Logging: sourcemap support for frontend stacktraces (#30590)
  * Added "Restart Grafana" topic. (#30844)
  * Docs: Org, Team, and User Admin (#30756)
  * bump grabpl version to 0.5.36 (#30874)
  * Plugins: Requests validator (#30445)
  * Docs: Update whats-new-in-v7-4.md (#30876)
  * Docs: Add server view folder (#30849)
  * Fixed image name and path  (#30871)
  * Grafana-ui: fixes closing modals with escape key (#30745)
  * InfluxDB: Add http configuration when selecting InfluxDB v2 flavor  (#30827)
  * TestData: Fixes issue with for ever loading state when all queries are hidden (#30861)
  * Chart/Tooltip: refactored style declaration (#30824)
  * ReleaseNotes: Updated changelog and release notes for 7.4.0-beta1 (#30853)
  * Grafana-ui: fixes no data message in Table component (#30821)
  * grafana/ui: Update pagination component for large number of pages (#30151)
  * Alerting: Customise OK notification priorities for Pushover notifier (#30169)
  * DashboardLinks: Support variable expression in to tooltip - Issue #30409 (#30569)
  * Chore: Remove panelTime.html, closes #30097 (#30842)
  * Docs: Time series panel, bar alignment docs (#30780)
  * Chore: add more docs annotations (#30847)
  * Transforms: allow boolean in field calculations (#30802)
  * Prometheus: Add tooltip to explain possibility to use patterns in text and title fields in annotations (#30825)
  * Update prometheus.md with image link fix (#30833)
  * BarChart: inside-align strokes, upgrade uPlot to 1.6.4. (#30806)
  * Update license-expiration.md (#30839)
  * Explore rewrite (#30804)
  * Prometheus: Set type of labels to string (#30831)
  * GrafanaUI: Add a way to persistently close InfoBox (#30716)
  * Fix typo in transformer registry (#30712)
  * Elasticsearch: Display errors with text responses (#30122)
  * CDN: Fixes cdn path when Grafana is under sub path (#30822)
  * TraceViewer: Fix lazy loading (#30700)
  * FormField: migrated sass styling to emotion (#30392)
  * AlertingNG: change API permissions (#30781)
  * Variables: Clears drop down state when leaving dashboard (#30810)
  * Grafana-UI: Add story/docs for ErrorBoundary (#30304)
  * Add missing callback dependency (#30797)
  * PanelLibrary: Adds library panel meta information to dashboard json (#30770)
  * Chore(deps): Bump gonum.org/v1/gonum from 0.6.0 to 0.8.2 (#30343)
  * Chore(deps): Bump gopkg.in/yaml.v2 from 2.3.0 to 2.4.0 (#30771)
  * GraphNG: improve behavior when switching between solid/dash/dots (#30796)
  * Chore(deps): Bump github.com/hashicorp/go-hclog from 0.14.1 to 0.15.0 (#30778)
  * Add width for Variable Editors (#30791)
  * Chore: Remove warning when calling resource (#30752)
  * Auth: Use SigV4 lib from grafana-aws-sdk  (#30713)
  * Panels: Fixes so panels are refreshed when scrolling past them fast (#30784)
  * GraphNG: add bar alignment option (#30499)
  * Expressions: Measure total transformation requests and elapsed time (#30514)
  * Menu: Mark menu components as internal (#30740)
  * TableInputCSV: migrated styles from sass to emotion (#30554)
  * CDN: Fix passing correct prefix to GetContentDeliveryURL (#30777)
  * Chore(deps): Bump gopkg.in/ini.v1 from 1.57.0 to 1.62.0 (#30772)
  * CDN: Adds support for serving assets over a CDN (#30691)
  * PanelEdit: Trigger refresh when changing data source (#30744)
  * Chore: remove __debug_bin (#30725)
  * BarChart: add alpha bar chart panel (#30323)
  * Docs: Time series panel (#30690)
  * Backend Plugins: Convert test data source to use SDK contracts (#29916)
  * Docs: Update whats-new-in-v7-4.md (#30747)
  * Add link to Elasticsearch docs. (#30748)
  * Mobile: Fixes issue scrolling on mobile in chrome (#30746)
  * TagsInput: Make placeholder configurable (#30718)
  * Docs: Add config settings for fonts in reporting (#30421)
  * Add menu.yaml to .gitignore (#30743)
  * bump cypress to 6.3.0 (#30644)
  * Datasource: Use json-iterator configuration compatible with standard library (#30732)
  * AlertingNG: Update UX to use new PageToolbar component (#30680)
  * Docs: Add usage insights export feature (#30376)
  * skip symlinks to directories when generating plugin manifest (#30721)
  * PluginCiE2E: Upgrade base images (#30696)
  * Variables: Fixes so text format will show All instead of custom all (#30730)
  * PanelLibrary: better handling of deleted panels (#30709)
  * Added section "Curated dashboards for Google Cloud Monitoring" for 7.4 What's New (#30724)
  * Added "curated dashboards" information and broke down, rearranged topics. (#30659)
  * Transform: improve the "outer join" performance/behavior (#30407)
  * Add alt text to plugin logos (#30710)
  * Deleted menu.yaml file (#30717)
  * Dashboard: Top Share URL icon should share panel URL when on viewPanel page (#30000)
  * Added entry for web server. (#30715)
  * DashboardPicker: switch to promise-based debounce, return dashboard UID (#30706)
  * Use connected GraphNG in Explore (#30707)
  * Fix documentation for streaming data sources (#30704)
  * PanelLibrary: changes casing of responses and adds meta property (#30668)
  * Influx: Show all datapoints for dynamically windowed flux query (#30688)
  * Trace: trace to logs design update (#30637)
  * DeployImage: Switch base images to Debian (#30684)
  * Chore: remove CSP debug logging line (#30689)
  * Docs: 7.4 documentation for expressions (#30524)
  * PanelEdit: Get rid of last remaining usage of navbar-button (#30682)
  * Grafana-UI: Fix setting default value for MultiSelect (#30671)
  * CustomScrollbar: migrated styles from sass to emotion (#30506)
  * DashboardSettings & PanelEdit: Use new PageToolbar (#30675)
  * Explore: Fix jumpy live tailing (#30650)
  * ci(npm-publish): add missing github package token to env vars (#30665)
  * PageToolbar: Extracting navbar styles & layout into a modern emotion based component (#30588)
  * AlertingNG: pause/unpause definitions via the API (#30627)
  * Docs: Refer to product docs in whats new for alerting templating feature (#30652)
  * ReleaseNotes: Updated changelog and release notes for 7.4.0-beta1 (#30666)
  * Variables: Fixes display value when using capture groups in regex (#30636)
  * Docs: Update _index.md (#30655)
  * Docs: Auditing updates (#30433)
  * Docs: add hidden_users configuration field (#30435)
  * Docs: Define TLS/SSL terminology (#30533)
  * Docs: Fix expressions enabled description (#30589)
  * Docs: Update ES screenshots (#30598)
  * Licensing Docs: Adding license restrictions docs (#30216)
  * Update documentation-style-guide.md (#30611)
  * Docs: Update queries.md (#30616)
  * chore(grafana-ui): bump storybook to 6.1.15 (#30642)
  * DashboardSettings: fixes vertical scrolling (#30640)
  * Usage Stats: Remove unused method for getting user stats (#30074)
  * Grafana/UI: Unit picker should not set a category as unit (#30638)
  * Graph: Fixes auto decimals issue in legend and tooltip (#30628)
  * AlertingNG: List saved Alert definitions in Alert Rule list (#30603)
  * chore: bump redux toolkit to 1.5.0 for immer 8.0.1 vulnerability fix (#30605)
  * Grafana/UI: Add disable prop to Segment (#30539)
  * Variables: Fixes so queries work for numbers values too (#30602)
  * Admin: Fixes so form values are filled in from backend (#30544)
  * Docs: Add new override info and add whats new 7.4 links (#30615)
  * TestData: Improve what's new in v7.4 (#30612)
  * Docs: Update 7.4 What's New to use more correct description of alerting notification template feature (#30502)
  * NodeGraph: Add docs (#30504)
  * Loki: Improve live tailing errors and fix Explore's logs container type errors (#30517)
  * TimeRangePicker: Updates components to use new ToolbarButton & ButtonGroup (#30570)
  * Update styling.md guide (#30594)
  * TestData: Adding what's new in v7.4 to the devenv dashboards (#30568)
  * Chore(deps): Bump github.com/aws/aws-sdk-go from 1.35.5 to 1.36.31 (#30583)
  * Chore(deps): Bump github.com/prometheus/client_golang (#30585)
  * Chore(deps): Bump gopkg.in/macaron.v1 from 1.3.9 to 1.4.0 (#30587)
  * Chore(deps): Bump github.com/google/uuid from 1.1.5 to 1.2.0 (#30584)
  * Explore: Fix logs hover state so that it is visible and in dark mode & simply hover code (#30572)
  * RefreshPicker: Fixes so valid intervals in url are visible in RefreshPicker (#30474)
  * Add documentation for Exemplars (#30317)
  * OldGraph: Fix height issue in Firefox (#30565)
  * XY Chart: fix editor error with empty frame (no fields) (#30573)
  * ButtonSelect & RefreshPicker: Rewrite of components to use new emotion based ToolbarButton & Menu (#30510)
  * XY Chart: share legend config with timeseries (#30559)
  * configuration.md: Document Content Security Policy options (#30413)
  * DataFrame: cache frame/field index in field state (#30529)
  * List + before -; rm old Git ref; reformat. (#30543)
  * Expressions: Add option to disable feature (#30541)
  * Explore: Fix loading visualisation on the top of the new time series panel (#30553)
  * Prometheus: Fix show query instead of Value if no __name__ and metric (#30511)
  * Decimals: Big Improvements to auto decimals and fixes to auto decimals bug found in 7.4-beta1  (#30519)
  * Postgres: Convert tests to stdlib (#30536)
  * Storybook: Migrate card story to use controls  (#30535)
  * AlertingNG: Enable UI to Save Alert Definitions (#30394)
  * Postgres: Be consistent about TLS/SSL terminology (#30532)
  * Loki: Append refId to logs uid (#30418)
  * Postgres: Fix indentation (#30531)
  * GraphNG: uPlot 1.6.3 (fix bands not filling below 0). close #30523. (#30527)
  * updates for e2e docker image (#30465)
  * GraphNG: uPlot 1.6.2 (#30521)
  * Docs: Update whats-new-in-v7-4.md (#30520)
  * Prettier: ignore build and devenv dirs (#30501)
  * Chore: Upgrade grabpl version (#30486)
  * Explore: Update styling of buttons (#30493)
  * Cloud Monitoring: Fix legend naming with display name override (#30440)
  * GraphNG: Disable Plot logging by default (#30390)
  * Admin: Fixes so whole org drop down is visible when adding users to org (#30481)
  * Docs: include Makefile option for local assets (#30455)
  * Footer: Fixes layout issue in footer  (#30443)
  * TimeSeriesPanel: Fixed default value for gradientMode (#30484)
  * Docs: fix typo in what's new doc (#30489)
  * Chore: adds wait to e2e test (#30488)
  * chore: update packages dependent on dot-prop to fix security vulnerability (#30432)
  * Dashboard: Remove Icon and change copy -> Copy to clipboard in the share embedded panel modal (#30480)
  * Chore: fix spelling mistake (#30473)
  * Chore: Restrict internal imports from other packages (#30453)
  * Docs: What's new fixes and improvements (#30469)
  * Timeseries: only migrage point size when configured (#30461)
  * Alerting: Hides threshold handle for percentual thresholds (#30431)
  * Graph: Fixes so only users with correct permissions can add annotations (#30419)
  * Chore: update latest version to 7.4.0-beta1 (#30452)
  * Docs: Add whats new 7.4 links (#30463)
  * Update whats-new-in-v7-4.md (#30460)
  * docs: 7.4 what's new (Add expressions note) (#30446)
  * Chore: Upgrade build pipeline tool (#30456)
  * PanelModel: Make sure the angular options are passed to react panel type changed handler (#30441)
  * Expressions: Fix button icon (#30444)
  * ReleaseNotes: Updated changelog and release notes for 7.4.0-beta1 (#30449)
  * Docs: Fix img link for alert notification template (#30436)
  * grafana/ui: Fix internal import from grafana/data (#30439)
  * prevent field config from being overwritten (#30437)
  * PanelOptions: Refactoring applying panel and field options out of PanelModel and add property clean up for properties not in field config registry  (#30389)
  * Dashboard: Remove template variables option from ShareModal (#30395)
  * Added doc content for variables inspector code change by Hugo (#30408)
  * Docs: update license expiration behavior for reporting (#30420)
  * Chore: use old version format in package.json (#30430)
  * Chore: upgrade NPM security vulnerabilities (#30397)
  * "Release: Updated versions in package to 7.5.0-pre.0" (#30428)
  * contribute: Add backend and configuration guidelines for PRs (#30426)
  * Chore: Update what's new URL (#30424)
- Update to version 7.4.5
  * Security: Fix API permissions issues related to team-sync CVE-2021-28146, CVE-2021-28147. (Enterprise)
  * Security: Usage insights requires signed in users CVE-2021-28148. (Enterprise)
  * Security: Do not allow editors to incorrectly bypass permissions on the default data source. CVE-2021-27962. (Enterprise)
- Drop patch add-gotest-module.patch
- Add patch drop-grafana-aws-sdk-0.3.0-module.patch
* Mon Feb 22 2021 tserong@suse.com
- Update to version 7.4.2:
  * Make Datetime local (No date if today) working (#31274) (#31275)
  * "Release: Updated versions in package to 7.4.2" (#31272)
  * [v7.4.x] Chore: grafana-toolkit uses grafana-ui and grafana-data workspaces (#31269)
  * Snapshots: Disallow anonymous user to create snapshots (#31263) (#31266)
  * only update usagestats every 30min (#31131) (#31262)
  * Prometheus: Fix enabling of disabled queries when editing in dashboard (#31055) (#31248)
  * CloudWatch: Ensure empty query row errors are not passed to the panel (#31172) (#31245)
  * StatPanels: Fixes to palette color scheme is not cleared when loading panel (#31126) (#31246)
  * QueryEditors: Fixes issue that happens after moving queries then editing would update other queries (#31193) (#31244)
  * LibraryPanels: Disconnect before connect during dashboard save (#31235) (#31238)
  * SqlDataSources: Fixes the Show Generated SQL button in query editors (#31236) (#31239)
  * Variables: Adds back default option for data source variable (#31208) (#31232)
  * IPv6: Support host address configured with enclosing square brackets (#31226) (#31228)
  * Postgres: Fix timeGroup macro converts long intervals to invalid numbers when TimescaleDB is enabled (#31179) (#31224)
  * Remove last synchronisation field from LDAP debug view (#30984) (#31221)
  * [v7.4.x]: Sync drone config from master to stable release branch (#31213)
  * DataSourceSrv: Filter out non queryable data sources by default (#31144) (#31214)
  * Alerting: Fix modal text for deleting obsolete notifier (#31171) (#31209)
  * Variables: Fixes missing empty elements from regex filters (#31156) (#31201)
  * DashboardLinks: Fixes links always cause full page reload (#31178) (#31181)
  * DashboardListPanel: Fixes issue with folder picker always showing All and using old form styles (#31160) (#31162)
  * Permissions: Fix team and role permissions on folders/dashboards not displayed for non Grafana Admin users (#31132) (#31176)
  * Prometheus: Multiply exemplars timestamp to follow api change (#31143) (#31170)
- Added add-gotest-module.patch to fix "inconsistent vendoring" build failure
* Wed Feb 17 2021 tserong@suse.com
- Update to version 7.4.1:
  * "Release: Updated versions in package to 7.4.1" (#31128)
  * Transforms: Fixes Outer join issue with duplicate field names not getting the same unique field names as before  (#31121) (#31127)
  * MuxWriter: Handle error for already closed file (#31119) (#31120)
  * Logging: sourcemap transform asset urls from CDN in logged stacktraces (#31115) (#31117)
  * Exemplars: Change CTA style (#30880) (#31105)
  * test: add support for timeout to be passed in for addDatasource (#30736) (#31090)
  * Influx: Make max series limit configurable and show the limiting message if applied (#31025) (#31100)
  * Elasticsearch: fix log row context erroring out (#31088) (#31094)
  * test: update addDashboard flow for v7.4.0 changes (#31059) (#31084)
  * Usage stats: Adds source/distributor setting (#31039) (#31076)
  * DashboardLinks: Fixes crash when link has no title (#31008) (#31050)
  * Make value mappings correctly interpret numeric-like strings (#30893) (#30912)
  * Elasticsearch: Fix alias field value not being shown in query editor (#30992) (#31037)
  * BarGauge: Improvements to value sizing and table inner width calculations  (#30990) (#31032)
  * convert path to posix by default (#31045) (#31053)
  * Alerting: Fixes so notification channels are properly deleted (#31040) (#31046)
  * Drone: Fix deployment image (#31027) (#31029)
  * Graph: Fixes so graph is shown for non numeric time values (#30972) (#31014)
  * instrumentation: make the first database histogram bucket smaller (#30995) (#31001)
  * Build: Releases e2e and e2e-selectors too (#31006) (#31007)
  * TextPanel: Fixes so panel title is updated when variables change (#30884) (#31005)
  * StatPanel: Fixes issue formatting date values using unit option (#30979) (#30991)
  * Units: Fixes formatting of duration units (#30982) (#30986)
  * Elasticsearch: Show Size setting for raw_data metric (#30980) (#30983)
  * Logging: sourcemap support for frontend stacktraces (#30590) (#30976)
  * e2e: extends selector factory to plugins (#30932) (#30934)
  * Variables: Adds queryparam formatting option (#30858) (#30924)
  * Exemplars: change api to reflect latest changes (#30910) (#30915)
  * "Release: Updated versions in package to 7.4.0" (#30898)
  * DataSourceSettings: Adds info box and link to Grafana Cloud (#30891) (#30896)
  * GrafanaUI: Add a way to persistently close InfoBox (#30716) (#30895)
  * [7.4.x] AlertingNG: List saved Alert definitions in Alert Rule list (30890)(30603)
  * Alerting: Fixes alert panel header icon not showing (#30840) (#30885)
  * Plugins: Requests validator (#30445) (#30877)
  * PanelLibrary: Adds library panel meta information to dashboard json (#30770) (#30883)
  * bump grabpl version to 0.5.36 (#30874) (#30878)
  * Chore: remove __debug_bin (#30725) (#30857)
  * Grafana-ui: fixes closing modals with escape key (#30745) (#30873)
  * DashboardLinks: Support variable expression in to tooltip - Issue #30409 (#30569) (#30852)
  * Add alt text to plugin logos (#30710) (#30872)
  * InfluxDB: Add http configuration when selecting InfluxDB v2 flavor  (#30827) (#30870)
  * Prometheus: Set type of labels to string (#30831) (#30835)
  * AlertingNG: change API permissions (#30781) (#30814)
  * Grafana-ui: fixes no data message in Table component (#30821) (#30855)
  * Prometheus: Add tooltip to explain possibility to use patterns in text and title fields in annotations (#30825) (#30843)
  * Chore: add more docs annotations (#30847) (#30851)
  * BarChart: inside-align strokes, upgrade uPlot to 1.6.4. (#30806) (#30846)
  * Transforms: allow boolean in field calculations (#30802) (#30845)
  * CDN: Fixes cdn path when Grafana is under sub path (#30822) (#30823)
  * bump cypress to 6.3.0 (#30644) (#30819)
  * Expressions: Measure total transformation requests and elapsed time (#30514) (#30789)
  * Grafana-UI: Add story/docs for ErrorBoundary (#30304) (#30811)
  * [v7.4.x]: Menu: Mark menu components as internal (#30801)
  * Graph: Fixes auto decimals issue in legend and tooltip (#30628) (#30635)
  * GraphNG: Disable Plot logging by default (#30390) (#30500)
  * Storybook: Migrate card story to use controls  (#30535) (#30549)
  * GraphNG: add bar alignment option (#30499) (#30790)
  * Variables: Clears drop down state when leaving dashboard (#30810) (#30812)
  * Add missing callback dependency (#30797) (#30809)
  * GraphNG: improve behavior when switching between solid/dash/dots (#30796) (#30799)
  * Add width for Variable Editors (#30791) (#30795)
  * Panels: Fixes so panels are refreshed when scrolling past them fast (#30784) (#30792)
  * PanelEdit: Trigger refresh when changing data source (#30744) (#30767)
  * AlertingNG: Enable UI to Save Alert Definitions (#30394) (#30548)
  * CDN: Fix passing correct prefix to GetContentDeliveryURL (#30777) (#30779)
  * CDN: Adds support for serving assets over a CDN (#30691) (#30776)
  * Explore: Update styling of buttons (#30493) (#30508)
  * Loki: Append refId to logs uid (#30418) (#30537)
  * skip symlinks to directories when generating plugin manifest (#30721) (#30738)
  * Mobile: Fixes issue scrolling on mobile in chrome (#30746) (#30750)
  * BarChart: add alpha bar chart panel (#30323) (#30754)
  * Datasource: Use json-iterator configuration compatible with standard library (#30732) (#30739)
  * Variables: Fixes so text format will show All instead of custom all (#30730) (#30731)
  * AlertingNG: pause/unpause definitions via the API (#30627) (#30672)
  * PanelLibrary: better handling of deleted panels (#30709) (#30726)
  * Transform: improve the "outer join" performance/behavior (#30407) (#30722)
  * DashboardPicker: switch to promise-based debounce, return dashboard UID (#30706) (#30714)
  * Use connected GraphNG in Explore (#30707) (#30708)
  * PanelLibrary: changes casing of responses and adds meta property (#30668) (#30711)
  * DeployImage: Switch base images to Debian (#30684) (#30699)
  * Trace: trace to logs design update (#30637) (#30702)
  * Influx: Show all datapoints for dynamically windowed flux query (#30688) (#30703)
  * ci(npm-publish): add missing github package token to env vars (#30665) (#30673)
  * Loki: Improve live tailing errors and fix Explore's logs container type errors (#30517) (#30681)
  * Grafana-UI: Fix setting default value for MultiSelect (#30671) (#30687)
  * Explore: Fix jumpy live tailing (#30650) (#30677)
  * Docs: Refer to product docs in whats new for alerting templating feature (#30652) (#30670)
  * Variables: Fixes display value when using capture groups in regex (#30636) (#30661)
  * Docs: Fix expressions enabled description (#30589) (#30651)
  * Licensing Docs: Adding license restrictions docs (#30216) (#30648)
  * DashboardSettings: fixes vertical scrolling (#30640) (#30643)
  * chore: bump redux toolkit to 1.5.0 for immer 8.0.1 vulnerability fix (#30605) (#30631)
  * Explore: Fix loading visualisation on the top of the new time series panel (#30553) (#30557)
  * Footer: Fixes layout issue in footer  (#30443) (#30494)
  * Variables: Fixes so queries work for numbers values too (#30602) (#30624)
  * Admin: Fixes so form values are filled in from backend (#30544) (#30623)
  * Docs: Update 7.4 What's New to use more correct description of alerting notification template feature (#30502) (#30614)
  * NodeGraph: Add docs (#30504) (#30613)
  * Cloud Monitoring: Fix legend naming with display name override (#30440) (#30503)
  * Expressions: Add option to disable feature (#30541) (#30558)
  * OldGraph: Fix height issue in Firefox (#30565) (#30582)
  * XY Chart: fix editor error with empty frame (no fields) (#30573) (#30577)
  * XY Chart: share legend config with timeseries (#30559) (#30566)
  * DataFrame: cache frame/field index in field state (#30529) (#30560)
  * Prometheus: Fix show query instead of Value if no __name__ and metric (#30511) (#30556)
  * Decimals: Big Improvements to auto decimals and fixes to auto decimals bug found in 7.4-beta1  (#30519) (#30550)
  * chore: update packages dependent on dot-prop to fix security vulnerability (#30432) (#30487)
  * GraphNG: uPlot 1.6.3 (fix bands not filling below 0). close #30523. (#30527) (#30528)
  * GraphNG: uPlot 1.6.2 (#30521) (#30522)
  * Chore: Upgrade grabpl version (#30486) (#30513)
  * grafana/ui: Fix internal import from grafana/data (#30439) (#30507)
  * prevent field config from being overwritten (#30437) (#30442)
  * Chore: upgrade NPM security vulnerabilities (#30397) (#30495)
  * TimeSeriesPanel: Fixed default value for gradientMode (#30484) (#30492)
  * Admin: Fixes so whole org drop down is visible when adding users to org (#30481) (#30497)
  * Chore: adds wait to e2e test (#30488) (#30490)
  * Graph: Fixes so only users with correct permissions can add annotations (#30419) (#30466)
  * Alerting: Hides threshold handle for percentual thresholds (#30431) (#30467)
  * Timeseries: only migrage point size when configured (#30461) (#30470)
  * Expressions: Fix button icon (#30444) (#30450)
  * PanelModel: Make sure the angular options are passed to react panel type changed handler (#30441) (#30451)
  * Docs: Fix img link for alert notification template (#30436) (#30447)
  * Chore: Upgrade build pipeline tool (#30456) (#30457)
  * PanelOptions: Refactoring applying panel and field options out of PanelModel and add property clean up for properties not in field config registry  (#30389) (#30438)
  * "Release: Updated versions in package to 7.4.0-beta.1" (#30427)
  * Chore: Update what's new URL (#30423)
  * GraphNG: assume uPlot's series stroke is always a function (#30416)
  * PanelLibrary: adding library panels to Dashboard Api (#30278)
  * Prettier: Fixes to files that came in after main upgrade (#30410)
  * Cloud Monitoring: Add curated dashboards for the most popular GCP services (#29930)
  * Mssql integrated security (#30369)
  * Prettier: Upgrade to 2  (#30387)
  * GraphNG: sort ascending if the values appear reversed (#30405)
  * Docs: Grafana whats new 7.4 (#30404)
  * Dashboards: Adds cheat sheet toggle to supported query editors (#28857)
  * Docs: Update timeseries-dimensions.md (#30403)
  * Alerting: Evaluate data templating in alert rule name and message (#29908)
  * Docs: Add links to 7.3 patch release notes (#30292)
  * Docs: Update _index.md (#29546)
  * Docs: Update jaeger.md (#30401)
  * Expressions: Remove feature toggle (#30316)
  * Docs: Update tempo.md (#30399)
  * Docs: Update zipkin.md (#30400)
  * services/provisioning: Various cleanup (#30396)
  * DashboardSchemas: OpenAPI Schema Generation (#30242)
  * AlertingNG: Enforce unique alert definition title (non empty)/UID per organisation (#30380)
  * Licensing: Document new v7.4 options and APIs (#30217)
  * Auth: add expired token error and update CreateToken function (#30203)
  * NodeGraph: Add node graph visualization (#29706)
  * Add jwtTokenAuth to plugin metadata schema (#30346)
  * Plugins: Force POSIX style path separators for manifest generation (#30287)
  * Add enterprise reporting fonts to gitignore (#30385)
  * Field overrides: skipping overrides for properties no longer existing in plugin (#30197)
  * NgAlerting: View query result (#30218)
  * Grafana-UI: Make Card story public (#30388)
  * Dashboard: migrate version history list (#29970)
  * Search: use Card component (#29892)
  * PanelEvents: Isolate more for old angular query editors (#30379)
  * Loki: Remove showing of unique labels with the empty string value (#30363)
  * Chore: Lint all files for no-only-tests (#30364)
  * Clears errors after running new query (#30367)
  * Prometheus: Change exemplars endpoint (#30378)
  * Explore: Fix a bug where Typeahead crashes when a large amount of ite… (#29637)
  * Circular vector: improve generics (#30375)
  * Update signing docs (#30296)
  * Email: change the year in templates (#30294)
  * grafana/ui: export TLS auth component (#30320)
  * Query Editor: avoid word wrap (#30373)
  * Transforms: add sort by transformer (#30370)
  * AlertingNG: Save alert instances (#30223)
  * GraphNG: Color series from by value scheme & change to fillGradient to gradientMode  (#29893)
  * Chore: Remove not used PanelOptionsGrid component (#30358)
  * Zipkin: Remove browser access mode (#30360)
  * Jaeger: Remove browser access mode (#30349)
  * chore: bump lodash to 4.17.20 (#30359)
  * ToolbarButton: New emotion based component to replace all navbar, DashNavButton and scss styles (#30333)
  * Badge: Increase contrast, remove rocket icon for plugin beta/alpha state (#30357)
  * Licensing: Send map of environment variables to plugins (#30347)
  * Dashboards: Exit to dashboard when deleting panel from panel view / edit view (#29032)
  * Cloud Monitoring: MQL support (#26551)
  * ReleaseNotes: Updated changelog and release notes for 7.4.0-beta1 (#30348)
  * Panel options UI: Allow collapsible categories (#30301)
  * Grafana-ui: Fix context menu item always using onClick instead of href (#30350)
  * Badge: Design improvement & reduce contrast (#30328)
  * make sure stats are added horizontally and not vertically (#30106)
  * Chore(deps): Bump google.golang.org/grpc from 1.33.1 to 1.35.0 (#30342)
  * Chore(deps): Bump github.com/stretchr/testify from 1.6.1 to 1.7.0 (#30341)
  * Chore(deps): Bump github.com/google/uuid from 1.1.2 to 1.1.5 (#30340)
  * Chore(deps): Bump github.com/hashicorp/go-version from 1.2.0 to 1.2.1 (#30339)
  * Fix HTML character entity error (#30334)
  * GraphNG: fix fillBelowTo regression (#30330)
  * GraphNG: implement softMin/softMax for auto-scaling stabilization. close #979. (#30326)
  * Legend: Fixes right y-axis legend from being pushed outside the bounds of the panel (#30327)
  * Grafana-toolkit: Update component generator templates (#30306)
  * Panels: remove beta flag from stat and bargauge panels (#30324)
  * GraphNG: support fill below to (bands) (#30268)
  * grafana-cli: Fix security issue (#28888)
  * AlertingNG: Modify queries and transform endpoint to get datasource UIDs (#30297)
  * Chore: Fix missing property from ExploreGraph (#30315)
  * Prometheus: Add support for Exemplars (#28057)
  * Grafana-UI: Enhances for TimeRangePicker and TimeRangeInput (#30102)
  * ReleaseNotes: Updated changelog and release notes for 7.4.0 (#30312)
  * Table: Fixes BarGauge cell display mode font size so that it is fixed to the default cell font size (#30303)
  * AngularGraph: Fixes issues with legend wrapping after legend refactoring (#30283)
  * Plugins: Add Open Distro to the list of data sources supported by sigv4 (#30308)
  * Chore: Moves common and response into separate packages (#30298)
  * GraphNG: remove y-axis position control from series color picker in the legend (#30302)
  * Table: migrate old-table config to new table config (#30142)
  * Elasticsearch: Support extended stats and percentiles in terms order by (#28910)
  * Docs: Update release notes index
  * GraphNG: stats in legend (#30251)
  * Grafana UI: EmptySearchResult docs (#30281)
  * Plugins: Use the includes.path (if exists) on sidebar includes links (#30291)
  * Fix spinner and broken buttons (#30286)
  * Graph: Consider reverse sorted data points on isOutsideRange check (#30289)
  * Update getting-started.md (#30257)
  * Backend: use sdk version (v0.81.0) without transform (gel) code (#29236)
  * Chore: update latest versions to 7.3.7 (#30282)
  * Loki: Fix hiding of series in table if labels have number values (#30185)
  * Loki: Lower min step to 1ms (#30135)
  * Prometheus: Improve autocomplete performance and remove disabling of dynamic label lookup (#30199)
  * Icons: Adds custom icon support ands new panel and interpolation icons (#30277)
  * ReleaseNotes: Updated changelog and release notes for 7.3.7 (#30280)
  * Grafana-ui: Allow context menu items to be open in new tab (#30141)
  * Cloud Monitoring: Convert datasource to use Dataframes (#29830)
  * GraphNG: added support to change series color from legend. (#30256)
  * AzureMonitor: rename labels for query type dropdown (#30143)
  * Decimals: Improving auto decimals logic for high numbers and scaled units  (#30262)
  * Elasticsearch: Use minimum interval for alerts (#30049)
  * TimeSeriesPanel: The new graph panel now supports y-axis value mapping #30272
  * CODEOWNERS: Make backend squad owners of backend style guidelines (#30266)
  * Auth: Add missing request headers to SigV4 middleware allowlist (#30115)
  * Grafana-UI: Add story/docs for FilterPill (#30252)
  * Grafana-UI: Add story/docs for Counter (#30253)
  * Backend style guide: Document JSON guidelines (#30267)
  * GraphNG: uPlot 1.6, hide "Show points" in Points mode, enable "dot" lineStyle (#30263)
  * Docs: Update prometheus.md (#30240)
  * Docs: Cloudwatch filter should be JSON format (#30243)
  * API: Add by UID routes for data sources  (#29884)
  * Docs: Update datasource_permissions.md (#30255)
  * Cloudwatch: Move deep link creation to the backend (#30206)
  * Metrics API: Use jsoniter for JSON encoding (#30250)
  * Add option in database config to skip migrations for faster startup. (#30146)
  * Set signed in users email correctly (#30249)
  * Drone: Upgrade build pipeline tool (#30247)
  * runRequest: Fixes issue with request time range and time range returned to panels are off causing data points to be cut off (outside) (#30227)
  * Elasticsearch: fix handling of null values in query_builder (#30234)
  * Docs: help users connect to Prometheus using SigV4 (#30232)
  * Update documentation-markdown-guide.md (#30207)
  * Update documentation-markdown-guide.md (#30235)
  * Better logging of plugin scanning errors (#30231)
  * Print Node.js and Toolkit versions (#30230)
  * Chore: bump rollup across all packages (#29486)
  * Backend style guide: Document database patterns (#30219)
  * Chore: Bump plugin-ci-alpine Docker image version (#30225)
  * Legends: Refactoring and rewrites of legend components to simplify components & reuse (#30165)
  * Use Node.js 14.x in plugin CI (#30209)
  * Field overrides: extracting the field config factory into its own reusable module. (#30214)
  * LibraryPanels: adds connections (#30212)
  * PanelOptionsGroups: Only restore styles from PanelOptionsGroup (#30215)
  * Variables: Add deprecation warning for value group tags (#30160)
  * GraphNG: Hide grid for right-y axis if left x-axis exists (#30195)
  * Middleware: Add CSP support (#29740)
  * Updated image links to have newer format. (#30208)
  * Docs: Update usage-insights.md (#30150)
  * Share panel dashboard add images (#30201)
  * Update documentation-style-guide.md (#30202)
  * Docs: Fix links to transforms (#30194)
  * docs(badge): migrate story to use controls (#30180)
  * Chore(deps): Bump github.com/prometheus/common from 0.14.0 to 0.15.0 (#30188)
  * Fix alert definition routine stop (#30117)
  * Chore(deps): Bump gopkg.in/square/go-jose.v2 from 2.4.1 to 2.5.1 (#30189)
  * InlineSwitch: Minor story fix (#30186)
  * Chore(deps): Bump github.com/gosimple/slug from 1.4.2 to 1.9.0 (#30178)
  * Chore(deps): Bump github.com/fatih/color from 1.9.0 to 1.10.0 (#30183)
  * Chore(deps): Bump github.com/lib/pq from 1.3.0 to 1.9.0 (#30181)
  * Chore(deps): Bump github.com/hashicorp/go-plugin from 1.2.2 to 1.4.0 (#30175)
  * Chore(deps): Bump github.com/getsentry/sentry-go from 0.7.0 to 0.9.0 (#30171)
  * Gauge: Fixes issue with all null values cause min & max to be null (#30156)
  * Links: Add underline on hover for links in NewsPanel (#30166)
  * GraphNG: Update to test dashboards (#30153)
  * CleanUp: Removed old panel options group component (#30157)
  * AngularQueryEditors: Fixes to Graphite query editor and other who refer to other queries (#30154)
  * Chore(deps): Bump github.com/robfig/cron/v3 from 3.0.0 to 3.0.1 (#30172)
  * Chore(deps): Bump github.com/urfave/cli/v2 from 2.1.1 to 2.3.0 (#30173)
  * Chore: Fix spelling issue (#30168)
  * Revise README.md. (#30145)
  * Chore(deps): Bump github.com/mattn/go-sqlite3 from 1.11.0 to 1.14.6 (#30174)
  * InlineSwitch: Added missing InlineSwitch component and fixed two places that used unaligned inline switch (#30162)
  * GraphNG: add new alpha XY Chart  (#30096)
  * Elastic: Support request cancellation properly (Uses new backendSrv.fetch Observable request API) (#30009)
  * OpenTSDB: Support request cancellation properly (#29992)
  * InfluxDB: Update Flux external link (#30158)
  * Allow dependabot to keep go packages up-to-date (#30170)
  * PluginState: Update comment
  * GraphNG: Minor polish & updates to new time series panel and move it from alpha to beta (#30163)
  * Share panel dashboard (#30147)
  * GraphNG: rename "graph3" to "timeseries" panel (#30123)
  * Add info about access mode (#30137)
  * Prometheus: Remove running of duplicated metrics query (#30108)
  * Prometheus: Fix autocomplete does not work on incomplete input (#29854)
  * GraphNG: remove graph2 panel (keep the parts needed for explore) (#30124)
  * Docs: Add metadata to activating licensing page (#30140)
  * MixedDataSource: Added missing variable support flag (#30110)
  * AngularPanels: Fixes issue with some panels not rendering when going into edit mode due to no height (#30113)
  * AngularPanels: Fixes issue with discrete panel that used the initialized event (#30133)
  * Explore: Make getFieldLinksForExplore more reusable (#30134)
  * Elasticsearch: Add Support for Serial Differencing Pipeline Aggregation (#28618)
  * Angular: Fixes issue with angular directive caused by angular upgrade in master (#30114)
  * Analytics: add data source type in data-request events (#30087)
  * GraphNG: "Interpolation: Step after" test (#30127)
  * GraphNG: check cross-axis presence when auto-padding. close #30121. (#30126)
  * Alerting: improve alerting default datasource search when extracting alerts (#29993)
  * Loki: Timeseries should not produce 0-values for missing data (#30116)
  * GraphNG: support dashes (#30070)
  * GraphNG: fix spanGaps optimization in alignDataFrames(). see #30101. (#30118)
  * Alerting NG: update API to expect UIDs instead of IDs (#29896)
  * GraphNG: Overhaul of main test dashboard and update to null & gaps dashboard (#30101)
  * Chore: Fix intermittent time-related test failure in explore datasource instance update (#30109)
  * QueryEditorRow: Ability to change query name (#29779)
  * Frontend: Failed to load application files message improvement IE11 (#30011)
  * Drone: Upgrade build pipeline tool (#30104)
  * Fix phrasing. (#30075)
  * Chore: Add CloudWatch HTTP API tests (#29691)
  * Elastic: Fixes so templating queries work (#30003)
  * Chore: Rewrite elasticsearch client test to standard library (#30093)
  * Chore: Rewrite tsdb influxdb test to standard library (#30091)
  * Fix default maximum lifetime  an authenticated user can be logged in (#30030)
  * Instrumentation: re-enable database wrapper feature to expose counter and histogram for database queries (#29662)
  * Docs: Update labels to fields transform (#30086)
  * GraphNG: adding possibility to toggle tooltip, graph and legend for series (#29575)
  * Chore: Rewrite tsdb cloudmonitoring test to standard library (#30090)
  * Chore: Rewrite tsdb azuremonitor time grain test to standard library (#30089)
  * Chore: Rewrite tsdb graphite test to standard library (#30088)
  * Chore: Upgrade Docker build image wrt. Go/golangci-lint/Node (#30077)
  * Usage Stats: Calculate concurrent users as a histogram (#30006)
  * Elasticsearch: Fix broken alerting when using pipeline aggregations (#29903)
  * Drone: Fix race conditions between Enterprise and Enterprise2 (#30076)
  * Chore: Rewrite models datasource cache test to standard library (#30040)
  * Plugins: prevent app plugin from rendering with wrong location (#30017)
  * Update NOTICE.md
  * Chore: Tiny typo fix `rage` -> `range` (#30067)
  * Docs: loki.md: Add example of Loki data source config (#29976)
  * ReleaseNotes: Updated changelog and release notes for 7.3.6 (#30066)
  * Docs: Update usage-insights.md (#30065)
  * Docs: Update white-labeling.md (#30064)
  * Chore(deps): Bump axios from 0.19.2 to 0.21.1 (#30059)
  * Chore: Rewrite models tags test to standard library (#30041)
  * Bump actions/setup-node from v1 to v2.1.4 (#29891)
  * Build(deps): Bump ini from 1.3.5 to 1.3.7 (#29787)
  * fall back to any architecture when getting plugin's checksum #30034 (#30035)
  * Lerna: Update to 3.22.1 (#30057)
  * SeriesToRows: Fixes issue in transform so that value field is always named Value (#30054)
  * [dashboard api] manage error when data in dashboard table is not valid json (#29999)
  * use sha256 checksum instead of md5 (#30018)
  * Chore: Rewrite brute force login protection test to standard library (#29986)
  * Chore: Rewrite login auth test to standard library (#29985)
  * Chore: Rewrite models dashboards test to standard library (#30023)
  * Chore: Rewrite models dashboard acl test to standard library (#30022)
  * Chore: Rewrite models alert test to standard library (#30021)
  * Chore: Rewrite ldap login test to standard library (#29998)
  * Chore: Rewrite grafana login test to standard library (#29997)
  * Fix two ini-file typos regarding LDAP (#29843)
  * Chore: Changes source map devtool to inline-source-map (#30004)
  * Chore: Sync Enterprise go.sum (#30005)
  * Chore: Add Enterprise dependencies (#29994)
  * SQLStore: customise the limit of retrieved datasources per organisation (#29358)
  * Chore: update crewjam/saml library to the latest master (#29991)
  * Graph: Fixes so users can not add annotations in readonly dash (#29990)
  * Currency: add Vietnamese dong (VND) (#29983)
  * Drone: Update pipelines for Enterprise (#29939)
  * Remove the bus from teamgroupsync (#29810)
  * Influx: Make variable query editor input uncontrolled (#29968)
  * PanelLibrary: Add PATCH to the API (#29956)
  * PanelEvents: Isolating angular panel events into it's own event bus + more event refactoring  (#29904)
  * Bump node-notifier from 8.0.0 to 8.0.1 (#29952)
  * LDAP: Update use_ssl documentation (#29964)
  * Docs: Missing 's' on 'logs' (#29966)
  * Docs: Update opentsdb.md (#29963)
  * Docs: Minor typo correction (#29962)
  * librarypanels: Fix JSON field casing in tests (#29954)
  * TemplateSrv: Do not throw  error for an unknown format but use glob as fallback and warn in the console (#29955)
  * PanelLibrary: Adds uid and renames title to name (#29944)
  * Docs: Fix raw format variable docs (#29945)
  * RedirectResponse: Implement all of api.Response (#29946)
  * PanelLibrary: Adds get and getAll to the api (#29772)
  * Chore: Remove duplicate interpolateString test (#29941)
  * Chore: Rewrite influxdb query parser test to standard library (#29940)
  * Folders: Removes the possibility to delete the General folder (#29902)
  * Chore: Convert tsdb request test to standard library (#29936)
  * Chore: Convert tsdb interval test to standard library (#29935)
  * Docs: Update configuration.md (#29912)
  * Docs: Update organization_roles.md (#29911)
  * Docs: Update _index.md (#29918)
  * GraphNG: bring back tooltip (#29910)
  * Ng Alerting: Remove scroll and fix SplitPane limiters (#29906)
  * Dashboard: Migrating dashboard settings to react (#27561)
  * Minor correction to explanation on correct MS SQL usage. (#29889)
  * AlertingNG: Create a scheduler to evaluate alert definitions (#29305)
  * Add changelog items for 7.3.6, 7.2.3 and 6.7.5 (#29901)
  * bump stable to 7.3.6 (#29899)
  * Upgrade go deps.  (#29900)
  * Expressions: Replace query input fields with select. (#29816)
  * PanelEdit: Update UI if panel plugin changes field config (#29898)
  * Elasticsearch: Remove timeSrv dependency (#29770)
  * PanelEdit: Need new data after plugin change (#29874)
  * Chore(toolkit): disable react/prop-types for eslint config (#29888)
  * Field Config API: Add ability to hide field option or disable it from the overrides (#29879)
  * SharedQuery: Fixes shared query editor now showing queries (#29849)
  * GraphNG: support fill gradient (#29765)
  * Backend style guide: Add more guidelines (#29871)
  * Keep query keys consistent (#29855)
  * Alerting: Copy frame field labels to time series tags (#29886)
  * Update configure-docker.md (#29883)
  * Usage Stats: Introduce an interface for usage stats service (#29882)
  * DataFrame: add a writable flag to fields (#29869)
  * InlineForms: Changes to make inline forms more flexible for query editors  (#29782)
  * Usage Stats: Allow to add additional metrics to the stats (#29774)
  * Fix the broken link of XORM documentation (#29865)
  * Move colors demo under theme colors (#29873)
  * Dashboard: Increase folder name size in search dashboard (#29821)
  * MSSQL: Config UI touches (#29834)
  * QueryOptions:  Open QueryEditors: run queries after changing group options #29864
  * GraphNG: uPlot 1.5.2, dynamic stroke/fill, Flot-style hover points (#29866)
  * Variables: Fixes so numerical sortorder works for options with null values (#29846)
  * GraphNG: only initialize path builders once (#29863)
  * GraphNG: Do not set fillColor from GraphNG only opacity (#29851)
  * add an example cloudwatch resource_arns() query that uses multiple tags (ref: #29499) (#29838)
  * Backend: Remove more globals (#29644)
  * MS SQL: Fix MS SQL add data source UI issues (#29832)
  * Display palette and colors for dark and light themes in storybook (#29848)
  * Docs: Fix broken link in logs-panel (#29833)
  * Docs: Add info about typing of connected props to Redux style guide (#29842)
  * Loki: Remove unnecessary deduplication (#29421)
  * Varibles: Fixes so clicking on Selected will not include All (#29844)
  * Explore/Logs: Correctly display newlines in detected fields (#29541)
  * Link suppliers: getLinks API update (#29757)
  * Select: Changes default menu placement for Select from auto to bottom (#29837)
  * Chore: Automatically infer types for dashgrid connected components  (#29818)
  * Chore: Remove unused Loki and Cloudwatch syntax providers  (#29686)
  * Pass row (#29839)
  * GraphNG: Context menu (#29745)
  * GraphNG: Enable scale distribution configuration (#29684)
  * Explore: Improve Explore performance but removing unnecessary re-renders (#29752)
  * DashboardDS: Fixes display of long queries (#29808)
  * Sparkline: Fixes issue with sparkline that sent in custom fillColor instead of fillOpacity (#29825)
  * Chore: Disable default golangci-lint filter (#29751)
  * Update style guide with correct usage of MS SQL (#29829)
  * QueryEditor: do not auto refresh on every update (#29762)
  * Chore: remove unused datasource status enum (#29827)
  * Expressions: support ${my var} syntax (#29819)
  * Docs: Update types-options.md (#29777)
  * Chore: Enable more go-ruleguard rules (#29781)
  * GraphNG: Load uPlot path builders lazily (#29813)
  * Elasticsearch: ensure query model has timeField configured in datasource settings (#29807)
  * Chore: Use Header.Set method instead of Header.Add (#29804)
  * Allow dependabot to check actions (#28159)
  * Grafana-UI: Support optgroup for MultiSelect (#29805)
  * Sliders: Update behavior and style tweak (#29795)
  * Grafana-ui: Fix collapsible children sizing (#29776)
  * Style guide: Document avoidance of globals in Go code (#29803)
  * Chore: Rewrite opentsdb test to standard library (#29792)
  * CloudWatch: Add support for AWS DirectConnect ConnectionErrorCount metric (#29583)
  * GraphNG: uPlot 1.5.1 (#29789)
  * GraphNG: update uPlot v1.5.0 (#29763)
  * Added httpMethod to webhook (#29780)
  * @grafana-runtime: Throw error if health check fails in DataSourceWithBackend (#29743)
  * Explore: Fix remounting of query row (#29771)
  * Expressions: Add placeholders to hint on input (#29773)
  * Alerting: Next gen Alerting page (#28397)
  * GraphNG: Add test dashboard for null & and gaps rendering (#29769)
  * Expressions: Field names from refId (#29755)
  * Plugins: Add support for signature manifest V2 (#29240)
  * Chore: Configure go-ruleguard via golangci-lint (#28419)
  * Move middleware context handler logic to service (#29605)
  * AlertListPanel: Add options to sort by Time(asc) and Time(desc) (#29764)
  * PanelLibrary: Adds delete Api (#29741)
  * Tracing: Release trace to logs feature (#29443)
  * ReleaseNotes: Updated changelog and release notes for 7.3.5 (#29753)
  * DataSourceSettings: Add servername field to DataSource TLS config (#29279)
  * Chore: update stable and testing versions (#29748)
  * ReleaseNotes: Updated changelog and release notes for 7.3.5 (#29744)
  * Elasticsearch: View in context feature for logs (#28764)
  * Chore: Disable gosec on certain line (#29382)
  * Logging: log frontend errors caught by ErrorBoundary, including component stack (#29345)
  * ChangePassword: improved keyboard navigation (#29567)
  * GrafanaDataSource: Fix selecting -- Grafana -- data source, broken after recent changes (#29737)
  * Docs: added version note for rename by regex transformation. (#29735)
  * @grafana/ui: Fix UI issues for cascader button dropdown and query input (#29727)
  * Docs: Update configuration.md (#29728)
  * Docs: Remove survey (#29549)
  * Logging: rate limit fronted logging endpoint (#29272)
  * API: add Status() to RedirectResponse (#29722)
  * Elasticsearch: Deprecate browser access mode (#29649)
  * Elasticsearch: Fix query initialization action (#29652)
  * PanelLibrary: Adds api and db to create Library/Shared/Reusable Panel (#29642)
  * Transformer: Rename metrics based on regex (#29281)
  * Variables: Fixes upgrade of legacy Prometheus queries (#29704)
  * Auth: Add SigV4 header allowlist to reduce chances of verification issues (#29650)
  * DataFrame: add path and description metadata (#29695)
  * Alerting: Use correct time series name override from frame fields (#29693)
  * GraphNG: fix bars migration and support color and linewidth (#29697)
  * PanelHeader: Fix panel header description inline code wrapping (#29628)
  * Bugfix 29848: Remove annotation_tag entries as part of annotations cleanup (#29534)
  * GraphNG: simple settings migration from flot panel (#29599)
  * GraphNG: replace bizcharts with uPlot for sparklines (#29632)
  * GitHubActions: Update node version in github action (#29683)
  * Adds go dep used by an Enterprise feature.  (#29645)
  * Typescript: Raise strict error limit for enterprise (#29688)
  * Remove unnecessary escaping (#29677)
  * Update getting-started-prometheus.md (#29678)
  * instrumentation: align label name with our other projects (#29514)
  * Typescript: Fixing typescript strict error, and separate check from publishing (#29679)
  * CloudWatch: namespace in search expression should be quoted if match exact is enabled #29109 (#29563)
  * Docs: Plugin schema updates (#28232)
  * RadioButton: Fix flex issue in master for radio buttons (#29664)
  * Update getting-started.md (#29670)
  * Expr: fix time unit typo in ds queries (#29668)
  * Expr: make reduction nan/null more consistent (#29665)
  * Expr: fix func argument panic (#29663)
  * Update documentation-style-guide.md (#29661)
  * Update documentation-markdown-guide.md (#29659)
  * Docs: Changed image format (#29658)
  * Expr: fix failure to execute due to OrgID (#29653)
  * GraphNG: rename "points" to "showPoints" (#29635)
  * Expressions: Restore showing expression query editor even if main data source is not mixed (#29656)
  * GraphNG: time range should match the panel timeRange (#29596)
  * Support svg embedded favicons in whitelabeling (#29436)
  * Add changelog to docs style guide (#29581)
  * Loki: Retry web socket connection when connection is closed abnormally (#29438)
  * GraphNG: Fix annotations and exemplars plugins (#29613)
  * Chore: Rewrite tsdb sql engine test to standard library (#29590)
  * GraphNG: fix and optimize spanNulls (#29633)
  * Build(deps): Bump highlight.js from 10.4.0 to 10.4.1 (#29625)
  * Cloudwatch: session cache should use UTC consistently (#29627)
  * GraphNG: rename GraphMode to DrawStyle (#29623)
  * GraphNG: add spanNulls config option (#29512)
  * Docs: add docs for concatenate transformer (#28667)
  * Stat/Gauge: expose explicit font sizing (#29476)
  * GraphNG: add gaps/nulls support to staircase & smooth interpolation modes (#29593)
  * grafana/ui: Migrate Field knobs to controls (#29433)
  * Prometheus: Fix link to Prometheus graph in dashboard (#29543)
  * Build: Publish next and latest npm channels to Github (#29615)
  * Update broken aliases (#29603)
  * API: add ID to snapshot API responses (#29600)
  * Elasticsearch: Migrate queryeditor to React (#28033)
  * QueryGroup & DataSourceSrv & DataSourcePicker changes simplify usage, error handling and reduce duplication, support for uid (#29542)
  * Elastic: Fixes config UI issues (#29608)
  * GraphNG: Fix issues with plugins not retrieving plot instance (#29585)
  * middleware: Make scenario test functions take a testing.T argument (#29564)
  * Grafana/ui: Storybook controls understand component types (#29574)
  * Login: Fixes typo in tooltip (#29604)
  * Panel: making sure we support all versions of chrome when detecting position of click event. (#29544)
  * Chore: Rewrite sqlstore migration test to use standard library (#29589)
  * Chore: Rewrite tsdb prometheus test to standard library (#29592)
  * Security: Add gosec G304 auditing annotations (#29578)
  * Chore: Rewrite tsdb testdatasource scenarios test to standard library (#29591)
  * Docs: Add missing key to enable SigV4 for provisioning Elasticsearch data source (#29584)
  * Add Microsoft.Network/natGateways (#29479)
  * Update documentation-style-guide.md (#29586)
  * @grafana/ui: Add bell-slash to available icons (#29579)
  * Alert: Fix forwardRef warning (#29577)
  * Update documentation-style-guide.md (#29580)
  * Chore: Upgrade typescript to 4.1 (#29493)
  * PanelLibrary: Adds library_panel table (#29565)
  * Make build docker full fix (#29570)
  * Build: move canary packages to github (#29411)
  * Devenv: Add default db for influxdb (#29371)
  * Chore: Check errors from Close calls (#29562)
  * GraphNG: support auto and explicit axis width (#29553)
  * Chore: upgrading y18n to 4.0.1 for security reasons (#29523)
  * Middleware: Rewrite tests to use standard library (#29535)
  * Overrides: show category on the overrides (#29556)
  * GraphNG: Bars, Staircase, Smooth modes (#29359)
  * Docs: Fix docs sync actions (#29551)
  * Chore: Update dev guide node version for Mac (#29548)
  * Docs: Update formatting-multi-value-variables.md (#29547)
  * Arrow: toArray() on nullable values should include null values (#29520)
  * Docs: Update syntax.md (#29545)
  * NodeJS: Update to LTS (14) (#29467)
  * Docs: Update repeat-panels-or-rows.md (#29540)
  * 3 minor changes, including updating the title TOC (#29501)
  * Auth proxy: Return standard error type (#29502)
  * Data: use pre-defined output array length in vectorToArray() (#29516)
  * Dashboards: hide playlist edit functionality from viewers and snapshots link from unauthenticated users (#28992)
  * docker: use yarn to build (#29538)
  * QueryEditors: Refactoring & rewriting out dependency on PanelModel (#29419)
  * Chore: skip flaky tests (#29537)
  * Graph NG: Invalidate uPlot config on timezone changes (#29531)
  * IntelliSense: Fix autocomplete and highlighting for Loki, Prometheus, Cloudwatch (#29381)
  * Variables: Fixes Textbox current value persistence (#29481)
  * OptionsEditor: simplify the options editor interfaces (#29518)
  * Icon: Changed the icon for signing in (#29530)
  * fixes bug with invalid handler name for metrics (#29529)
  * Middleware: Simplifications (#29491)
  * GraphNG: simplify effects responsible for plot updates/initialization  (#29496)
  * Alarting: fix alarm messages in dingding (Fixes #29470) (#29482)
  * PanelEdit: making sure the correct datasource query editor is being rendered. (#29500)
  * AzureMonitor: Unit MilliSeconds naming (#29399)
  * Devenv: update mysql_tests and postgres_tests blocks for allowing dynamically change of underlying docker image (#29525)
  * Chore: Enable remaining eslint-plugin-react rules (#29519)
  * Docs/Transformations: Add documentation about Binary operations in Add field from calculation (#29511)
  * Datasources: fixed long error message overflowing container (#29440)
  * docker: fix Dockerfile after Gruntfile.js removed (#29515)
  * Chore: Adds Panel Library featuretoggle (#29521)
  * Docs: Update filter-variables-with-regex.md (#29508)
  * Docs: InfluxDB_V2 datasource: adding an example on how to add InfluxQL as a datasource (#29490)
  * Loki: Add query type and line limit to query editor in dashboard (#29356)
  * Docs: Added Security Group support to Azure Auth (#29418)
  * DataLinks: Removes getDataSourceSettingsByUid from applyFieldOverrides  (#29447)
  * Bug: trace viewer doesn't show more than 300 spans (#29377)
  * Live: publish all dashboard changes to a single channel (#29474)
  * Chore: Enable eslint-plugin-react partial rules (#29428)
  * Alerting: Update alertDef.ts with more time options (#29498)
  * DataSourceSrv: Look up data source by uid and name transparently (#29449)
  * Instrumentation: Add examplars for request histograms (#29357)
  * Variables: Fixes Constant variable persistence confusion (#29407)
  * Docs: Fix broken link for plugins (#29346)
  * Prometheus: don't override displayName property (#29441)
  * Grunt: Removes grunt dependency and replaces some of its usage (#29461)
  * Transformation: added support for excluding/including rows based on their values. (#26884)
  * Chore: Enable exhaustive linter (#29458)
  * Field overrides: added matcher to match all fields within frame/query. (#28872)
  * Log: Use os.Open to open file for reading (#29483)
  * MinMax: keep global min/main in field state (#29406)
  * ReactGridLayout: Update dependency to 1.2 (#29455)
  * Jest: Upgrade to latest (#29450)
  * Chore: bump grafana-ui rollup dependencies (#29315)
  * GraphNG: use uPlot's native ms support (#29445)
  * Alerting: Add support for Sensu Go notification channel (#28012)
  * adds tracing for all bus calls that passes ctx (#29434)
  * prometheus: Improve IsAPIError's documentation (#29432)
  * ReleaseNotes: Updated changelog and release notes for 7.3.4 (#29430)
  * Elasticsearch: Fix index pattern not working with multiple base sections (#28348)
  * Plugins: Add support for includes' icon (#29416)
  * Docs: fixing frontend docs issue where enums ending up in wrong folder level. (#29429)
  * Variables: Fixes issue with upgrading legacy queries (#29375)
  * Queries: Extract queries from dashboard (#29349)
  * Docs: docker -> Docker (#29331)
  * PanelEvents: Refactors and removes unnecessary events, fixes panel editor update issue when panel options change (#29414)
  * Fix: Correct panel edit uistate migration (#29413)
  * Alerting: Improve Prometheus Alert Rule error message (#29390)
  * Fix: Migrate Panel edit uiState percentage strings to number (#29412)
  * remove insecure cipher suit as default option (#29378)
  * * prometheus fix variables fetching when  customQueryParameters used #28907 (#28949)
  * Chore: Removes observableTester (#29369)
  * Chore: Adds e2e tests for Variables (#29341)
  * Fix gosec finding of unhandled errors (#29398)
  * Getting started with Grafana and MS SQL (#29401)
  * Arrow: cast timestams to Number (#29402)
  * Docs: Add Cloud content links (#29317)
  * PanelEditor: allow access to the eventBus from panel options (#29327)
  * GraphNG: support x != time in library (#29353)
  * removes unused golint file (#29391)
  * prefer server cipher suites (#29379)
  * Panels/DashList: Fix order of recent dashboards (#29366)
  * Core: Move SplitPane layout from PanelEdit. (#29266)
  * Drone: Upgrade build pipeline tool (#29365)
  * Update yarn.lock to use latest rc-util (#29313)
  * Variables: Adds description field  (#29332)
  * Chore: Update latest.json (#29351)
  * Drone: Upload artifacts for release branch builds (#29297)
  * Docs: fixing link issues in auto generated frontend docs. (#29326)
  * Drone: Execute artifact publishing for both editions in parallel during release (#29362)
  * Devenv: adding default credentials for influxdb (#29344)
  * Drone: Check CUE dashboard schemas (#29334)
  * Backend: fix IPv6 address parsing erroneous (#28585)
  * dashboard-schemas cue 3.0.0 compatible (#29352)
  * Update documentation-style-guide.md (#29354)
  * Docs: Update requirements.md (#29350)
  * ReleaseNotes: Updated changelog and release notes for 7.3.4 (#29347)
  * ReleaseNotes: Updated changelog and release notes for 7.3.4 (#29338)
  * Drone: Publish NPM packages after Storybook to avoid race condition (#29340)
  * Add an option to hide certain users in the UI (#28942)
  * Guardian: Rewrite tests from goconvey (#29292)
  * Docs: Fix editor role and alert notification channel description (#29301)
  * Docs: Improve custom Docker image instructions (#29263)
  * Security: Fixes minor security issue with alert notification webhooks that allowed GET & DELETE requests #29330
  * Chore: Bump storybook to v6 (#28926)
  * ReleaseNotes: Updates release notes link in package.json (master) (#29329)
  * Docs: Accurately reflecting available variables (#29302)
  * Heatmap: Fixes issue introduced by new eventbus (#29322)
  * Dashboard Schemas (#28793)
  * devenv: Add docker load test which authenticates with API key (#28905)
  * Login: Fixes redirect url encoding issues of # %%23 being unencoded after login (#29299)
  * InfluxDB: update flux library and support boolean label values (#29310)
  * Explore/Logs: Update Parsed fields to Detected fields (#28881)
  * GraphNG: Init refactorings and fixes (#29275)
  * fixing a broken relref link (#29312)
  * Drone: Upgrade build pipeline tool (#29308)
  * decreasing frontend docs threshold. (#29304)
  * Docker: update docker root group docs and docker image (#29222)
  * WebhookNotifier: Convert tests away from goconvey (#29291)
  * Annotations: fixing so when changing annotations query links submenu will be updated. (#28990)
  * [graph-ng] add temporal DataFrame alignment/outerJoin & move null-asZero pass inside (#29250)
  * Dashboard: Fixes kiosk state after being redirected to login page and back (#29273)
  * make it possible to hide change password link in profile menu (#29246)
  * Theme: Add missing color type (#29265)
  * Chore: Allow reducerTester to work with every data type & payload-less actions (#29241)
  * Explore/Prometheus: Update default query type option to "Both" (#28935)
  * Loki/Explore: Add query type selector (#28817)
  * Variables: New Variables are stored immediately (#29178)
  * reduce severity level to warning (#28939)
  * Units: Changes FLOP/s to FLOPS and some other rates per second units get /s suffix  (#28825)
  * Docs: Remove duplicate "Transformations overview" topics from the TOC (#29247)
  * Docs: Fixed broken relrefs and chanfed TOC entry name from Alerting to Alerts. (#29251)
  * Docs: Remove duplicate Panel overview topic.  (#29248)
  * Increase search limit on team add user and improve placeholder (#29258)
  * Fix warnings for conflicting style rules (#29249)
  * Make backwards compatible (#29212)
  * Minor cosmetic markdown tweaks in docs/cloudwatch.md (#29238)
  * Getting Started: Updated index topic, removed "what-is-grafana", and adjusted weight o… (#29216)
  * BarGauge: Fix story for BarGauge, caused knobs to show for other stories (#29232)
  * Update glossary to add hyperlinks to Explore and Transformation entries (#29217)
  * Chore: Enable errorlint linter (#29227)
  * TimeRegions: Fixed issue with time regions and tresholds due to angular js upgrade (#29229)
  * CloudWatch: Support request cancellation properly (#28865)
  * CloudMonitoring: Support request cancellation properly (#28847)
  * Chore: Handle wrapped errors (#29223)
  * Expressions: Move GEL into core as expressions (#29072)
  * Chore: remove compress:release grunt task (#29225)
  * Refactor/Explore: Inline datasource actions into initialisation (#28953)
  * Fix README typo (#29219)
  * Grafana UI: Card API refactor (#29034)
  * Plugins: Changed alertlist alert url to view instead of edit (#29060)
  * React: Upgrading react to v17, wip (#29057)
  * Gauge: Tweaks short value auto-sizing (#29197)
  * BackendSrv: support binary responseType like $http did (#29004)
  * GraphNG: update the options config (#28917)
  * Backend: Fix build (#29206)
  * Permissions: Validate against Team/User permission role update (#29101)
  * ESlint: React fixes part 1 (#29062)
  * Tests: Adds expects for observables (#28929)
  * Variables: Adds new Api that allows proper QueryEditors for Query variables (#28217)
  * Introduce eslint-plugin-react (#29053)
  * Automation: Adds GitHub release action (#29194)
  * Refactor declarative series configuration to a config builder (#29106)
  * ReleaseNotes: Updated changelog and release notes for 7.3.3 (#29189)
  * Panels: fix positioning of the header title (#29167)
  * trace user login and datasource name instead of id (#29183)
  * playlist: Improve test (#29120)
  * Drone: Fix publish-packages invocation (#29179)
  * Table: Fix incorrect condtition for rendering table filter (#29165)
  * Chore: Upgrade grafana/build-ci-deploy image to latest Go (#29171)
  * DashboardLinks: will only refresh dashboard search when changing tags for link. (#29040)
  * ReleaseNotes: Updated changelog and release notes for 7.3.3 (#29169)
  * CloudWatch: added HTTP API Gateway specific metrics and dimensions (#28780)
  * Release: Adding release notes for 7.3.3 (#29168)
  * SQL: Define primary key for tables without it (#22255)
  * changed link format from MD to HTML (#29163)
  * Backend: Rename variables for style conformance (#29097)
  * Docs: Fixes what'new menu and creates index page, adds first draft of release notes to docs (#29158)
  * Drone: Upgrade build pipeline tool and build image (#29161)
  * ReleaseNotes: Updated changelog and release notes for 7.4.0 (#29160)
  * ReleaseNotes: Updated changelog and release notes for 7.3.3 (#29159)
  * Chore: Upgrade Go etc in build images (#29157)
  * Chore: Remove unused Go code (#28852)
  * API: Rewrite tests from goconvey (#29091)
  * Chore: Fix linting issues caught by ruleguard (#28799)
  * Fix panic when using complex dynamic URLs in app plugin routes  (#27977)
  * Snapshots: Fixes so that dashboard snapshots show data when using Stat, Gauge, BarGauge or Table panels (#29031)
  * Fix authomation text: remove hyphen (#29149)
  * respect fronted-logging.enabled flag (#29107)
  * build paths in an os independent way (#29143)
  * Provisioning: always pin app to the sidebar when enabled (#29084)
  * Automation: Adds new changelog actions (#29142)
  * Chore: Rewrite preferences test from GoConvey to stdlib and testify (#29129)
  * Chore: Upgrade Go dev tools (#29124)
  * Automation: Adding version bump action
  * DataFrames: add utility function to check if structure has changed (#29006)
  * Drone: Fix Drone config verification for enterprise on Windows (#29118)
  * Chore: Require OrgId to be specified in delete playlist command (#29117)
  * Plugin proxy: Handle URL parsing errors (#29093)
  * Drone: Verify Drone config at beginning of pipelines (#29071)
  * Legend/GraphNG: Refactoring legend types and options (#29067)
  * Doc: Update documentation-style-guide.md (#29082)
  * Chore: Bumps types for jest (#29098)
  * LogsPanel: Fix scrolling in dashboards (#28974)
  * sort alphabetically unique labels, labels and parsed fields (#29030)
  * Data source proxy: Convert 401 from data source to 400 (#28962)
  * Plugins: Implement testDatasource for Jaeger (#28916)
  * Update react-testing-library (#29061)
  * Graph: Fixes stacking issues like floating bars when data is not aligned  (#29051)
  * StatPanel: Fixes hanging issue when all values are zero (#29077)
  * Auth: Enable more complete credential chain for SigV4 default SDK auth option (#29065)
  * Chore: Convert API tests to standard Go lib (#29009)
  * Update README.md (#29075)
  * Update CODEOWNERS (#28906)
  * Enhance automation text for missing information (#29052)
  * GraphNG: Adding ticks test dashboard and improves tick spacing (#29044)
  * Chore: Migrate Dashboard List panel to React (#28607)
  * Test Datasource/Bug: Fixes division by zero in csv metric values scenario (#29029)
  * Plugins: Bring back coreplugin package (#29064)
  * Add 'EventBusName' dimension to CloudWatch 'AWS/Events' namespace (#28402)
  * CloudWatch: Add support for AWS/ClientVPN metrics and dimensions (#29055)
  * AlertingNG: manage and evaluate alert definitions via the API (#28377)
  * Fix linting issues (#28811)
  * Logging: Log frontend errors (#28073)
  * Fix for multi-value template variable for project selector (#29042)
  * Chore: Rewrite test helpers from GoConvey to stdlib (#28919)
  * GraphNG: Fixed axis measurements (#29036)
  * Fix links to logql docs (#29037)
  * latest 7.3.2 (#29041)
  * Elasticsearch: Add Moving Function Pipeline Aggregation (#28131)
  * changelog 7.3.2 (#29038)
  * MutableDataFrame: Remove unique field name constraint and values field index and unused/seldom used stuff  (#27573)
  * Fix prometheus docs related to query variable (#29027)
  * Explore: support ANSI colors in live logs (#28895)
  * Docs: Add documentation about log levels (#28975)
  * Dashboard: remove usage of Legacyforms (#28707)
  * Docs: Troubleshoot starting docker containers on Mac (#28754)
  * Elasticsearch: interpolate variables in Filters Bucket Aggregation (#28969)
  * Chore: Bump build pipeline version (#29023)
  * Annotations: Fixes error when trying to create annotation when dashboard is unsaved (#29013)
  * TraceViewer: Make sure it does not break when no trace is passed (#28909)
  * Thresholds: Fixes color assigned to null values (#29010)
  * Backend: Remove unused code (#28933)
  * Fix documentation (#28998)
  * Tracing: Add setting for sampling server (#29011)
  * Logs Panel: Fix inconsistent higlighting (#28971)
  * MySQL: Update README.md (#29003)
  * IntervalVariable: Fix variable tooltip (#28988)
  * StatPanels: Fixes auto min max when latest value is zero (#28982)
  * Chore: Fix SQL related Go variable naming (#28887)
  * MSSQL: Support request cancellation properly (Uses new backendSrv.fetch Observable request API) (#28809)
  * Variables: Fixes loading with a custom all value in url (#28958)
  * Backend: Adds route for well-known change password URL (#28788)
  * docs: fix repeated dashboards link (#29002)
  * LogsPanel: Don't show scroll bars when not needed (#28972)
  * Drone: Fix docs building (#28986)
  * StatPanel: Fixed center of values in edge case scenarios (#28968)
  * Update getting-started-prometheus.md (#28502)
  * Docs: fix relref (#28977)
  * Docs: Minor docs update
  * Docs: Another workflow docs update
  * Docs: Workflow minor edit
  * Docs: Another minor edit
  * Docs: Update PR workflow docs
  * Docs: Update bot docs
  * StatPanels: set default to last (#28617)
  * Tracing: log traceID in request logger (#28952)
  * start tracking usage stats for tempo (#28948)
  * Docs: Update bot docs
  * GrafanaBot: Update labels and commands and adds docs  (#28950)
  * Docs: updates for file-based menu (#28500)
  * Grot: Added command/label to close feature requests with standard message (#28937)
  * GraphNG: Restore focus option (#28946)
  * Docs: Fix links (#28945)
  * Short URL: Cleanup unvisited/stale short URLs (#28867)
  * GraphNG: Using new VizLayout, moving Legend into GraphNG and some other refactorings (#28913)
  * CloudWatch Logs: Change what we use to measure progress (#28912)
  * Chore: use jest without grunt (#28558)
  * Chore: Split Explore redux code into multiple sections (#28819)
  * TestData: Fix issue with numeric inputs in TestData query editor (#28936)
  * setting: Fix tests on Mac (#28886)
  * Plugins signing: Fix docs urls (#28930)
  * Field color: handling color changes when switching panel types (#28875)
  * Variables: make sure that we support both old and new syntax for custom variables. (#28896)
  * CodeEditor: added support for javascript language (#28818)
  * Update CHANGELOG.md (#28928)
  * Plugins: allow override when allowing unsigned plugins (#28901)
  * Chore: Fix spelling issue (#28904)
  * Grafana-UI: LoadingPlaceholder docs (#28874)
  * Gauge: making sure threshold panel json is correct before render (#28898)
  * Chore: Rewrite test in GoConvey to stdlib and testify (#28918)
  * Update documentation-style-guide.md (#28908)
  * Adding terms to glossary (#28884)
  * Devenv: Fix Prometheus basic auth proxy (#28889)
  * API: replace SendLoginLogCommand with LoginHook (#28777)
  * Dashboards / Folders: delete related data (permissions, stars, tags, versions, annotations) when deleting a dashboard or a folder (#28826)
  * Loki: Correct grammar in DerivedFields.tsx (#28885)
  * Docs: Update list of Enterprise plugins (#28882)
  * Live: update centrifuge and the ChannelHandler api (#28843)
  * Update share-panel.md (#28880)
  * CRLF (#28822)
  * PanelHeader: show streaming indicator (and allow unsubscribe)  (#28682)
  * Docs: Plugin signing docs (#28671)
  * Chore: Fix issues reported by staticcheck; enable stylecheck linter (#28866)
  * Elasticsearch: Filter pipeline aggregations from order by options (#28620)
  * Variables: added __user.email to global variable (#28853)
  * Fix titles case and add missing punctuation marks (#28713)
  * VizLayout: Simple viz layout component for legend placement and scaling (#28820)
  * Chore: Fix staticcheck issues (#28860)
  * Chore: Fix staticcheck issues (#28854)
  * Disable selecting enterprise plugins with no license (#28758)
  * Tempo: fix test data source (#28836)
  * Prometheus: fix missing labels from value (#28842)
  * Chore: Fix issues found by staticcheck (#28802)
  * Chore: Remove dead code (#28664)
  * Units: added support to handle negative fractional numbers. (#28849)
  * Variables: Adds variables inspection (#25214)
  * Marked: Upgrade and always sanitize by default (#28796)
  * Currency: add Philippine peso currency (PHP) (#28823)
  * Alert: Remove z-index on Alert component so that it does not overlay ontop of other content (#28834)
  * increase blob column size for encrypted dashboard data (#28831)
  * Gauge: Improve font size auto sizing (#28797)
  * grafana/toolkit: allow builds with lint warnings (#28810)
  * core and grafana/toolkit: Use latest version of grafana-eslint-conifg (#28816)
  * Icon: Replace font awesome icons where possible (#28757)
  * Remove homelinks panel (#28808)
  * StatPanels: Add new calculation option for percentage difference  (#26369)
  * Dashboard: Add Datetime local (No date if today) option in panel axes' units (#28011)
  * Variables: Adds named capture groups to variable regex (#28625)
  * Panel inspect: Interpolate variables in panel inspect title (#28779)
  * grafana/toolkit: Drop console and debugger statements by default when building plugin with toolkit (#28776)
  * Variables: Fixes URL values for dependent variables (#28798)
  * Graph: Fixes event emit function error (#28795)
  * Adds storybook integrity check to drone config (#28785)
  * Live: improve broadcast semantics and avoid double posting (#28765)
  * Events: Remove unused or unnecessary events  (#28783)
  * Docs: added code comments to frontend packages. (#28784)
  * Plugin Dockerfiles: Upgrade Go, golangci-lint, gcloud SDK (#28767)
  * Dependencies: Update angularjs to 1.8.2 (#28736)
  * EventBus: Introduces new event bus with emitter backward compatible interface (#27564)
  * ColorSchemes: Add new color scheme (#28719)
  * Docs: Add NGINX example for using websockets to Loki (#27998)
  * Docs: Made usage of config/configuration consistent #19270 (#28167)
  * Cloudwatch: Fix issue with field calculation transform not working properly with Cloudwatch data (#28761)
  * grafana/toolkit: Extract CHANGELOG when building plugin (#28773)
  * Drone: Upgrade build pipeline tool (#28769)
  * devenv: Upgrade MSSQL Docker image (#28749)
  * Docs: Add docs for InfoBox component (#28705)
  * Reoeragnization. (#28760)
  * gtime: Add ParseDuration function (#28525)
  * Explore: Remove redundant decodeURI and fix urls (#28697)
  * Dashboard: fix view panel mode for Safari / iOS (#28702)
  * Provisioning: Fixed problem with getting started panel being added to custom home dashboard (#28750)
  * LoginPage: Removed auto-capitalization from the login form (#28716)
  * Plugin page: Fix dom validation warning (#28737)
  * Migration: Remove LegacyForms from dashboard folder permissions (#28564)
  * Dependencies: Remove unused dependency (#28711)
  * AlertRuleList: Add keys to alert rule items (#28735)
  * Chore: Pin nginx base image in nginx proxy Dockerfiles (#28730)
  * Drone: Upgrade build-pipeline tool (#28728)
  * TableFilters: Fixes filtering with field overrides (#28690)
  * Templating: Speeds up certain variable queries for Postgres, MySql and MSSql (#28686)
  * Fix typo in unsigned plugin warning (#28709)
  * Chore: Convert sqlstore annotation test from GoConvey to testify (#28715)
  * updates from https://github.com/grafana/grafana/pull/28679 (#28708)
  * Chore: Add some scenario tests for Explore (#28534)
  * Update latest version to 7.3.1 (#28701)
  * Changelog update - 7.3.1 (#28699)
  * Drone: Don't build on Windows for PRs (#28663)
  * Build: changing docs docker image to prevent setting up frontend devenv. (#28670)
  * Prometheus: Fix copy paste behaving as cut and paste (#28622)
  * Loki: Fix error when some queries return zero results (#28645)
  * Chore: allow higher nodejs version than 12 (#28624)
  * TextPanel: Fixes problems where text panel would show old content (#28643)
  * PanelMenu: Fixes panel submenu not being accessible for panels close to the right edge of the screen (#28666)
  * Cloudwatch: Fix duplicate metric data (#28642)
  * Add info about CSV download for Excel in What's new article (#28661)
  * Docs: Describe pipeline aggregation changes in v7.3 (#28660)
  * Plugins: Fix descendent frontend plugin signature validation (#28638)
  * Docker:  use root group in the custom Dockerfile (#28639)
  * Bump rxjs to 6.6.3 (#28657)
  * StatPanel: Fixed value being under graph and reduced likley hood for white and dark value text mixing (#28641)
  * Table: Fix image cell mode so that it works with value mappings (#28644)
  * Build: support custom build tags (#28609)
  * Plugin signing: Fix copy on signed plugin notice (#28633)
  * Dashboard: Fix navigation from one SoloPanelPage to another one (#28578)
  * CloudWatch: Improve method name, performance optimization (#28632)
  * Developer guide: Update wrt. Windows (#28559)
  * Docs: Update graph panel for tabs (#28552)
  * update latest.json (#28603)
  * Docs: data source insights (#28542)
  * Field config API: add slider editor (#28007)
  * changelog: update for 7.3.0 (#28602)
  * Update uPlot to 1.2.2 and align timestamps config with new uPLot API (#28569)
  * Live: updated the reference to use lazy loaded Monaco in code editor. (#28597)
  * Dashboard: Allow add panel for viewers_can_edit (#28570)
  * Docs: Data source provisioning and sigV4 (#28593)
  * Docs: Additional 7.3 upgrade notes (#28592)
  * CI: Add GCC to Windows Docker image (#28562)
  * CloudWatch Logs queue and websocket support (#28176)
  * Explore/Loki: Update docs and cheatsheet (#28541)
  * Grafana-UI: Add Card component (#28216)
  * AddDatasource: Improve plugin categories (#28584)
  * StatPanel: Fixes BizChart error max: yyy should not be less than min zzz (#28587)
  * docs: a few tweaks for clarity and readability (#28579)
  * API: Reducing some api docs errors (#28575)
  * Grafana-UI: ContextMenu docs (#28508)
  * Short URL: Update last seen at when visiting a short URL (#28565)
  * Fix backend build on Windows (#28557)
  * add value prop (#28561)
  * Plugin signing: UI information (#28469)
  * Use fetch API in InfluxDB data source (#28555)
  * PanelEdit: Prevent the preview pane to be resized further than window height (#28370)
  * Docs: Update generic-oauth.md (#28517)
  * GCS image uploader: Add tests (#28521)
  * Move metrics collector queries to config (#28549)
  * Plugins: Fix plugin URL paths on Windows (#28548)
  * API: add login username in SendLoginLogCommand (#28544)
  * AzureMonitor: Support decimal (as float64) type in analytics/logs (#28480)
  * Auth: Fix SigV4 request verification step for Amazon Elasticsearch Service (#28481)
  * Grafana/ui: auto focus threshold editor input (#28360)
  * Docs: SigV4 What's New and AWS Elasticsearch documentation (#28506)
  * Drone: Upgrade build pipeline tool (#28533)
  * Drone: Refactor version branch pipeline logic (#28531)
  * Drone: Upgrade build-pipeline tool (#28520)
  * Docs: Update field color scheme docs and 7.3 what's new (#28496)
  * Templating: Custom variable edit UI, change text input into textarea  (#28312) (#28322)
  * Currency: Adds Indonesian IDR currency (#28363)
  * Chore: Fix flaky sqlstore annotation test (#28527)
  * Checkbox: Fix component sample typo (#28518)
  * Image uploader: Fix uploading of images to GCS (#26493)
  * OAuth: Support Forward OAuth Identity for backend data source plugins (#27055)
  * Updated documentation style guide  (#28488)
  * Cloud Monitoring: Fix help section for aliases (#28499)
  * Docs: what's new in enterprise 7.3 (#28472)
  * Plugins: Track plugin signing errors and expose them to the frontend (#28219)
  * Elasticsearch: Fix handling of errors when testing data source (#28498)
  * Auth: Should redirect to login when anonymous enabled and URL with different org than anonymous specified  (#28158)
  * Drone: Don't build Windows installer for version branches (#28494)
  * Docs: Grafana Enterprise auditing feature (#28356)
  * Drone: Add version branch pipeline (#28490)
  * Getting Started section rehaul (#28090)
  * Docs: Add survey content (#28446)
  * Docs: Update prometheus.md (#28483)
  * Docs: Add view settings and view stats (#28155)
  * Remove entry from 7.3.0-beta2 Changelog (#28478)
  * Circle: Remove release pipeline (#28474)
  * Update latest.json (#28476)
  * Switch default version to Graphite 1.1 (#28471)
  * Plugin page: update readme icon (#28465)
  * Chore: Update changelog (#28473)
  * Explore: parse time range fix (#28467)
  * Alerting: Log alert warnings for obsolete notifiers when extracting alerts and remove spammy error (#28162)
  * Shorten url: Unification across Explore and Dashboards (#28434)
  * Explore: Support wide data frames (#28393)
  * Docs: updated cmd to build docs locally to generate docs prior to building site. (#28371)
  * Live: support real time measurements (alpha) (#28022)
  * CloudWatch/Athena - valid metrics and dimensions. (#28436)
  * Chore: Use net.JoinHostPort (#28421)
  * Chore: Upgrade grafana-eslint to latest (#28444)
  * Fix cut off icon (#28442)
  * Docs: Add shared (#28411)
  * Loki: Visually distinguish error logs for LogQL2 (#28359)
  * Database; Remove database metric feature flag and update changelog (#28438)
  * TestData: multiple arrow requests should return multiple frames (#28417)
  * Docs: Test survey code (#28437)
  * Docs: improved github action that syncs docs to website (#28277)
  * update latest.json with latest stable version (#28433)
  * 7.2.2 changelog update (#28406)
  * plugins: Don't exit on duplicate plugin (#28390)
  * API: Query database from /api/health endpoint (#28349)
  * Chore: Fix conversion of a 64-bit integer to a lower bit size type uint (#28425)
  * Prometheus: fix parsing of infinite sample values (#28287) (#28288)
  * Chore: Rewrite some tests to use testify (#28420)
  * Plugins: do not remount app plugin on nav change (#28105)
  * App Plugins: Add backend support (#28272)
  * Chore: react hooks eslint fixes in grafana-ui (#28026)
  * ci-e2e: Add Git (#28410)
  * TestData: Remove useEffect that triggeres query on component load (#28321)
  * FieldColor: Remove inverted color scheme (#28408)
  * Chore: Set timezone for tests to non utc. (#28405)
  * Chore: fix jsdoc desc and return (#28383)
  * Docs: Fixing v51 link (#28396)
  * fixes windows crlf warning (#28346)
  * Grafana/ui: pass html attributes to segment (#28316)
  * Alerting: Return proper status code when trying to create alert notification channel with duplicate name or uid (#28043)
  * OAuth: Able to skip auto login (#28357)
  * CloudWatch: Fix custom metrics (#28391)
  * Docs: Adds basic frontend data request concepts (#28253)
  * Instrumentation: Add histogram for request duration (#28364)
  * remove status label from histogram (#28387)
  * OAuth: configurable user name attribute (#28286)
  * Component/NewsPanel: Add rel="noopener" to NewsPanel links (#28379)
  * Webpack: Split out unicons and bizcharts (#28374)
  * Explore: Fix date formatting in url for trace logs link (#28381)
  * Docs: Add activate-license (#28156)
  * Instrumentation: Add counters and histograms for database queries (#28236)
  * Docs: Make tables formatting more consistent (#28164)
  * CloudWatch: Adding support for additional Amazon CloudFront metrics (#28378)
  * Add unique ids to query editor fields (#28376)
  * Plugins: Compose filesystem paths with filepath.Join (#28375)
  * Explore: Minor tweaks to exemplars marble (#28366)
  * Instrumentation: Adds environment_info metric  (#28355)
  * AzureMonitor: Fix capitalization of NetApp 'volumes' namespace (#28369)
  * ColorSchemes: Adds more color schemes and text colors that depend on the background (#28305)
  * Automation: Update backport github action trigger (#28352)
  * Dashboard links: Places drop down list so it's always visible (#28330)
  * Docs: Add missing records from grafana-ui 7.2.1 CHANGELOG (#28302)
  * Templating: Replace all '$tag' in tag values query (#28343)
  * Docs: Add docs for valuepicker (#28327)
  * Git: Create .gitattributes for windows line endings (#28340)
  * Update auth-proxy.md (#28339)
  * area/grafana/toolkit: update e2e docker image (#28335)
  * AlertingNG: remove warn/crit from eval prototype (#28334)
  * Automation: Tweaks to more info message (#28332)
  * Loki: Run instant query only when doing metric query (#28325)
  * SAML: IdP-initiated SSO docs (#28280)
  * IssueTriage: Needs more info automation and messages (#28137)
  * GraphNG: Use AxisSide enum (#28320)
  * BackendSrv: Fixes queue countdown when unsubscribe is before response (#28323)
  * Automation: Add backport github action (#28318)
  * Build(deps): Bump http-proxy from 1.18.0 to 1.18.1 (#27507)
  * Bump handlebars from 4.4.3 to 4.7.6 (#27416)
  * Bump tree-kill from 1.2.1 to 1.2.2 (#27405)
  * Loki: Base maxDataPoints limits on query type (#28298)
  * Explore: respect min_refresh_interval (#27988)
  * Drone: Use ${DRONE_TAG} in release pipelines, since it should work (#28299)
  * Graph NG: fix toggling queries and extract Graph component from graph3 panel (#28290)
  * fix: for graph size not taking up full height or width
  * should only ignore the file in the grafana mixin root folder (#28306)
  * Drone: Fix grafana-mixin linting (#28308)
  * SQLStore: Run tests as integration tests (#28265)
  * Chore: Add cloud-middleware as code owners (#28310)
  * API: Fix short URLs (#28300)
  * CloudWatch: Add EC2CapacityReservations Namespace (#28309)
  * Jaeger: timeline collapser to show icons (#28284)
  * update latest.json with latest beta version (#28293)
  * Update changelog (#28292)
  * Docs : - Added period (#28260)
  * Add monitoring mixing for Grafana (#28285)
  * Chore: Update package.json (#28291)
  * Drone: Fix enterprise release pipeline (#28289)
  * Alerting: Append appSubUrl to back button on channel form (#28282)
- Rework package Makefile & README now that Grunt is gone
* Mon Jan  4 2021 dmueller@suse.com
- Update to version 7.3.6:
  * fixes for saml vulnerability
  * [v7.3.x] Fix: Correct panel edit uistate migration (#29413) (#29711)
  * PanelEdit: Prevent the preview pane to be resized further than window height (#28370) (#29726)
  * Fix: Migrate Panel edit uiState percentage strings to number (#29412) (#29723)
  * "Release: Updated versions in package to 7.3.5" (#29710)
  * Chore: upgrading y18n to 4.0.1 for security reasons (#29523) (#29709)
  * Panel: making sure we support all versions of chrome when detecting position of click event. (#29544) (#29708)
  * PanelEdit: making sure the correct datasource query editor is being rendered. (#29500) (#29707)
  * [v7.3.x] Auth: Add SigV4 header allowlist to reduce chances of verification issues (#29705)
  * Alerting: Use correct time series name override from frame fields (#29693) (#29698)
  * CloudWatch: namespace in search expression should be quoted if match exact is enabled #29109 (#29563) (#29687)
  * Adds go dep used by an Enterprise feature.  (#29645) (#29690)
  * instrumentation: align label name with our other projects (#29514) (#29685)
  * Instrumentation: Add examplars for request histograms (#29357) (#29682)
  * Login: Fixes typo in tooltip (#29604) (#29606)
  * fixes bug with invalid handler name for metrics (#29529) (#29532)
  * AzureMonitor: Unit MilliSeconds naming (#29399) (#29526)
  * Alarting: fix alarm messages in dingding (Fixes #29470) (#29482) (#29527)
  * Bug: trace viewer doesn't show more than 300 spans (#29377) (#29504)
  * Prometheus: don't override displayName property (#29441) (#29488)
  * resolve conflicts (#29415)
  * Drone: Upgrade build pipeline tool (#29365) (#29368)
  * Drone: Upload artifacts for release branch builds (#29297) (#29364)
  * Drone: Execute artifact publishing for both editions in parallel during release (#29362) (#29363)
  * Drone: Publish NPM packages after Storybook to avoid race condition (#29340) (#29343)
  * Docs: Fix editor role and alert notification channel description (#29301) (#29337)
  * "Release: Updated versions in package to 7.3.4" (#29336)
  * Security: Fixes minor security issue with alert notification webhooks that allowed GET & DELETE requests #29330 (#29335)
  * Backport of InfluxDB: update flux library and support boolean label values #29333
  * ReleaseNotes: Update link in package.json (#29328)
  * Login: Fixes redirect url encoding issues of # %%23 being unencoded after login (#29299) (#29323)
  * Drone: Upgrade build pipeline tool (#29308) (#29309)
  * Annotations: fixing so when changing annotations query links submenu will be updated. (#28990) (#29285)
  * Dashboard: Fixes kiosk state after being redirected to login page and back (#29273) (#29278)
  * Increase search limit on team add user and improve placeholder (#29258) (#29261)
  * Drone: Sync with master (#29205)
  * Drone: Fix publish-packages invocation (#29179) (#29184)
  * Chore: Upgrade grafana/build-ci-deploy image to latest Go (#29171) (#29180)
  * Table: Fix incorrect condtition for rendering table filter (#29165) (#29181)
  * DashboardLinks: will only refresh dashboard search when changing tags for link. (#29040) (#29177)
  * Drone: Upgrade build pipeline tool and build image (#29161) (#29162)
  * Release: Updated versions in package to 7.3.3 (#29126)
  * git cherry-pick -x 0f3bebb38daa488e108881ce17d4f68167a834e6 (#29155)
  * Build: support custom build tags (#28609) (#29128)
  * Revert "Graph: Fixes stacking issues like floating bars when data is not aligned  (#29051) (#29088)" (#29151)
  * Provisioning: always pin app to the sidebar when enabled (#29084) (#29146)
  * build paths in an os independent way (#29143) (#29147)
  * Chore: Upgrade Go dev tools (#29124) (#29132)
  * Automatin: set node version
  * Automation: Adding version bump action
  * Drone: Fix Drone config verification for enterprise on Windows (#29118) (#29119)
  * [v7.3.x] Drone: Verify Drone config at beginning of pipelines (#29111)
  * Test Datasource/Bug: Fixes division by zero in csv metric values scenario (#29029) (#29068)
  * [v7.3.x] StatPanel: Fixes hanging issue when all values are zero (#29087)
  * Data source proxy: Convert 401 from data source to 400 (#28962) (#29095)
  * Graph: Fixes stacking issues like floating bars when data is not aligned  (#29051) (#29088)
  * Auth: Enable more complete credential chain for SigV4 default SDK auth option (#29065) (#29086)
  * Fix for multi-value template variable for project selector (#29042) (#29054)
  * Thresholds: Fixes color assigned to null values (#29010) (#29018)
  * [v7.3.x] Chore: Bump build pipeline version (#29025)
  * Release v7.3.2 (#29024)
  * Fix conflict (#29020)
  * StatPanels: Fixes auto min max when latest value is zero (#28982) (#29007)
  * Tracing: Add setting for sampling server (#29011) (#29015)
  * Gauge: making sure threshold panel json is correct before render (#28898) (#28984)
  * Variables: make sure that we support both old and new syntax for custom variables. (#28896) (#28985)
  * Explore: Remove redundant decodeURI and fix urls (#28697) (#28963)
  * [v7.3.x] Drone: Fix docs building (#28987)
  * Alerting: Append appSubUrl to back button on channel form (#28282) (#28983)
  * Plugins: allow override when allowing unsigned plugins (#28901) (#28927)
  * CloudWatch Logs: Change what we use to measure progress (#28912) (#28964)
  * Tracing: log traceID in request logger (#28952) (#28959)
  * Panel inspect: Interpolate variables in panel inspect title (#28779) (#28801)
  * UsageStats: start tracking usage stats for tempo (#28948) (#28951)
  * Short URL: Cleanup unvisited/stale short URLs (#28867) (#28944)
  * Plugins signing: Fix docs urls (#28930) (#28934)
  * Chore: Fix spelling issue (#28904) (#28925)
  * API: replace SendLoginLogCommand with LoginHook (#28777) (#28891)
  * Elasticsearch: Exclude pipeline aggregations from order by options (#28620) (#28873)
  * Dashboards / Folders: delete related data (permissions, stars, tags, versions, annotations) when deleting a dashboard or a folder (#28826) (#28890)
  * Disable selecting enterprise plugins with no license (#28758) (#28859)
  * Tempo: fix test data source (#28836) (#28856)
  * Prometheus: fix missing labels from value (#28842) (#28855)
  * Units: added support to handle negative fractional numbers. (#28849) (#28851)
  * increase blob column size for encrypted dashboard data (#28831) (#28832)
  * Gauge: Improve font size auto sizing (#28797) (#28828)
  * Variables: Fixes URL values for dependent variables (#28798) (#28800)
  * grafana/toolkit: Extract CHANGELOG when building plugin (#28773) (#28774)
  * Templating: Custom variable edit UI, change text input into textarea  (#28312) (#28322) (#28704)
  * Cloudwatch: Fix issue with field calculation transform not working properly with Cloudwatch data (#28761) (#28775)
  * Plugin page: Fix dom validation warning (#28737) (#28741)
  * Dashboard: fix view panel mode for Safari / iOS (#28702) (#28755)
  * Fix typo in unsigned plugin warning (#28709) (#28722)
  * TableFilters: Fixes filtering with field overrides (#28690) (#28727)
  * Templating: Speeds up certain variable queries for Postgres, MySql and MSSql (#28686) (#28726)
  * Prometheus: Fix copy paste behaving as cut and paste (#28622) (#28691)
* Mon Nov  9 2020 Stefano Torresi <stefano.torresi@suse.com>
- Update packaging
  * avoid systemd and shadow hard requirements
  * Require the user from a new dedicated 'system-user-grafana' sibling package
  * avoid pinning to a specific Go version in the spec file
* Thu Nov  5 2020 witold.bedyk@suse.com
- Update to version 7.3.1:
  * Breaking changes
  - CloudWatch: The AWS CloudWatch data source's authentication scheme has changed. See the upgrade notes for details and how this may affect you.
  - Units: The date time units `YYYY-MM-DD HH:mm:ss` and `MM/DD/YYYY h:mm:ss a` have been renamed to `Datetime ISO` and `Datetime US` respectively.
  * Features / Enhancements
  - AzureMonitor: Support decimal (as float64) type in analytics/logs.
  - Add monitoring mixing for Grafana.
  - CloudWatch: Missing Namespace AWS/EC2CapacityReservations.
  - CloudWatch: Add support for AWS DirectConnect virtual interface metrics and add missing dimensions.
  - CloudWatch: Adding support for Amazon ElastiCache Redis metrics.
  - CloudWatch: Adding support for additional Amazon CloudFront metrics.
  - CloudWatch: Re-implement authentication.
  - Elasticsearch: Support multiple pipeline aggregations for a query.
  - Prometheus: Add time range parameters to labels API.
  - Loki: Visually distinguish error logs for LogQL2.
  - Api: Add /healthz endpoint for health checks.
  - API: Enrich add user to org endpoints with user ID in the response.
  - API: Enrich responses and improve error handling for alerting API endpoints.
  - Elasticsearch: Add support for date_nanos type.
  - Elasticsearch: Allow fields starting with underscore.
  - Elasticsearch: Increase maximum geohash aggregation precision to 12.
  - Postgres: Support request cancellation properly (Uses new backendSrv.fetch Observable request API).
  - Provisioning: Remove provisioned dashboards without parental reader.
  - API: Return ID of the deleted resource for dashboard, datasource and folder DELETE endpoints.
  - API: Support paging in the admin orgs list API.
  - API: return resource ID for auth key creation, folder permissions update and user invite complete endpoints.
  - BackendSrv: Uses credentials, deprecates withCredentials & defaults to same-origin.
  - CloudWatch: Update list of AmazonMQ metrics and dimensions.
  - Cloudwatch: Add Support for external ID in assume role.
  - Cloudwatch: Add af-south-1 region.
  - DateFormats: Default ISO & US formats never omit date part even if date is today (breaking change).
  - Explore: Transform prometheus query to elasticsearch query.
  - InfluxDB/Flux: Increase series limit for Flux datasource.
  - InfluxDB: exclude result and table column from Flux table results.
  - InfluxDB: return a table rather than an error when timeseries is missing time.
  - Loki: Add scopedVars support in legend formatting for repeated variables.
  - Loki: Re-introduce running of instant queries.
  - Loki: Support request cancellation properly (Uses new backendSrv.fetch Observable request API).
  - MixedDatasource: Shows retrieved data even if a data source fails.
  - Postgres: Support Unix socket for host.
  - Prometheus: Add scopedVars support in legend formatting for repeated variables.
  - Prometheus: Support request cancellation properly (Uses new backendSrv.fetch Observable request API).
  - Prometheus: add $__rate_interval variable.
  - Table: Adds column filtering.
  - grafana-cli: Add ability to read password from stdin to reset admin password.
* Fri Sep 18 2020 jcavalheiro@suse.com
- Update to version 7.1.5:
  * Features / Enhancements
  - Stats: Stop counting the same user multiple times.
  - Field overrides: Filter by field name using regex.
  - AzureMonitor: map more units.
  - Explore: Don't run queries on datasource change.
  - Graph: Support setting field unit & override data source (automatic) unit.
  - Explore: Unification of logs/metrics/traces user interface
  - Table: JSON Cell should try to convert strings to JSON
  - Variables: enables cancel for slow query variables queries.
  - TimeZone: unify the time zone pickers to one that can rule them all.
  - Search: support URL query params.
  - Grafana-UI: Add FileUpload.
  - TablePanel: Sort numbers correctly.
  * Bug fixes
  - Alerting: remove LongToWide call in alerting.
  - AzureMonitor: fix panic introduced in 7.1.4 when unit was unspecified and alias was used.
  - Variables: Fixes issue with All variable not being resolved.
  - Templating: Fixes so texts show in picker not the values.
  - Templating: Templating: Fix undefined result when using raw interpolation format
  - TextPanel: Fix content overflowing panel boundaries.
  - StatPanel: Fix stat panel display name not showing when explicitly set.
  - Query history: Fix search filtering if null value.
  - Flux: Ensure connections to InfluxDB are closed.
  - Dashboard: Fix for viewer can enter panel edit mode by modifying url (but cannot not save anything).
  - Prometheus: Fix prom links in mixed mode.
  - Sign In Use correct url for the Sign In button.
  - StatPanel: Fixes issue with name showing for single series / field results
  - BarGauge: Fix space bug in single series mode.
  - Auth: Fix POST request failures with anonymous access
  - Templating: Fix recursive loop of template variable queries when changing ad-hoc-variable
  - Templating: Fixed recursive queries triggered when switching dashboard settings view
  - GraphPanel: Fix annotations overflowing panels.
  - Prometheus: Fix performance issue in processing of histogram labels.
  - Datasources: Handle URL parsing error.
  - Security: Use Header.Set and Header.Del for X-Grafana-User header.
  * Changes in spec file
  - Fix golang version = 1.14 to avoid dependency conflicts on some OBS projects
* Fri Jun  5 2020 jcavalheiro@suse.com
- Update to version 7.0.3
  * Features / Enhancements
  - Stats: include all fields. #24829, @ryantxu
  - Variables: change VariableEditorList row action Icon to IconButton. #25217, @hshoff
  * Bug fixes
  - Cloudwatch: Fix dimensions of DDoSProtection. #25317, @papagian
  - Configuration: Fix env var override of sections containing hyphen. #25178, @marefr
  - Dashboard: Get panels in collapsed rows. #25079, @peterholmberg
  - Do not show alerts tab when alerting is disabled. #25285, @dprokop
  - Jaeger: fixes cascader option label duration value. #25129, @Estrax
  - Transformations: Fixed Transform tab crash & no update after adding first transform. #25152, @torkelo
- Update to version 7.0.2
  * Bug fixes
  - Security: Urgent security patch release to fix CVE-2020-13379
* Mon Jun  1 2020 jcavalheiro@suse.com
- Update to version 7.0.1
  * Features / Enhancements
  - Datasource/CloudWatch: Makes CloudWatch Logs query history more readable. #24795, @kaydelaney
  - Download CSV: Add date and time formatting. #24992, @ryantxu
  - Table: Make last cell value visible when right aligned. #24921, @peterholmberg
  - TablePanel: Adding sort order persistance. #24705, @torkelo
  - Transformations: Display correct field name when using reduce transformation. #25068, @peterholmberg
  - Transformations: Allow custom number input for binary operations. #24752, @ryantxu
  * Bug fixes
  - Dashboard/Links: Fixes dashboard links by tags not working. #24773, @KamalGalrani
  - Dashboard/Links: Fixes open in new window for dashboard link. #24772, @KamalGalrani
  - Dashboard/Links: Variables are resolved and limits to 100. #25076, @hugohaggmark
  - DataLinks: Bring back variables interpolation in title. #24970, @dprokop
  - Datasource/CloudWatch: Field suggestions no longer limited to prefix-only. #24855, @kaydelaney
  - Explore/Table: Keep existing field types if possible. #24944, @kaydelaney
  - Explore: Fix wrap lines toggle for results of queries with filter expression. #24915, @ivanahuckova
  - Explore: fix undo in query editor. #24797, @zoltanbedi
  - Explore: fix word break in type head info. #25014, @zoltanbedi
  - Graph: Legend decimals now work as expected. #24931, @torkelo
  - LoginPage: Fix hover color for service buttons. #25009, @tskarhed
  - LogsPanel: Fix scrollbar. #24850, @ivanahuckova
  - MoveDashboard: Fix for moving dashboard caused all variables to be lost. #25005, @torkelo
  - Organize transformer: Use display name in field order comparer. #24984, @dprokop
  - Panel: shows correct panel menu items in view mode. #24912, @hugohaggmark
  - PanelEditor Fix missing labels and description if there is only single option in category. #24905, @dprokop
  - PanelEditor: Overrides name matcher still show all original field names even after Field default display name is specified. #24933, @torkelo
  - PanelInspector: Makes sure Data display options are visible. #24902, @hugohaggmark
  - PanelInspector: Hides unsupported data display options for Panel type. #24918, @hugohaggmark
  - PanelMenu: Make menu disappear on button press. #25015, @tskarhed
  - Postgres: Fix add button. #25087, @phemmer
  - Prometheus: Fix recording rules expansion. #24977, @ivanahuckova
  - Stackdriver: Fix creating Service Level Objectives (SLO) datasource query variable. #25023, @papagian
* Sun May 24 2020 Joao Cavalheiro <jcavalheiro@suse.com>
- Update to version 7.0.0
  * Breaking changes
  - Removed PhantomJS: PhantomJS was deprecated in Grafana v6.4 and starting from Grafana v7.0.0, all PhantomJS support has been removed. This means that Grafana no longer ships with a built-in image renderer, and we advise you to install the Grafana Image Renderer plugin.
  - Dashboard: A global minimum dashboard refresh interval is now enforced and defaults to 5 seconds.
  - Interval calculation: There is now a new option Max data points that controls the auto interval $__interval calculation. Interval was previously calculated by dividing the panel width by the time range. With the new max data points option it is now easy to set $__interval to a dynamic value that is time range agnostic. For example if you set Max data points to 10 Grafana will dynamically set $__interval by dividing the current time range by 10.
  - Datasource/Loki: Support for deprecated Loki endpoints has been removed.
  - Backend plugins: Grafana now requires backend plugins to be signed, otherwise Grafana will not load/start them. This is an additional security measure to make sure backend plugin binaries and files haven't been tampered with. Refer to Upgrade Grafana for more information.
  - @grafana/ui: Forms migration notice, see @grafana/ui changelog
  - @grafana/ui: Select API change for creating custom values, see @grafana/ui changelog
    + Deprecation warnings
  - Scripted dashboards is now deprecated. The feature is not removed but will be in a future release. We hope to address the underlying requirement of dynamic dashboards in a different way. #24059
  - The unofficial first version of backend plugins together with usage of grafana/grafana-plugin-model is now deprecated and support for that will be removed in a future release. Please refer to backend plugins documentation for information about the new officially supported backend plugins.
  * Features / Enhancements
  - Backend plugins: Log deprecation warning when using the unofficial first version of backend plugins. #24675, @marefr
  - Editor: New line on Enter, run query on Shift+Enter. #24654, @davkal
  - Loki: Allow multiple derived fields with the same name. #24437, @aocenas
  - Orgs: Add future deprecation notice. #24502, @torkelo
  * Bug Fixes
  - @grafana/toolkit: Use process.cwd() instead of PWD to get directory. #24677, @zoltanbedi
  - Admin: Makes long settings values line break in settings page. #24559, @hugohaggmark
  - Dashboard: Allow editing provisioned dashboard JSON and add confirmation when JSON is copied to dashboard. #24680, @dprokop
  - Dashboard: Fix for strange "dashboard not found" errors when opening links in dashboard settings. #24416, @torkelo
  - Dashboard: Fix so default data source is selected when data source can't be found in panel editor. #24526, @mckn
  - Dashboard: Fixed issue changing a panel from transparent back to normal in panel editor. #24483, @torkelo
  - Dashboard: Make header names reflect the field name when exporting to CSV file from the the panel inspector. #24624, @peterholmberg
  - Dashboard: Make sure side pane is displayed with tabs by default in panel editor. #24636, @dprokop
  - Data source: Fix query/annotation help content formatting. #24687, @AgnesToulet
  - Data source: Fixes async mount errors. #24579, @Estrax
  - Data source: Fixes saving a data source without failure when URL doesn't specify a protocol. #24497, @aknuds1
  - Explore/Prometheus: Show results of instant queries only in table. #24508, @ivanahuckova
  - Explore: Fix rendering of react query editors. #24593, @ivanahuckova
  - Explore: Fixes loading more logs in logs context view. #24135, @Estrax
  - Graphite: Fix schema and dedupe strategy in rollup indicators for Metrictank queries. #24685, @torkelo
  - Graphite: Makes query annotations work again. #24556, @hugohaggmark
  - Logs: Clicking "Load more" from context overlay doesn't expand log row. #24299, @kaydelaney
  - Logs: Fix total bytes process calculation. #24691, @davkal
  - Org/user/team preferences: Fixes so UI Theme can be set back to Default. #24628, @AgnesToulet
  - Plugins: Fix manifest validation. #24573, @aknuds1
  - Provisioning: Use proxy as default access mode in provisioning. #24669, @bergquist
  - Search: Fix select item when pressing enter and Grafana is served using a sub path. #24634, @tskarhed
  - Search: Save folder expanded state. #24496, @Clarity-89
  - Security: Tag value sanitization fix in OpenTSDB data source. #24539, @rotemreiss
  - Table: Do not include angular options in options when switching from angular panel. #24684, @torkelo
  - Table: Fixed persisting column resize for time series fields. #24505, @torkelo
  - Table: Fixes Cannot read property subRows of null. #24578, @hugohaggmark
  - Time picker: Fixed so you can enter a relative range in the time picker without being converted to absolute range. #24534, @mckn
  - Transformations: Make transform dropdowns not cropped. #24615, @dprokop
  - Transformations: Sort order should be preserved as entered by user when using the reduce transformation. #24494, @hugohaggmark
  - Units: Adds scale symbol for currencies with suffixed symbol. #24678, @hugohaggmark
  - Variables: Fixes filtering options with more than 1000 entries. #24614, @hugohaggmark
  - Variables: Fixes so Textbox variables read value from url. #24623, @hugohaggmark
  - Zipkin: Fix error when span contains remoteEndpoint. #24524, @aocenas
  - SAML: Switch from email to login for user login attribute mapping (Enterprise)
- Update Makefile and spec file
  * Remove phantomJS patch from Makefile
  * Fix multiline strings in Makefile
  * Exclude s390 from SLE12 builds, golang 1.14 is not built for s390
* Thu May 14 2020 Enno Gotthold <egotthold@suse.com>
- Add instructions for patching the Grafana javascript frontend.
* Tue May  5 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- BuildRequires golang(API) instead of go metapackage version range
  * BuildRequires:  golang(API) >= 1.14   from
    BuildRequires:  ( go >= 1.14 with go < 1.15 )
* Tue Apr 28 2020 Enno Gotthold <egotthold@suse.com>
- Update to version 6.7.3
  - This version fixes bsc#1170557 and its corresponding CVE-2020-12245
  - Admin: Fix Synced via LDAP message for non-LDAP external users. #23477, @alexanderzobnin
  - Alerting: Fixes notifications for alerts with empty message in Google Hangouts notifier. #23559, @hugohaggmark
  - AuthProxy: Fixes bug where long username could not be cached.. #22926, @jcmcken
  - Dashboard: Fix saving dashboard when editing raw dashboard JSON model. #23314, @peterholmberg
  - Dashboard: Try to parse 8 and 15 digit numbers as timestamps if parsing of time range as date fails. #21694, @jessetan
  - DashboardListPanel: Fixed problem with empty panel after going into edit mode (General folder filter being automatically added) . #23426, @torkelo
  - Data source: Handle datasource withCredentials option properly. #23380, @hvtuananh
  - Security: Fix annotation popup XSS vulnerability. #23813, @torkelo
  - Server: Exit Grafana with status code 0 if no error. #23312, @aknuds1
  - TablePanel: Fix XSS issue in header column rename (backport). #23814, @torkelo
  - Variables: Fixes error when setting adhoc variable values. #23580, @hugohaggmark
* Mon Apr  6 2020 egotthold@suse.com
- Update to version 6.7.2:
  (see installed changelog for the full list of changes)
  - BackendSrv: Adds config to response to fix issue for external plugins that used this property . #23032, @torkelo
  - Dashboard: Fixed issue with saving new dashboard after changing title . #23104, @dprokop
  - DataLinks: make sure we use the correct datapoint when dataset contains null value.. #22981, @mckn
  - Plugins: Fixed issue for plugins that imported dateMath util . #23069, @mckn
  - Security: Fix for dashboard snapshot original dashboard link could contain XSS vulnerability in url. #23254, @torkelo
  - Variables: Fixes issue with too many queries being issued for nested template variables after value change. #23220, @torkelo
  - Plugins: Expose promiseToDigest. #23249, @torkelo
  - Reporting (Enterprise): Fixes issue updating a report created by someone else
* Fri Mar 20 2020 Johannes Kastl <kastl@b1-systems.de>
- update to 6.7.1:
  (see installed changelog for the full list of changes)
  Bug Fixes
  - Azure: Fixed dropdowns not showing current value. #22914, @torkelo
  - BackendSrv: only add content-type on POST, PUT requests. #22910, @hugohaggmark
  - Panels: Fixed size issue with panel internal size when exiting panel edit mode. #22912, @torkelo
  - Reporting: fixes migrations compatibility with mysql (Enterprise)
  - Reporting: Reduce default concurrency limit to 4 (Enterprise)
* Fri Mar 20 2020 Johannes Kastl <kastl@b1-systems.de>
- update to 6.7.0:
  (see installed changelog for the full list of changes)
  Bug Fixes
  - AngularPanels: Fixed inner height calculation for angular panels . #22796, @torkelo
  - BackendSrv: makes sure provided headers are correctly recognized and set. #22778, @hugohaggmark
  - Forms: Fix input suffix position (caret-down in Select) . #22780, @torkelo
  - Graphite: Fixed issue with query editor and next select metric now showing after selecting metric node . #22856, @torkelo
  - Rich History: UX adjustments and fixes. #22729, @ivanahuckova
- update to 6.7.0-beta1:
  Breaking changes
  - Slack: Removed Mention setting and instead introduce Mention Users, Mention Groups, and Mention Channel. The first two settings require user and group IDs, respectively. This change was necessary because the way of mentioning via the Slack API changed and mentions in Slack notifications no longer worked.
  - Alerting: Reverts the behavior of diff and percent_diff to not always be absolute. Something we introduced by mistake in 6.1.0. Alerting now support diff(), diff_abs(), percent_diff() and percent_diff_abs(). #21338
  - Notice about changes in backendSrv for plugin authors
    In our mission to migrate away from AngularJS to React we have removed all AngularJS dependencies in the core data retrieval service backendSrv.
    Removing the AngularJS dependencies in backendSrv has the unfortunate side effect of AngularJS digest no longer being triggered for any request made with backendSrv. Because of this, external plugins using backendSrv directly may suffer from strange behaviour in the UI.
    To remedy this issue, as a plugin author you need to trigger the digest after a direct call to backendSrv.
  Bug Fixes
    API: Fix redirect issues. #22285, @papagian
    Alerting: Don't include image_url field with Slack message if empty. #22372, @aknuds1
    Alerting: Fixed bad background color for default notifications in alert tab . #22660, @krvajal
    Annotations: In table panel when setting transform to annotation, they will now show up right away without a manual refresh. #22323, @krvajal
    Azure Monitor: Fix app insights source to allow for new __timeFrom and __timeTo. #21879, @ChadNedzlek
    BackendSrv: Fixes POST body for form data. #21714, @hugohaggmark
    CloudWatch: Credentials cache invalidation fix. #22473, @sunker
    CloudWatch: Expand alias variables when query yields no result. #22695, @sunker
    Dashboard: Fix bug with NaN in alerting. #22053, @a-melnyk
    Explore: Fix display of multiline logs in log panel and explore. #22057, @thomasdraebing
    Heatmap: Legend color range is incorrect when using custom min/max. #21748, @sv5d
    Security: Fixed XSS issue in dashboard history diff . #22680, @torkelo
    StatPanel: Fixes base color is being used for null values .
    [#22646], @torkelo
* Fri Mar  6 2020 kastl@b1-systems.de
- Update to version 6.6.2:
  (see installed changelog for the full list of changes)
* Fri Mar  6 2020 kastl@b1-systems.de
- Update to version 6.6.1:
  (see installed changelog for the full list of changes)
* Thu Mar  5 2020 kastl@b1-systems.de
- Update to version 6.6.0:
  (see installed changelog for the full list of changes)
* Thu Mar  5 2020 kastl@b1-systems.de
- Update to version 6.5.3:
  (see installed changelog for the full list of changes)
* Thu Mar  5 2020 kastl@b1-systems.de
- Update to version 6.5.2:
  (see installed changelog for the full list of changes)
* Thu Mar  5 2020 kastl@b1-systems.de
- Update to version 6.5.1:
  (see installed changelog for the full list of changes)
* Thu Mar  5 2020 kastl@b1-systems.de
- Update to version 6.5.0
  (see installed changelog for the full list of changes)
* Thu Mar  5 2020 kastl@b1-systems.de
- Update to version 6.4.5:
  * Create version 6.4.5
  * CloudWatch: Fix high CPU load (#20579)
* Thu Mar  5 2020 kastl@b1-systems.de
- add obs-service-go_modules to download required modules into vendor.tar.gz
- adjusted spec file to use vendor.tar.gz
- adjusted Makefile to work with new filenames
- BuildRequire go1.14
- Update to version 6.4.4:
  * DataLinks: Fix blur issues. #19883, @aocenas
  * Docker: Makes it possible to parse timezones in the docker image. #20081, @xlson
  * LDAP: All LDAP servers should be tried even if one of them returns a connection error. #20077, @jongyllen
  * LDAP: No longer shows incorrectly matching groups based on role in debug page. #20018, @xlson
  * Singlestat: Fix no data / null value mapping . #19951, @ryantxu
* Tue Dec  3 2019 witold.bedyk@suse.com
- Revert the spec file and make script
- Remove PhantomJS dependency
* Wed Oct 16 2019 ecsos@opensuse.org
- Update to 6.4.3
  * Bug Fixes
  - Alerting: All notification channels should send even if one fails to send. #19807, @jan25
  - AzureMonitor: Fix slate interference with dropdowns. #19799, @aocenas
  - ContextMenu: make ContextMenu positioning aware of the viewport width. #19699, @krvajal
  - DataLinks: Fix context menu not showing in singlestat-ish visualisations. #19809, @dprokop
  - DataLinks: Fix url field not releasing focus. #19804, @aocenas
  - Datasource: Fixes clicking outside of some query editors required 2 clicks. #19822, @aocenas
  - Panels: Fixes default tab for visualizations without Queries Tab. #19803, @hugohaggmark
  - Singlestat: Fixed issue with mapping null to text. #19689, @torkelo
  - @grafana/toolkit: Don't fail plugin creation when git user.name config is not set. #19821, @dprokop
  - @grafana/toolkit: TSLint line number off by 1. #19782, @fredwangwang
* Wed Oct 16 2019 ecsos@opensuse.org
- Update to 6.4.2
  * Bug Fixes
  - CloudWatch: Changes incorrect dimension wmlid to wlmid . #19679, @ATTron
  - Grafana Image Renderer: Fixes plugin page. #19664, @hugohaggmark
  - Graph: Fixes auto decimals logic for y axis ticks that results in too many decimals for high values. #19618, @torkelo
  - Graph: Switching to series mode should re-render graph. #19623, @torkelo
  - Loki: Fix autocomplete on label values. #19579, @aocenas
  - Loki: Removes live option for logs panel. #19533, @davkal
  - Profile: Fix issue with user profile not showing more than sessions sessions in some cases. #19578, @huynhsamha
  - Prometheus: Fixes so results in Panel always are sorted by query order. #19597, @hugohaggmark
  - ShareQuery: Fixed issue when using -- Dashboard -- datasource (to share query result) when dashboard had rows. #19610, @torkelo
  - Show SAML login button if SAML is enabled. #19591, @papagian
  - SingleStat: Fixes  postfix/prefix usage. #19687, @hugohaggmark
  - Table: Proper handling of json data with dataframes. #19596, @marefr
  - Units: Fixed wrong id for Terabits/sec. #19611, @andreaslangnevyjel
- Changes from 6.4.1
  * Bug Fixes
  - Provisioning: Fixed issue where empty nested keys in YAML provisioning caused a server crash, #19547
  - ImageRendering: Fixed issue with image rendering in enterprise build (Enterprise)
  - Reporting: Fixed issue with reporting service when STMP was disabled (Enterprise).
- Changes from 6.4.0
  * Features / Enhancements
  - Build: Upgrade go to 1.12.10. #19499, @marefr
  - DataLinks: Suggestions menu improvements. #19396, @dprokop
  - Explore: Take root_url setting into account when redirecting from dashboard to explore. #19447, @ivanahuckova
  - Explore: Update broken link to logql docs. #19510, @ivanahuckova
  - Logs: Adds Logs Panel as a visualization. #19504, @davkal
  * Bug Fixes
  - CLI: Fix version selection for plugin install. #19498, @aocenas
  - Graph: Fixes minor issue with series override color picker and custom color . #19516, @torkelo
- Changes from 6.4.0 Beta 2
  * Features / Enhancements
  - Azure Monitor: Remove support for cross resource queries (#19115)". #19346, @sunker
  - Docker: Upgrade packages to resolve reported vulnerabilities. #19188, @marefr
  - Graphite: Time range expansion reduced from 1 minute to 1 second. #19246, @torkelo
  - grafana/toolkit: Add plugin creation task. #19207, @dprokop
  * Bug Fixes
  - Alerting: Prevents creating alerts from unsupported queries. #19250, @hugohaggmark
  - Alerting: Truncate PagerDuty summary when greater than 1024 characters. #18730, @nvllsvm
  - Cloudwatch: Fix autocomplete for Gamelift dimensions. #19146, @kevinpz
  - Dashboard: Fix export for sharing when panels use default data source. #19315, @torkelo
  - Database: Rewrite system statistics query to perform better. #19178, @papagian
  - Gauge/BarGauge: Fix issue with [object Object] in titles . #19217, @ryantxu
  - MSSQL: Revert usage of new connectionstring format introduced by #18384. #19203, @marefr
  - Multi-LDAP: Do not fail-fast on invalid credentials. #19261, @gotjosh
  - MySQL, Postgres, MSSQL: Fix validating query with template variables in alert . #19237, @marefr
  - MySQL, Postgres: Update raw sql when query builder updates. #19209, @marefr
  - MySQL: Limit datasource error details returned from the backend. #19373, @marefr
- Changes from 6.4.0 Beta 1
  * Features / Enhancements
  - API: Readonly datasources should not be created via the API. #19006, @papagian
  - Alerting: Include configured AlertRuleTags in Webhooks notifier. #18233, @dominic-miglar
  - Annotations: Add annotations support to Loki. #18949, @aocenas
  - Annotations: Use a single row to represent a region. #17673, @ryantxu
  - Auth: Allow inviting existing users when login form is disabled. #19048, @548017
  - Azure Monitor: Add support for cross resource queries. #19115, @sunker
  - CLI: Allow installing custom binary plugins. #17551, @aocenas
  - Dashboard: Adds Logs Panel (alpha) as visualization option for Dashboards. #18641, @hugohaggmark
  - Dashboard: Reuse query results between panels . #16660, @ryantxu
  - Dashboard: Set time to to 23:59:59 when setting To time using calendar. #18595, @simPod
  - DataLinks: Add DataLinks support to Gauge, BarGauge and SingleStat2 panel. #18605, @ryantxu
  - DataLinks: Enable access to labels & field names. #18918, @torkelo
  - DataLinks: Enable multiple data links per panel. #18434, @dprokop
  - Docker: switch docker image to alpine base with phantomjs support. #18468, @DanCech
  - Elasticsearch: allow templating queries to order by doc_count. #18870, @hackery
  - Explore: Add throttling when doing live queries. #19085, @aocenas
  - Explore: Adds ability to go back to dashboard, optionally with query changes. #17982, @kaydelaney
  - Explore: Reduce default time range to last hour. #18212, @davkal
  - Gauge/BarGauge: Support decimals for min/max. #18368, @ryantxu
  - Graph: New series override transform constant that renders a single point as a line across the whole graph. #19102, @davkal
  - Image rendering: Add deprecation warning when PhantomJS is used for rendering images. #18933, @papagian
  - InfluxDB: Enable interpolation within ad-hoc filter values. #18077, @kvc-code
  - LDAP: Allow an user to be synchronized against LDAP. #18976, @gotjosh
  - Ldap: Add ldap debug page. #18759, @peterholmberg
  - Loki: Remove prefetching of default label values. #18213, @davkal
  - Metrics: Add failed alert notifications metric. #18089, @koorgoo
  - OAuth: Support JMES path lookup when retrieving user email. #14683, @bobmshannon
  - OAuth: return GitLab groups as a part of user info (enable team sync). #18388, @alexanderzobnin
  - Panels: Add unit for electrical charge - ampere-hour. #18950, @anirudh-ramesh
  - Plugin: AzureMonitor - Reapply MetricNamespace support. #17282, @raphaelquati
  - Plugins: better warning when plugins fail to load. #18671, @ryantxu
  - Postgres: Add support for scram sha 256 authentication. #18397, @nonamef
  - RemoteCache: Support SSL with Redis. #18511, @kylebrandt
  - SingleStat: The gauge option in now disabled/hidden (unless it's an old panel with it already enabled) . #18610, @ryantxu
  - Stackdriver: Add extra alignment period options. #18909, @sunker
  - Units: Add South African Rand (ZAR) to currencies. #18893, @jeteon
  - Units: Adding T,P,E,Z,and Y bytes. #18706, @chiqomar
  * Bug Fixes
  - Alerting: Notification is sent when state changes from no_data to ok. #18920, @papagian
  - Alerting: fix duplicate alert states when the alert fails to save to the database. #18216, @kylebrandt
  - Alerting: fix response popover prompt when add notification channels. #18967, @lzdw
  - CloudWatch: Fix alerting for queries with Id (using GetMetricData). #17899, @alex-berger
  - Explore: Fix auto completion on label values for Loki. #18988, @aocenas
  - Explore: Fixes crash using back button with a zoomed in graph. #19122, @hugohaggmark
  - Explore: Fixes so queries in Explore are only run if Graph/Table is shown. #19000, @hugohaggmark
  - MSSQL: Change connectionstring to URL format to fix using passwords with semicolon. #18384, @Russiancold
  - MSSQL: Fix memory leak when debug enabled. #19049, @briangann
  - Provisioning: Allow escaping literal '$' with '$$' in configs to avoid interpolation. #18045, @kylebrandt
  - TimePicker: Fixes hiding time picker dropdown in FireFox. #19154, @hugohaggmark
  * Breaking changes
    + Annotations
    There are some breaking changes in the annotations HTTP API for region annotations. Region annotations are now represented
    using a single event instead of two seperate events. Check breaking changes in HTTP API below and HTTP API documentation for more details.
    + Docker
    Grafana is now using Alpine 3.10 as docker base image.
    + HTTP API
  - GET /api/alert-notifications now requires at least editor access.
    New /api/alert-notifications/lookup returns less information than /api/alert-notifications and can be access by any authenticated user.
  - GET /api/alert-notifiers now requires at least editor access
  - GET /api/org/users now requires org admin role.
    New /api/org/users/lookup returns less information than /api/org/users and can be access by users that are org admins,
    admin in any folder or admin of any team.
  - GET /api/annotations no longer returns regionId property.
  - POST /api/annotations no longer supports isRegion property.
  - PUT /api/annotations/:id no longer supports isRegion property.
  - PATCH /api/annotations/:id no longer supports isRegion property.
  - DELETE /api/annotations/region/:id has been removed.
  * Deprecation notes
    + PhantomJS
  - PhantomJS, which is used for rendering images of dashboards and panels,
    is deprecated and will be removed in a future Grafana release.
    A deprecation warning will from now on be logged when Grafana starts up if PhantomJS is in use.
    Please consider migrating from PhantomJS to the Grafana Image Renderer plugin.
- Changes from 6.3.6
  * Features / Enhancements
  - Metrics: Adds setting for turning off total stats metrics. #19142, @marefr
  * Bug Fixes
  - Database: Rewrite system statistics query to perform better. #19178, @papagian
  - Explore: Fixes error when switching from prometheus to loki data sources. #18599, @kaydelaney
- Rebase package spec. Use mostly from fedora, fix suse specified things and fix some errors.
- Add missing directories provisioning/datasources and provisioning/notifiers
  and sample.yaml as described in packaging/rpm/control from upstream.
  Missing directories are shown in logfiles.
* Thu Sep  5 2019 simon.crute@grafana.com
- Version 6.3.5
  * Upgrades
    + Build: Upgrade to go 1.12.9.
  * Bug Fixes
    + Dashboard: Fixes dashboards init failed loading error for dashboards with panel links that had missing properties.
    + Editor: Fixes issue where only entire lines were being copied.
    + Explore: Fixes query field layout in splitted view for Safari browsers.
    + LDAP: multildap + ldap integration.
    + Profile/UserAdmin: Fix for user agent parser crashes grafana-server on 32-bit builds.
    + Prometheus: Prevents panel editor crash when switching to Prometheus datasource.
    + Prometheus: Changes brace-insertion behavior to be less annoying.
- Version 6.3.4
  * Security: CVE-2019-15043 - Parts of the HTTP API allow unauthenticated use.
* Fri Aug 16 2019 simon.crute@grafana.com
- Version 6.3.3
  * Bug Fixes
    + Annotations: Fix failing annotation query when time series query is cancelled. #18532 1, @dprokop 1
    + Auth: Do not set SameSite cookie attribute if cookie_samesite is none. #18462 1, @papagian 3
    + DataLinks: Apply scoped variables to data links correctly. #18454 1, @dprokop 1
    + DataLinks: Respect timezone when displaying datapoint’s timestamp in graph context menu. #18461 2, @dprokop 1
    + DataLinks: Use datapoint timestamp correctly when interpolating variables. #18459 1, @dprokop 1
    + Explore: Fix loading error for empty queries. #18488 1, @davkal
    + Graph: Fixes legend issue clicking on series line icon and issue with horizontal scrollbar being visible on windows. #18563 1, @torkelo 2
    + Graphite: Avoid glob of single-value array variables . #18420, @gotjosh
    + Prometheus: Fix queries with label_replace remove the $1 match when loading query editor. #18480 5, @hugohaggmark 3
    + Prometheus: More consistently allows for multi-line queries in editor. #18362 2, @kaydelaney 2
    + TimeSeries: Assume values are all numbers. #18540 4, @ryantxu
- Version 6.3.2
  * Bug Fixes
    + Gauge/BarGauge: Fixes issue with losts thresholds and issue loading Gauge with avg stat. #18375 12
- Version 6.3.1
  * Bug Fixes
    + PanelLinks: Fix crash issue Gauge & Bar Gauge for panels with panel links (drill down links). #18430 2
- Version 6.3.0
  * Features / Enhancements
    + OAuth: Do not set SameSite OAuth cookie if cookie_samesite is None. #18392 4, @papagian 3
    + Auth Proxy: Include additional headers as part of the cache key. #18298 6, @gotjosh
    + Build grafana images consistently. #18224 12, @hassanfarid
    + Docs: SAML. #18069 11, @gotjosh
    + Permissions: Show plugins in nav for non admin users but hide plugin configuration. #18234 1, @aocenas
    + TimePicker: Increase max height of quick range dropdown. #18247 2, @torkelo 2
    + Alerting: Add tags to alert rules. #10989 13, @Thib17 1
    + Alerting: Attempt to send email notifications to all given email addresses. #16881 1, @zhulongcheng
    + Alerting: Improve alert rule testing. #16286 2, @marefr
    + Alerting: Support for configuring content field for Discord alert notifier. #17017 2, @jan25
    + Alertmanager: Replace illegal chars with underscore in label names. #17002 5, @bergquist 1
    + Auth: Allow expiration of API keys. #17678, @papagian 3
    + Auth: Return device, os and browser when listing user auth tokens in HTTP API. #17504, @shavonn 1
    + Auth: Support list and revoke of user auth tokens in UI. #17434 2, @shavonn 1
    + AzureMonitor: change clashing built-in Grafana variables/macro names for Azure Logs. #17140, @shavonn 1
    + CloudWatch: Made region visible for AWS Cloudwatch Expressions. #17243 2, @utkarshcmu
    + Cloudwatch: Add AWS DocDB metrics. #17241, @utkarshcmu
    + Dashboard: Use timezone dashboard setting when exporting to CSV. #18002 1, @dehrax
    + Data links. #17267 11, @torkelo 2
    + Docker: Switch base image to ubuntu:latest from debian:stretch to avoid security issues… #17066 5, @bergquist 1
    + Elasticsearch: Support for visualizing logs in Explore . #17605 7, @marefr
    + Explore: Adds Live option for supported datasources. #17062 1, @hugohaggmark 3
    + Explore: Adds orgId to URL for sharing purposes. #17895 1, @kaydelaney 2
    + Explore: Adds support for new loki ‘start’ and ‘end’ params for labels endpoint. #17512, @kaydelaney 2
    + Explore: Adds support for toggling raw query mode in explore. #17870, @kaydelaney 2
    + Explore: Allow switching between metrics and logs . #16959 2, @marefr
    + Explore: Combines the timestamp and local time columns into one. #17775, @hugohaggmark 3
    + Explore: Display log lines context . #17097, @dprokop 1
    + Explore: Don’t parse log levels if provided by field or label. #17180 1, @marefr
    + Explore: Improves performance of Logs element by limiting re-rendering. #17685, @kaydelaney 2
    + Explore: Support for new LogQL filtering syntax. #16674 4, @davkal
    + Explore: Use new TimePicker from Grafana/UI. #17793, @hugohaggmark 3
    + Explore: handle newlines in LogRow Highlighter. #17425, @rrfeng 1
    + Graph: Added new fill gradient option. #17528 3, @torkelo 2
    + GraphPanel: Don’t sort series when legend table & sort column is not visible . #17095, @shavonn 1
    + InfluxDB: Support for visualizing logs in Explore. #17450 9, @hugohaggmark 3
    + Logging: Login and Logout actions (#17760). #17883 1, @ATTron
    + Logging: Move log package to pkg/infra. #17023, @zhulongcheng
    + Metrics: Expose stats about roles as metrics. #17469 2, @bergquist 1
    + MySQL/Postgres/MSSQL: Add parsing for day, weeks and year intervals in macros. #13086 6, @bernardd
    + MySQL: Add support for periodically reloading client certs. #14892, @tpetr
    + Plugins: replace dataFormats list with skipDataQuery flag in plugin.json. #16984, @ryantxu
    + Prometheus: Take timezone into account for step alignment. #17477, @fxmiii
    + Prometheus: Use overridden panel range for $__range instead of dashboard range. #17352, @patrick246
    + Prometheus: added time range filter to series labels query. #16851 3, @FUSAKLA
    + Provisioning: Support folder that doesn’t exist yet in dashboard provisioning. #17407 1, @Nexucis
    + Refresh picker: Handle empty intervals. #17585 1, @dehrax
    + Singlestat: Add y min/max config to singlestat sparklines. #17527 4, @pitr
    + Snapshot: use given key and deleteKey. #16876, @zhulongcheng
    + Templating: Correctly display __text in multi-value variable after page reload. #17840 1, @EduardSergeev
    + Templating: Support selecting all filtered values of a multi-value variable. #16873 2, @r66ad
    + Tracing: allow propagation with Zipkin headers. #17009 4, @jrockway
    + Users: Disable users removed from LDAP. #16820 2, @alexanderzobnin
  * Bug Fixes
    + PanelLinks: Fix render issue when there is no panel description. #18408 3, @dehrax
    + OAuth: Fix “missing saved state” OAuth login failure due to SameSite cookie policy. #18332 1, @papagian 3
    + cli: fix for recognizing when in dev mode… #18334, @xlson
    + DataLinks: Fixes incorrect interpolation of ${__series_name} . #18251 1, @torkelo 2
    + Loki: Display live tailed logs in correct order in Explore. #18031 3, @kaydelaney 2
    + PhantomJS: Fixes rendering on Debian Buster. #18162 2, @xlson
    + TimePicker: Fixed style issue for custom range popover. #18244, @torkelo 2
    + Timerange: Fixes a bug where custom time ranges didn’t respect UTC. #18248 1, @kaydelaney 2
    + remote_cache: Fix redis connstr parsing. #18204 1, @mblaschke
    + AddPanel: Fix issue when removing moved add panel widget . #17659 2, @dehrax
    + CLI: Fix encrypt-datasource-passwords fails with sql error. #18014, @marefr
    + Elasticsearch: Fix default max concurrent shard requests. #17770 4, @marefr
    + Explore: Fix browsing back to dashboard panel. #17061, @jschill
    + Explore: Fix filter by series level in logs graph. #17798, @marefr
    + Explore: Fix issues when loading and both graph/table are collapsed. #17113, @marefr
    + Explore: Fix selection/copy of log lines. #17121, @marefr
    + Fix: Wrap value of multi variable in array when coming from URL. #16992 1, @aocenas
    + Frontend: Fix for Json tree component not working. #17608, @srid12
    + Graphite: Fix for issue with alias function being moved last. #17791, @torkelo 2
    + Graphite: Fixes issue with seriesByTag & function with variable param. #17795, @torkelo 2
    + Graphite: use POST for /metrics/find requests. #17814 2, @papagian 3
    + HTTP Server: Serve Grafana with a custom URL path prefix. #17048 6, @jan25
    + InfluxDB: Fixes single quotes are not escaped in label value filters. #17398 1, @Panzki
    + Prometheus: Correctly escape ‘|’ literals in interpolated PromQL variables. #16932, @Limess
    + Prometheus: Fix when adding label for metrics which contains colons in Explore. #16760, @tolwi
    + SinglestatPanel: Remove background color when value turns null. #17552 1, @druggieri
* Tue Jul 30 2019 ro@suse.de
- make phantomjs dependency configurable
* Thu Jul 11 2019 Jan Fajerski <jan.fajerski@suse.com>
- spec file change:
  * alter permissions of /etc/grafana and /var/lib/grafana to 755
  * alter owner of /etc/grafana/provisioning/dashboards tree to root:root
  * this allows installing dashboards via rpms without these rpms depending on this rpm
* Tue Jun 25 2019 dmueller@suse.com
- Update to version 6.2.5:
  * release 6.2.5
  * Panel: Fully escape html in drilldown links (was only sanitized before)  (#17731)
  * Grafana-CLI: Wrapper for `grafana-cli` within RPM/DEB packages and config/homepath are now global flags (#17695)
  * config: fix connstr for remote_cache (#17675)
  * TablePanel: fix annotations display (#17646)
  * middleware: fix Strict-Transport-Security header (#17644)
  * Elasticsearch: Fix empty query request to send properly (#17488)
  * release 6.2.4
  * grafana-cli: Fix receiving flags via command line (#17617)
  * HTTPServer: Fix X-XSS-Protection header formatting (#17620)
  * release 6.2.3
  * cli: grafana-cli should receive flags from the command line (#17606)
  * AuthProxy: Optimistic lock pattern for remote cache Set (#17485)
  * OAuth: Fix for wrong user token updated on OAuth refresh in DS proxy (#17541)
  * middleware: add security related HTTP(S) response headers (#17522)
  * remote_cache: Fix redis (#17483)
  * auth_proxy: non-negative cache TTL (#17495)
* Sat Jun 15 2019 dmueller@suse.com
- Update to version 6.2.2:
  * Security Fix: Prevent csv formula injection attack
  * PluginConfig: Fixed plugin config page navigation when using subpath
  * Explore: Update time range before running queries
  * Perf: Fix slow dashboards ACL query
  * Database: Initialize xorm with an empty schema for postgres
  * CloudWatch: Avoid exception while accessing results
* Tue May 28 2019 jcavalheiro@suse.com
- Remove phantomjs dependency
  * Modified: Makefile
- Update to version 6.2.1
  * Bug Fixes
    + Auth Proxy: Resolve database is locked errors.
    + Database: Retry transaction if sqlite returns database is locked error.
    + Explore: Fixes so clicking in a Prometheus Table the query is filtered by clicked value.
    + Singlestat: Fixes issue with value placement and line wraps.
    + Tech: Update jQuery to 3.4.1 to fix issue on iOS 10 based browers as well as Chrome 53.x.
  * Features / Enhancements
    + CLI: Add command to migrate all datasources to use encrypted password fields.
    + Gauge/BarGauge: Improvements to auto value font size.
  * Modified: README
- Update to version 6.2.0
  * Bug Fixes
    + BarGauge: Fix for negative min values.
    + Gauge/BarGauge: Fix for issues editing min & max options.
    + Search: Make only folder name only open search with current folder filter.
    + AzureMonitor: Revert to clearing chained dropdowns.
    + Dashboard: Fixes blank dashboard after window resize with panel without title.
    + Dashboard: Fixes lazy loading & expanding collapsed rows on mobile.
    + Dashboard: Fixes scrolling issues for Edge browser.
    + Dashboard: Show refresh button in first kiosk(tv) mode.
    + Explore: Fix empty result from datasource should render logs container.
    + Explore: Fixes so clicking in a Prometheus Table the query is filtered by clicked value.
    + Explore: Makes it possible to zoom in Explore/Loki/Graph without exception.
    + Gauge: Fixes orientation issue after switching from BarGauge to Gauge.
    + GettingStarted: Fixes layout issues in getting started panel.
    + InfluxDB: Fix HTTP method should default to GET.
    + Panels: Fixed alert icon position in panel header.
    + Panels: Fixes panel error tooltip not showing.
    + Plugins: Fix how datemath utils are exposed to plugins.
    + Singlestat: fixed centering issue for very small panels.
    + Search: Scroll issue in dashboard search in latest Chrome.
    + Docker: Prevent a permission denied error when writing files to the default provisioning directory.
    + Gauge: Adds background shade to gauge track and improves height usage.
    + RemoteCache: Avoid race condition in Set causing error on insert. .
    + Build: Fix bug where grafana didn't start after mysql on rpm packages.
    + CloudWatch: Fixes query order not affecting series ordering & color.
    + CloudWatch: Use default alias if there is no alias for metrics.
    + Config: Fixes bug where timeouts for alerting was not parsed correctly.
    + Elasticsearch: Fix view percentiles metric in table without date histogram.
    + Explore: Prevents histogram loading from killing Prometheus instance.
    + Graph: Allow override decimals to fully override.
    + Mixed Datasource: Fix error when one query is disabled.
    + Search: Fixes search limits and adds a page parameter.
    + Security: Responses from backend should not be cached.
  * Breaking Changes
    + Plugins: Data source plugins that process hidden queries need to add a "hiddenQueries: true" attribute in plugin.json.
    + Gauge Panel: The suffix / prefix options have been removed from the new Gauge Panel (introduced in v6.0). #16870.
  * Features / Enhancements
    + Plugins: Support templated urls in plugin routes.
    + Packaging: New MSI windows installer package**.
    + Admin: Add more stats about roles.
    + Alert list panel: Support variables in filters.
    + Alerting: Adjust label for send on all alerts to default .
    + Alerting: Makes timeouts and retries configurable.
    + Alerting: No notification when going from no data to pending.
    + Alerting: Pushover alert, support for different sound for OK.
    + Auth: Enable retries and transaction for some db calls for auth tokens .
    + AzureMonitor: Adds support for multiple subscriptions per datasource.
    + Bar Gauge: New multi series enabled gauge like panel with horizontal and vertical layouts and 3 display modes.
    + Build: Upgrades to golang 1.12.4.
    + CloudWatch: Update AWS/IoT metric and dimensions.
    + Config: Show user-friendly error message instead of stack trace.
    + Dashboard: Enable filtering dashboards in search by current folder.
    + Dashboard: Lazy load out of view panels .
    + DataProxy: Restore Set-Cookie header after proxy request.
    + Datasources: Add pattern validation for time input on datasource config pages.
    + Elasticsearch: Add 7.x version support.
    + Explore: Adds reconnect for failing datasource.
    + Explore: Support user timezone.
    + InfluxDB: Add support for POST HTTP verb.
    + Loki: Search is now case insensitive.
    + OAuth: Update jwt regexp to include =.
    + Panels: No title will no longer make panel header take up space.
    + Prometheus: Adds tracing headers for Prometheus datasource.
    + Provisioning: Add API endpoint to reload provisioning configs.
    + Provisioning: Do not allow deletion of provisioned dashboards.
    + Provisioning: Interpolate env vars in provisioning files.
    + Security: Add new setting allow_embedding.
    + Security: Store datasource passwords encrypted in secureJsonData.
    + UX: Improve Grafana usage for smaller screens.
    + Units: Add angle units, Arc Minutes and Seconds.
* Sat May 18 2019 dmueller@suse.com
- Update to version 6.1.6
  * Security: Bump jQuery to 3.4.0
  * Playlist: Fix loading dashboards by tag.
- Update to version 6.0.2:
  * Fixed issue with alert links in alert list panel causing panel not found errors, fixes #15680
  * Improved error handling when rendering dashboard panels, fixes #15913
  * fix allow anonymous server bind for ldap search
  * add nil/length check when delete old login attempts
  * fix discord notifier so it doesn't crash when there are no image generated
  * fix only users that can edit a dashboard should be able to update panel json
  * move to new component to handle focus
  * added state to not set focus on search every render
  * Snapshots update
  * Use app config directly in ButtonRow instead of passing datasources page URL via prop
  * Update snapshots
  * Fixed url of back button in datasource edit page, when root_url configured
  * release: Bumped version
- Update to version 6.0.1:
  * Bug Fixes:
    + utils: show string errors
    + Viewers with viewers_can_edit should be able to access /explore
    +  log phantomjs output even if it timeout and include orgId when render alert
- Update to version 6.0.0:
  * Breaking Changes:
    + Text Panel: The text panel does no longer by default allow unsantizied
    HTML. This means that if you have text panels with scripts tags they will no
    longer work as before. To enable unsafe javascript execution in text panels
    enable the settings disable_sanitize_html under the section [panels] in your
    Grafana ini file, or set env variable GF_PANELS_DISABLE_SANITIZE_HTML=true.
    + Dashboard: Panel property minSpan replaced by maxPerRow. Dashboard
    migration will automatically migrate all dashboard panels using the minSpan
    property to the new maxPerRow property
    + Internal Metrics Edition has been added to the build_info metric. This will break any Graphite queries using this metric. Edition will be a new label for the Prometheus metric.
  * New Features:
    + Alerting: Adds support for Google Hangouts Chat notifications
    + Elasticsearch: Support bucket script pipeline aggregations
    + Influxdb: Add support for time zone (tz) clause
    + Snapshots: Enable deletion of public snapshot
    + Provisioning: Provisioning support for alert notifiers
    + Explore: A whole new way to do ad-hoc metric queries and exploration. Split view in half and compare metrics & logs and much much more. Read more here
    + Auth: Replace remember me cookie solution for Grafana's builtin, LDAP and OAuth authentication with a solution based on short-lived tokens
    + AzureMonitor: Enable alerting by converting Azure Monitor API to Go
    + Explore A new query focused workflow for ad-hoc data exploration and troubleshooting.
    + Grafana Loki Integration with the new open source log aggregation system from Grafana Labs.
    + Gauge Panel A new standalone panel for gauges.
    + New Panel Editor UX improves panel editing and enables easy switching between different visualizations.
    + Google Stackdriver Datasource is out of beta and is officially released.
    + React Plugin support enables an easier way to build plugins.
    + Named Colors in our new improved color picker.
    + Removal of user session storage makes Grafana easier to deploy & improves security.
  * Bug Fixes:
    + Metrics: Fixes broken usagestats metrics for /metrics
    + Dashboard: Fixes kiosk mode should have &kiosk appended to the url
    + Dashboard: Fixes kiosk=tv mode with autofitpanels should respect header
    + Image rendering: Fixed image rendering issue for dashboards with auto refresh,
    + Dashboard: Fix only users that can edit a dashboard should be able to update panel json.
    + LDAP: fix allow anonymous initial bind for ldap search.
    + UX: Fixed scrollbar not visible initially (only after manual scroll).
    + Datasource admin TestData
    + Dashboard: Fixed scrolling issue that caused scroll to be locked to bottom.
    + Explore: Viewers with viewers_can_edit should be able to access /explore.
    + Security fix: limit access to org admin and alerting pages.
    + Panel Edit minInterval changes did not persist
    + Teams: Fixed bug when getting teams for user.
    + Stackdriver: fix for float64 bounds for distribution metrics
    + Stackdriver: no reducers available for distribution type
    + Influxdb: Add support for alerting on InfluxDB queries that use the non_negative_difference function
    + Alerting: Fix percent_diff calculation when points are nulls
    + Alerting: Fixed handling of alert urls with true flags
    + Gauge: Fix issue with gauge requests being cancelled
    + Gauge: Accept decimal inputs for thresholds
    + UI: Fix error caused by named colors that are not part of named colors palette
    + Search: Bug pressing special regexp chars in input fields
    + Permissions: No need to have edit permissions to be able to "Save as"
    + Search: Fix for issue with scrolling the "tags filter" dropdown
    + Prometheus: Query for annotation always uses 60s step regardless of dashboard range
    + Annotations: Fix creating annotation when graph panel has no data points position the popup outside viewport
    + Piechart/Flot: Fixes multiple piechart instances with donut bug
    + plus many minor changes and fixes
- Update to version 5.4.3:
  * Fixes:
    + Alerting Invalid frequency causes division by zero in alert scheduler
    + Dashboard Dashboard links do not update when time range changes
    + Limits Support more than 1000 datasources per org
    + Backend fix signed in user for orgId=0 result should return active org id
    + Provisioning Adds orgId to user dto for provisioned dashboards
- Update to version 5.4.2:
  * Fixes:
    + Datasource admin: Fix for issue creating new data source when same name exists
    + OAuth: Fix for oauth auto login setting, can now be set using env variable
    + Dashboard search: Fix for searching tags in tags filter dropdown.
- Update to version 5.4.1:
  * Fixes:
    + Stackdriver: Fixes issue with data proxy and Authorization header
    + Units: fixedUnit for Flow:l/min and mL/min
    + Logging: Fix for issue where data proxy logged a secret when debug logging was enabled, now redacted.
    + InfluxDB: Add support for alerting on InfluxDB queries that use the cumulative_sum function.
    + Plugins: Panel plugins should no receive the panel-initialized event again as usual.
    + Embedded Graphs: Iframe graph panels should now work as usual.
    + Postgres: Improve PostgreSQL Query Editor if using different Schemas,
    + Quotas: Fixed for updating org & user quotas.
    + Cloudwatch: Add the AWS/SES Cloudwatch metrics of BounceRate and ComplaintRate to auto complete list.
    + Dashboard Search: Fixed filtering by tag issues.
    + Graph: Fixed time region issues,
    + Graph: Fixed issue with series color picker popover being placed outside window.
- Update to version 5.4.0:
  * Breaking Changes:
    + Postgres/MySQL/MSSQL datasources now per default uses max open connections = unlimited (earlier 10), max idle connections = 2 (earlier 10) and connection max lifetime = 4 hours (earlier unlimited).
  * Features:
    + Alerting: Introduce alert debouncing with the FOR setting.
    + Alerting: Option to disable OK alert notifications
    + Postgres/MySQL/MSSQL: Adds support for configuration of max open/idle connections and connection max lifetime. Also, panels with multiple SQL queries will now be executed concurrently
    + MySQL: Graphical query builder
    + MySQL: Support connecting thru Unix socket for MySQL datasource
    + MSSQL: Add encrypt setting to allow configuration of how data sent between client and server are encrypted
    + Stackdriver: Not possible to authenticate using GCE metadata server
    + Teams: Team preferences (theme, home dashboard, timezone) support
    + Graph: Time regions support enabling highlight of weekdays and/or certain timespans
    + OAuth: Automatic redirect to sign-in with OAuth
    + Stackdriver: Template query editor
  * Fixes:
    + Cloudwatch: Fix invalid time range causes segmentation fault
    + Cloudwatch: AWS/CodeBuild metrics and dimensions
    + MySQL: Fix $__timeFrom() and $__timeTo() should respect local time zone
    + Graph: Fix legend always visible even if configured to be hidden
    + Elasticsearch: Fix regression when using datasource version 6.0+ and alerting
- Update to version 5.3.4:
  * minor bug fixes
* Sat May 18 2019 dmueller@suse.com
- Update to version 5.3.3 (CVE-2018-19039, bsc#1115960) :
  * File Exfiltration vulnerability Security fix
* Tue Jan  8 2019 witold.bedyk@suse.com
- Provide default dashboard provider from upstream
* Mon Oct 29 2018 moio@suse.com
- Update to version 5.3.2
  * InfluxDB/Graphite/Postgres: Prevent cross site scripting (XSS) in query editor
  * Postgres: Fix template variables error
  * Cloudwatch: Fix service panic because of race conditions
  * Cloudwatch: Fix check for invalid percentile statistics
  * Stackdriver/Cloudwatch: Allow user to change unit in graph panel if cloudwatch/stackdriver datasource response doesn't include unit
  * Stackdriver: stackdriver user-metrics duplicated response when multiple resource types
  * Variables: Fix text box template variable doesn't work properly without a default value
  * Variables: Fix variable dependency check when using ${var} format
  * Dashboard: Fix kiosk=1 url parameter should put dashboard in kiosk mode
  * LDAP: Fix super admins can also be admins of orgs
  * Provisioning: Fix deleting provisioned dashboard folder should cleanup provisioning meta data
  * Docker: adds curl back into the docker image for utility
- Update to version 5.3.1
  * Render: Fix PhantomJS render of graph panel when legend displayed as table to the right
  * Stackdriver: Filter option disappears after removing initial filter
  * Elasticsearch: Fix no limit size in terms aggregation for alerting queries
  * InfluxDB: Fix for annotation issue that caused text to be shown twice
  * Variables: Fix nesting variables leads to exception and missing refresh
  * Variables: Prometheus: Single letter labels are not supported
  * Graph: Fix graph time formatting for Last 24h ranges
  * Playlist: Fix cannot add dashboards with long names to playlist
  * HTTP API: Fix /api/org/users so that query and limit querystrings works
- Update to version 5.3.0
  * Stackdriver: Filter wildcards and regex matching are not yet supported
  * Stackdriver: Support the distribution metric type for heatmaps
  * Cloudwatch: Automatically set graph yaxis unit
- Update to version 5.3.0-beta3
  * Stackdriver: Fix for missing ngInject
  * Permissions: Fix for broken permissions selector
  * Alerting: Alert reminders deduping not working as expected when running multiple Grafana instances
- Update to version 5.3.0-beta2
  + New Features
  * Annotations: Enable template variables in tagged annotations queries
  * Stackdriver: Support for Google Stackdriver Datasource
  + Minor
  * Provisioning: Dashboard Provisioning now support symlinks that changes target
  * OAuth: Allow oauth email attribute name to be configurable
  * Tags: Default sort order for GetDashboardTags
  * Prometheus: Label completion queries respect dashboard time range
  * Prometheus: Allow to display annotations based on Prometheus series value
  * Prometheus: Adhoc-filtering for Prometheus dashboards
  * Singlestat: Fix gauge display accuracy for percents
  * Dashboard: Prevent auto refresh from starting when loading dashboard with absolute time range
  * Templating: New templating variable type Text box that allows free text input
  * Alerting: Link to view full size image in Microsoft Teams alert notifier
  * Alerting: Fixes a bug where all alerts would send reminders after upgrade & restart
  * Alerting: Concurrent render limit for graphs used in notifications
  * Postgres/MySQL/MSSQL: Add support for replacing $__interval and  $__interval_ms in alert queries
- Update to version 5.3.0-beta1
  + New Major Features
  * Alerting: Notification reminders
  * Dashboard: TV & Kiosk mode changes, new cycle view mode button in dashboard toolbar
  * OAuth: Gitlab OAuth with support for filter by groups
  * Postgres: Graphical query builder
  + New Features
  * LDAP: Define Grafana Admin permission in ldap group mappings, PR
  * LDAP: Client certificates support
  * Profile: List teams that the user is member of in current/active organization
  * Configuration: Allow auto-assigning users to specific organization (other than Main. Org) and
  * Dataproxy: Pass configured/auth headers to a Datasource
  * CloudWatch: GetMetricData support
  * Postgres: TimescaleDB support, e.g. use time_bucket for grouping by time when option enabled
  * Cleanup: Make temp file time to live configurable
  + Minor
  * Alerting: Its now possible to configure the default value for how to handle errors and no data in alerting
  * Alerting: Fix diff and percent_diff reducers
  * Alerting: Fix rendering timeout which could cause notifications to not be sent due to rendering timing out
  * Docker: Make it possible to set a specific plugin url
  * GrafanaCli: Fixed issue with grafana-cli install plugin resulting in corrupt http response from source error
  * Provisioning: Should allow one default datasource per organisation
  * Github OAuth: Allow changes of user info at Github to be synched to Grafana when signing in
  * OAuth: Fix overriding tls_skip_verify_insecure using environment variable
  * Prometheus: Fix graph panel bar width issue in aligned prometheus queries
  * Prometheus: Heatmap - fix unhandled error when some points are missing
  * Prometheus: Add $__interval, $__interval_ms, $__range, $__range_s & $__range_ms support for dashboard and template queries
  * Elasticsearch: For alerting/backend, support having index name to the right of pattern in index pattern
  * Graphite: Fix for quoting of int function parameters (when using variables)
  * InfluxDB: Support timeFilter in query templating for InfluxDB
  * Postgres/MySQL/MSSQL: New $__unixEpochGroup and $__unixEpochGroupAlias macros
  * Postgres/MySQL/MSSQL: Add previous fill mode to $__timeGroup macro which will fill in previously seen value when point is missing
  * Postgres/MySQL/MSSQL: Use floor rounding in $__timeGroup macro function
  * Postgres/MySQL/MSSQL: Use metric column as prefix when returning multiple value columns
  * Postgres/MySQL/MSSQL: New $__timeGroupAlias macro. Postgres $__timeGroup no longer automatically adds time column alias
  * Postgres/MySQL/MSSQL: Escape single quotes in variables
  * Postgres/MySQL/MSSQL: Min time interval support
  * MySQL/MSSQL: Use datetime format instead of epoch for $__timeFilter, $__timeFrom and $__timeTo macros
  * Postgres: Escape ssl mode parameter in connectionstring
  * Cloudwatch: Improved error handling
  * Cloudwatch: AppSync metrics and dimensions
  * Cloudwatch: Direct Connect metrics and dimensions
  * Cloudwatch: Added BurstBalance metric to list of AWS RDS metrics
  * Cloudwatch: Add new Redshift metrics and dimensions
  * Dashboard: Fix selecting current dashboard from search should not reload dashboard
  * Dashboard: Use uid when linking to dashboards internally in a dashboard
  * Graph: Option to hide series from tooltip
  * Singlestat: Make colorization of prefix and postfix optional in singlestat
  * Table: Adjust header contrast for the light theme
  * Table: Fix link color when using light theme and thresholds in use
  * Table: Fix for useless horizontal scrollbar for table panel
  * Table: Make table sorting stable when null values exist
  * Heatmap: Fix broken tooltip and crosshair on Firefox
  * Datasource: Fix UI issue with secret fields after updating datasource
  * Variables: Skip unneeded extra query request when de-selecting variable values used for repeated panels
  * Variables: Limit amount of queries executed when updating variable that other variable(s) are dependent on
  * Variables: Support query variable refresh when another variable referenced in Regex field change its value
  * Variables: Support variables in query variable Custom all value field
  * Units: Change units to include characters for power of 2 and 3
  * Units: Polish złoty currency
  * Units: Adds bitcoin axes unit
  * Api: Delete nonexistent datasource should return 404
  * Logging: Reopen log files after receiving a SIGHUP signal
  * Login: Show loading animation while waiting for authentication response on login
  * UI: Fix iOS home screen "app" icon and Windows 10 app experience
  * Plugins: Convert URL-like text to links in plugins readme
    + Breaking changes
  * Postgres datasource no longer automatically adds time column alias when using the $__timeGroup alias. However, there's code in place which should make this change backward compatible and shouldn't create any issues
  * Kiosk mode now also hides submenu (variables)
  * ?inactive url parameter no longer supported, replaced with kiosk=tv url parameter
  + New experimental features
  * Dashboard: Auto fit dashboard panels to optimize space used for current TV / Monitor
  + Tech
  * Frontend: Convert all Frontend Karma tests to Jest tests
  * Backend: Upgrade to golang 1.11
- Update to version 5.2.4
  * GrafanaCli: Fixed issue with grafana-cli install plugin resulting in corrupt http response from source error
- Update to version 5.2.3
  * Important fix for LDAP & OAuth login vulnerability
- Update to version 5.2.2
  * Prometheus: Fix graph panel bar width issue in aligned prometheus queries
  * Dashboard: Dashboard links not updated when changing variables
  * Postgres/MySQL/MSSQL: Fix connection leak
  * Plugins: Fix loading of external plugins
  * Dashboard: Remove unwanted scrollbars in embedded panels
  * Prometheus: Prevent error using $__interval_ms in query
- Update to version 5.2.1
  * Auth Proxy: Important security fix for whitelist of IP address feature
  * UI: Fix - Grafana footer overlapping page
  * Logging: Errors should be reported before crashing
- Update to version 5.2.0-stable
  * Plugins: Handle errors correctly when loading datasource plugin thx
  * Render: Enhance error message if phantomjs executable is not found
  * Dashboard: Set correct text in drop down when variable is present in url
  * LDAP: Handle "dn" ldap attribute more gracefully
- Update to version 5.2.0-beta3
  * Build: All rpm packages should be signed
- Update to version 5.2.0-beta2
  + New Features
  * Dashboard: Import dashboard to folder
  + Minor
  * Permissions: Important security fix for API keys with viewer role
  * Dashboard: Fix so panel titles doesn't wrap
  * Dashboard: Prevent double-click when saving dashboard
  * Dashboard: AutoFocus the add-panel search filter thx
  * Units: W/m2 (energy), l/h (flow) and kPa (pressure)
  * Units: Litre/min (flow) and milliLitre/min (flow)
  * Alerting: Fix mobile notifications for Microsoft Teams alert notifier
  * Influxdb: Add support for mode function
  * Cloudwatch: Fixes panic caused by bad timerange settings
  * Auth Proxy: Whitelist proxy IP address instead of client IP address
  * User Management: Make sure that a user always has a current org assigned
  * Snapshots: Fix: annotations not properly extracted leading to incorrect rendering of annotations
  * LDAP: Allow use of DN in group_search_filter_user_attribute and member_of
  * Graph: Fix legend decimals precision calculation
  * Dashboard: Make sure to process panels in collapsed rows when exporting dashboard
  * Dashboard: Dashboard link doesn't work when "As dropdown" option is checked
  * Dashboard: Fix regressions after save modal changes, including adhoc template issues
  * Docker: Config keys ending with _FILE are not respected
- Update to version 5.2.0-beta1
  + New Features
  * Elasticsearch: Alerting support
  * Build: Crosscompile and packages Grafana on arm, windows, linux and darwin
  * Login: Change admin password after first login
  * Alert list panel: Updated to support filtering alerts by name, dashboard title, folder, tags
  + Minor
  * Dashboard: Modified time range and variables are now not saved by default
  * Graph: Show invisible highest value bucket in histogram
  * Dashboard: Enable "Save As..." if user has edit permission
  * Prometheus: Query dates are now step-aligned
  * Prometheus: Table columns order now changes when rearrange queries
  * Variables: Fix variable interpolation when using multiple formatting types
  * Dashboard: Fix date selector styling for dark/light theme in time picker control
  * Discord: Alert notification channel type for Discord
  * InfluxDB: Support SELECT queries in templating query
  * InfluxDB: Support count distinct aggregation
  * Dashboard: JSON Model under dashboard settings can now be updated & changes saved
  * Security: Fix XSS vulnerabilities in dashboard links
  * Singlestat: Fix "time of last point" shows local time when dashboard timezone set to UTC
  * Prometheus: Add support for passing timeout parameter to Prometheus
  * Login: Add optional option sign out url for generic oauth
  * Login: Use proxy server from environment variable if available
  * Invite users: Friendlier error message when smtp is not configured
  * Graphite: Don't send distributed tracing headers when using direct/browser access mode
  * Sidenav: Show create dashboard link for viewers if at least editor in one folder
  * SQL: Second epochs are now correctly converted to ms
  * Singlestat: Fix singlestat threshold tooltip
  * Dashboard: Hide grid controls in fullscreen/low-activity views
  * Dashboard: Validate uid when importing dashboards
  * Docker: Support for env variables ending with _FILE
  * Alert list panel: Show alerts for user with viewer role
  * Provisioning: Verify checksum of dashboards before updating to reduce load on database
  * Provisioning: Support symlinked files in dashboard provisioning config files
  * Dashboard list panel: Search dashboards by folder
  * Sidenav: Always show server admin link in sidenav if grafana admin
- Update to version 5.1.5
  * Docker: Config keys ending with _FILE are not respected
- Update to version 5.1.4
  * Permissions: Important security fix for API keys with viewer role
* Sat Jun 16 2018 opensuse-packaging@opensuse.org
- Update to version 5.1.3:
  * Heatmap support for Prometheus
  * Align Zero-Line for Right and Left Y-axes
  * allow setting the database
  * MSSQL Data Source
  * support multiple histogram series
  * support cloudwatch high resolution query
  * Added radiation units
  * Modify Grafana Pagerduty notifier to use Pagerduty API V2
  * prometheus editor: variable autocomplete support
  * Use net.SplitHostPort to support IPv6
  * See /usr/share/doc/packages/grafana/CHANGELOG.md for more details
* Sat Jun 16 2018 mc@suse.com
- remove unknown build flag -s
* Sat May  5 2018 dmueller@suse.com
- fix build for older distributions
* Wed Mar  7 2018 jengelh@inai.de
- Remove marketing wording from description.
* Wed Mar  7 2018 jan.fajerski@suse.com
- add user and group according to packaging guidelines
- add README and Makefile as Sources
* Thu Mar  1 2018 jfajerski@suse.com
- Update to version 5.0.0:
  + Github OAuth Fixed fetching github orgs from private github org
  + Provisioning Now handles deletes when dashboard json files removed from disk
  + Reset password Fixed problem with reset password form
  + Save dashboard Fixed issue with time range & variable reset after saving
  + Folders Make it easier/explicit to access/modify folders using the API
  + many more bugfixes
  + See /usr/share/doc/packages/grafana/CHANGELOG.md for more details
* Thu Feb  8 2018 jfajerski@suse.com
- Update to version 5.0.0beta1:
  + New Features:
  * Dashboard folders
  * Teams User groups (teams) implemented. Can be used in folder & dashboard permission list.
  * Dashboard grid: Panels are now layed out in a two dimensional grid (with x, y, w, h).
  * Templating: Vertical repeat direction for panel repeats.
  * UX: Major update to page header and navigation
  * Dashboard settings: Combine dashboard settings views into one with side menu
  * Alerting: Add support for internal image store
  * Data Source Proxy: Add support for whitelisting specified cookies that will be passed through to the data source when proxying data source requests
  * Text: Text panel are now edited in the ace editor
  * Teams: Add Microsoft Teams notifier
  * Datasources: Its now possible to configure datasources with config files
  * Graphite: Query editor updated to support new query by tag features
  * Dashboard history: New config file option versions_to_keep sets how many versions per dashboard to store
  * Dashboard as cfg: Load dashboards from file into Grafana on startup/change
  * Prometheus: Grafana can now send alerts to Prometheus Alertmanager while firing
  * Table: Support multiple table formated queries in table panel
  * Security: Protect against brute force (frequent) login attempts
  + Breaking Changes:
  * Persistent dashboard url's: New url's for dashboards that allows renaming dashboards without breaking links
  * GET /api/alerts property dashboardUri renamed to url and is now the full url (that is including app sub url).
  + Many Bugfixes
  + See /usr/share/doc/packages/grafana/CHANGELOG.md for more details
  - ------------------------------------------------------------------
* Mon Jan 29 2018 jan.fajerski@suse.com
- Use %%{_fillupdir} for sysconfig file
* Wed Jan 24 2018 tserong@suse.com
- Remove non-standard-gid from rpmlintrc
* Thu Jan 18 2018 tserong@suse.com
- Use GRAFANA_GROUP macro in spec file instead of GROUP (which otherwise
  collides with the package group, resulting in incorrect file/directory
  ownership)
* Sat Nov 11 2017 kkaempf@suse.com
- mark %%{_datadir}/%%{name}/conf/defaults.ini as %%conf instead
  of %%doc, grafana-server won't start without this file.
* Tue Oct 24 2017 johannes.grassler@suse.com
- Create /var/lib/grafana/dashboards/
* Tue Oct 17 2017 johannes.grassler@suse.com
- Create plugin directory and clean up (create in %%install,
  add to %%files) handling of /var/lib/grafana/* and
  /var/log/grafana.
* Mon Sep 18 2017 tserong@suse.com
- Update to version 4.5.1:
  + New Features:
  * Table panel: Render cell values as links
  * Elasticsearch: Add ad hoc filters directly by clicking values
  * MySQL: New rich query editor with syntax highlighting
  * Prometheus: New rich query editor with syntax highlighting
  + Enhancements:
  * GitHub OAuth: Support for GitHub organizations with 100+ teams
  * Graphite: Calls to Graphite api /metrics/find now include time range
  * Graphite: Added new graphite 1.0 functions
  * Elasticsearch: Ad-hoc filters now use query phrase match filters
  + Breaking change:
  * InfluxDB/Elasticsearch: The panel & data source option named "Group by
    time interval" is now named "Min time interval" and does now always
    define a lower limit for the auto group by time.
  + Other changes:
  * InfluxDB: Change time range filter for absolute time ranges to be
    inclusive instead of exclusive
  * InfluxDB: Added paranthesis around tag filters in queries
  + Bug Fixes:
  - Modals: Maintain scroll position after opening/leaving modal
  - Templating: You cannot select data source variables as data source
    for other template variables
  - MySQL/Postgres: Fix for max_idle_conn option default which was wrongly
    set to zero which does not mean unlimited but means zero.
  + See /usr/share/doc/packages/grafana/CHANGELOG.md for more details
* Thu Jun 22 2017 jan.fajerski@suse.com
- Fix spec file to create and own /var/{lib,log}/grafana (bsc#1044933)
* Fri Jun 16 2017 tserong@suse.com
- Require phantomjs package at runtime instead of shipping prebuilt
  x86_64 phantomjs binary (bsc#1044444)
* Tue May  2 2017 tserong@suse.com
- Make %%fdupes create hardlinks, not symlinks (symlinks result in
  grafana not being able to load plugins, and the UI breaking)
* Fri Apr 28 2017 tserong@suse.com
- Moved build of frontend assets from RPM %%pre and %%posttrans to
  Makefile, so this piece of work can be done by the packager, rather
  than at installation time.
* Thu Mar 23 2017 thipp@suse.de
- Update to version 4.2.0
- Refactoring based on new packaging proposal
* Mon Sep  5 2016 avvissu@yandex.by
- Update to 3.1.1:
  * see: /usr/share/doc/packages/grafana/CHANGELOG.txt
* Wed Jun  1 2016 avvissu@yandex.by
- Update to 3.0.4:
  * see: /usr/share/doc/packages/grafana/CHANGELOG.txt
* Wed May 25 2016 avvissu@yandex.by
- Update to 3.0.3:
  * see: /usr/share/doc/packages/grafana/CHANGELOG.txt
* Tue May 17 2016 avvissu@yandex.by
- Update to 3.0.2
  * see: /usr/share/doc/packages/grafana/CHANGELOG.txt
- Enable dependency auto-generation
- Don't use npm install -g grunt-cli
- Spec file cleanup
* Fri Apr  1 2016 avvissu@yandex.by
- Add golang(github.com/tools/godep)
* Thu Mar 31 2016 avvissu@yandex.by
- Remove static libraries
* Tue Mar 29 2016 avvissu@yandex.by
- Add _service file to control the URL used by %%%% pre
* Tue Feb 23 2016 avvissu@yandex.ru
- Use BuildRequires when a development branch becomes stable
* Mon Jan 25 2016 avvissu@yandex.ru
- Fix buid error: don't use %%%%goinstall (golang-macros.rb is not
  stable)
* Tue Jan  5 2016 avvissu@yandex.ru
- Fix build error: change GOPATH
- Copy the vendor folder after installation of package
* Fri Dec 11 2015 avvissu@yandex.ru
- Update to 2.6.0:
  * see: /usr/share/doc/packages/grafana/CHANGELOG
- Create a new spec file for building RPM
* Fri May  8 2015 mrueckert@suse.de
- initial package
